
#ifndef _LINUX_IREC_H
#define _LINUX_IREC_H

#include <limits.h>

#include <linux/ioctl.h>
#include <asm/types.h>

#define IREC_MAJOR  61
#define IREC_IRQ  4
#define IREC_PORT  0x3f8

#define PULSE_BIT  0x01000000
#define PULSE_MASK 0x00FFFFFF

#if INT_MAX>=PULSE_BIT
typedef int irec_t;
#else
#error "No appropriate type for irec data available."
#endif


/*
 * irec compatible hardware features
 */


#define IREC_MODE2SEND(x) (x)
#define IREC_SEND2MODE(x) (x)
#define IREC_MODE2REC(x) ((x) << 16)
#define IREC_REC2MODE(x) ((x) >> 16)

#define IREC_MODE_RAW                  0x00000001
#define IREC_MODE_PULSE                0x00000002
#define IREC_MODE_MODE2                0x00000004
#define IREC_MODE_CODE                 0x00000008
#define IREC_MODE_IRECCODE             0x00000010
#define IREC_MODE_STRING               0x00000020


#define IREC_CAN_SEND_RAW              IREC_MODE2SEND(IREC_MODE_RAW)
#define IREC_CAN_SEND_PULSE            IREC_MODE2SEND(IREC_MODE_PULSE)
#define IREC_CAN_SEND_MODE2            IREC_MODE2SEND(IREC_MODE_MODE2)
#define IREC_CAN_SEND_CODE             IREC_MODE2SEND(IREC_MODE_CODE)
#define IREC_CAN_SEND_IRECCODE         IREC_MODE2SEND(IREC_MODE_IRECCODE)
#define IREC_CAN_SEND_STRING           IREC_MODE2SEND(IREC_MODE_STRING)

#define IREC_CAN_SEND_MASK             0x0000003f

#define IREC_CAN_SET_SEND_CARRIER      0x00000100
#define IREC_CAN_SET_SEND_DUTY_CYCLE   0x00000200

#define IREC_CAN_REC_RAW               IREC_MODE2REC(IREC_MODE_RAW)
#define IREC_CAN_REC_PULSE             IREC_MODE2REC(IREC_MODE_PULSE)
#define IREC_CAN_REC_MODE2             IREC_MODE2REC(IREC_MODE_MODE2)
#define IREC_CAN_REC_CODE              IREC_MODE2REC(IREC_MODE_CODE)
#define IREC_CAN_REC_IRECCODE          IREC_MODE2REC(IREC_MODE_IRECCODE)
#define IREC_CAN_REC_STRING            IREC_MODE2REC(IREC_MODE_STRING)

#define IREC_CAN_REC_MASK              IREC_MODE2REC(IREC_CAN_SEND_MASK)

#define IREC_CAN_SET_REC_CARRIER       (IREC_CAN_SET_SEND_CARRIER << 16)
#define IREC_CAN_SET_REC_DUTY_CYCLE    (IREC_CAN_SET_SEND_DUTY_CYCLE << 16)

#define IREC_CAN_SET_REC_DUTY_CYCLE_RANGE 0x40000000
#define IREC_CAN_SET_REC_CARRIER_RANGE    0x80000000


#define IREC_CAN_SEND(x) ((x)&IREC_CAN_SEND_MASK)
#define IREC_CAN_REC(x) ((x)&IREC_CAN_REC_MASK)

/*
 * IOCTL commands for irec driver
 */

#define IREC_GET_FEATURES              _IOR('i', 0x00000000, __u32)

#define IREC_GET_SEND_MODE             _IOR('i', 0x00000001, __u32)
#define IREC_GET_REC_MODE              _IOR('i', 0x00000002, __u32)
#define IREC_GET_SEND_CARRIER          _IOR('i', 0x00000003, __u32)
#define IREC_GET_REC_CARRIER           _IOR('i', 0x00000004, __u32)
#define IREC_GET_SEND_DUTY_CYCLE       _IOR('i', 0x00000005, __u32)
#define IREC_GET_REC_DUTY_CYCLE        _IOR('i', 0x00000006, __u32)

#define IREC_FLUSH_READ_BUFFER         _IOR('i', 0x00000007, __u32)

/* code length in bits, currently only for IREC_MODE_IRECCODE */
#define IREC_GET_LENGTH                _IOR('i', 0x0000000f, __u32)

#define IREC_SET_SEND_MODE             _IOW('i', 0x00000011, __u32)
#define IREC_SET_REC_MODE              _IOW('i', 0x00000012, __u32)
/* Note: these can reset the according pulse_width */
#define IREC_SET_SEND_CARRIER          _IOW('i', 0x00000013, __u32)
#define IREC_SET_REC_CARRIER           _IOW('i', 0x00000014, __u32)
#define IREC_SET_SEND_DUTY_CYCLE       _IOW('i', 0x00000015, __u32)
#define IREC_SET_REC_DUTY_CYCLE        _IOW('i', 0x00000016, __u32)

#define IREC_SET_REC_DUTY_CYCLE_RANGE  _IOW('i', 0x0000001e, __u32)
#define IREC_SET_REC_CARRIER_RANGE     _IOW('i', 0x0000001f, __u32)

#endif
