//////////////////////////////////////////////////////////////
///                                                        ///
/// database.c: database functions of dtv                  ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.6 $
// $Date: 2001/06/08 09:33:38 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#include <stdlib.h>

#include "definitions.h"
#include "structures.h"
#include "prototypes.h"

#ifndef NO_DATABASE
#include <pgsql/libpq-fe.h>
static PGconn *ddbConn = NULL;
#endif

static char buf[1024];
static char sbuf[4096];
static char tbuf[4096];


int initDatabase (void)
{
#ifndef NO_DATABASE
   ddbConn = PQsetdb("localhost", NULL, NULL, NULL, "dtvdb");

   if (PQstatus(ddbConn) == CONNECTION_BAD)
      return (-1);
#endif

   return (0);
}


char *getPresentFollowingInfo (struct Channel *Channel)
{
   int                   i, j, k, Source = 0;
   time_t                ThisTime, Time, NextTime;
   struct tm            *StartTime;
   struct ProgramInfo   *ProgramInfo = NULL;
   char                 *sptr;
   struct Channel       *AvChannel;
#ifndef NO_DATABASE
   PGresult             *res_events = NULL, *res_event = NULL;

   if (!ddbConn)
    { logPrintf (0, "database connection not open\n"); return (NULL); }
#endif
   if (!Channel)
    { logPrintf (0, "getPresentFollowingInfo called with NULL pointer\n");
      return (NULL); }
   if (Channel->MasterChannel)
      AvChannel = Channel->MasterChannel;
   else xForeach (AvailableChannels, AvChannel)
      if ((Channel->TransportStreamID == AvChannel->TransportStreamID) &&
          (Channel->ServiceID == AvChannel->ServiceID)) break;
   if (!AvChannel)
    { logPrintf (0, "getPresentFollowingInfo: channel not found\n");
      return (NULL); }

#ifndef NO_DATABASE
   sprintf (buf, "SELECT ID,START FROM events WHERE CHID=%d ORDER BY START;",
               Channel->ChannelID);

   res_events = PQexec (ddbConn, buf);

   if (!res_events || PQresultStatus(res_events) != PGRES_TUPLES_OK ||
        PQntuples(res_events) == 0) Source = 1;
#endif

   tbuf[0] = '\0';
   ThisTime = time (NULL); j =  0;
#ifndef NO_DATABASE
   if (!Source)
   {
      for (i = 0; i < PQntuples (res_events); i++)
      {
         if ((atol(PQgetvalue(res_events, i, 1)) > ThisTime) && (i>0))
          { k = i-1; i = PQntuples (res_events); }
      }
   } else k = -1;
#endif

   xForeach (AvChannel->ProgramInfos, ProgramInfo)
      if (ProgramInfo->StartTime <= ThisTime &&
       ProgramInfo->StartTime + ProgramInfo->Duration > ThisTime)
         break;

   while (j < 3)
   {
      if (ProgramInfo)
      {
         StartTime = localtime (&ProgramInfo->StartTime);
         if (Channel->NvodList) sprintf (tbuf, "%s \t2\f%c%s\n",
                  tbuf, COL2ID (clrCyan), ProgramInfo->ShortName);
         else sprintf (tbuf, "%s \f%c%2d:%02d\t2\f%c%s\n", tbuf,
                  COL2ID (clrGreen), StartTime->tm_hour, StartTime->tm_min,
                  COL2ID (clrCyan), ProgramInfo->ShortName);
         if (ProgramInfo->ShortText && ProgramInfo->ShortText[0])
            sprintf (tbuf, "%s\t2\f%c%s\n", tbuf, COL2ID (clrWhite),
               ProgramInfo->ShortText);
         else if (ProgramInfo->Content && ProgramInfo->Content[0])
            sprintf (tbuf, "%s\t2\f%c%s\n", tbuf, COL2ID (clrMagenta),
               ProgramInfo->Content);
         NextTime = ProgramInfo->StartTime + ProgramInfo->Duration;
         ProgramInfo = (struct ProgramInfo *) xSucc (ProgramInfo);
         if (ProgramInfo && (ProgramInfo->StartTime - NextTime >
            GetGlobalOption ("programInfoMaximumGap")))
            ProgramInfo = NULL;
      }
#ifndef NO_DATABASE
      else if ((k != -1) && ((k + j) < PQntuples (res_events)))
      {
         sprintf (buf, "SELECT NAME,TYPE,SHDESC FROM events WHERE ID=%s;",
               PQgetvalue(res_events, k+j, 0));
         res_event = PQexec (ddbConn, buf);
         if (res_event && PQresultStatus(res_event) == PGRES_TUPLES_OK &&
              PQntuples(res_event) == 1)
         {
            Time = atol (PQgetvalue(res_events, k+j, 1));
            StartTime = localtime (&Time);
            sprintf (tbuf, "%s \f%c%2d:%02d\t2\f%c%s\n", tbuf, COL2ID (clrGreen),
                     StartTime->tm_hour, StartTime->tm_min, COL2ID (clrCyan),
                     PQgetvalue(res_event, 0, 0));
            if (PQgetvalue(res_event, 0, 2)[0] != '\0') sprintf (tbuf,
               "%s\t2\f%c%s\n", tbuf, COL2ID (clrWhite), (PQgetvalue(res_event, 0, 2)));
            else sprintf (tbuf, "%s\t2\f%c%s\n", tbuf, COL2ID (clrMagenta),
               (PQgetvalue(res_event, 0, 1)));
         }
         PQclear(res_event);
      }
#endif
      j++;
   }
#ifndef NO_DATABASE
   if (res_events) PQclear(res_events);
#endif
   if (tbuf[0] && (sptr = osdWrapText (0, 0, 0, tbuf)))
      return (sptr);
   return (NULL);
}


char *getExtendedInfo (struct Channel *Channel)
{
   int                   i, j, k, Source = 0;
   time_t                ThisTime, Time;
   struct tm            *StartTime;
   struct ProgramInfo   *ProgramInfo = NULL;
   char                 *sptr;
   struct Channel       *AvChannel;
#ifndef NO_DATABASE
   PGresult             *res_events = NULL, *res_event = NULL;

   if (!ddbConn)
    { logPrintf (0, "database connection not open\n"); return (NULL); }
#endif
   if (!Channel)
    { logPrintf (0, "getExtendedInfo called with NULL pointer\n");
      return (NULL); }
   if (Channel->MasterChannel)
      AvChannel = Channel->MasterChannel;
   else xForeach (AvailableChannels, AvChannel)
      if ((Channel->TransportStreamID == AvChannel->TransportStreamID) &&
          (Channel->ServiceID == AvChannel->ServiceID)) break;
   if (!AvChannel)
    { logPrintf (0, "getExtendedInfo: channel not found\n");
      return (NULL); }

#ifndef NO_DATABASE
   sprintf (buf, "SELECT ID,START FROM events WHERE CHID=%d ORDER BY START;",
               Channel->ChannelID);

   res_events = PQexec (ddbConn, buf);

   if (!res_events || PQresultStatus(res_events) != PGRES_TUPLES_OK ||
        PQntuples(res_events) == 0) Source = 1;
#endif

   tbuf[0] = '\0';
   ThisTime = time (NULL); j =  0;
#ifndef NO_DATABASE
   if (!Source)
   {
      for (i = 0; i < PQntuples (res_events); i++)
      {
         if ((atol(PQgetvalue(res_events, i, 1)) > ThisTime) && (i>0))
          { k = i-1; i = PQntuples (res_events); }
      }
   } else k = -1;
#endif

   xForeach (AvChannel->ProgramInfos, ProgramInfo)
      if (ProgramInfo->StartTime <= ThisTime &&
       ProgramInfo->StartTime + ProgramInfo->Duration > ThisTime)
         break;

   while (j < 1)
   {
      if (ProgramInfo)
      {
         StartTime = localtime (&ProgramInfo->StartTime);
         if (Channel->NvodList) sprintf (tbuf, "%s \t2\f%c%s\n",
                  tbuf, COL2ID (clrCyan), ProgramInfo->ShortName);
         else sprintf (tbuf, "%s \f%c%2d:%02d\t2\f%c%s\n", tbuf,
                  COL2ID (clrGreen), StartTime->tm_hour, StartTime->tm_min,
                  COL2ID (clrCyan), ProgramInfo->ShortName);
         if (ProgramInfo->Content && ProgramInfo->Content[0])
            sprintf (tbuf, "%s\t2\f%c%s\n", tbuf,
               COL2ID (clrMagenta), ProgramInfo->Content);
         if (ProgramInfo->ExtendedText && ProgramInfo->ExtendedText[0])
            sprintf (tbuf, "%s\t2\f%c%s\n", tbuf,
               COL2ID (clrWhite), ProgramInfo->ExtendedText);
         else if (ProgramInfo->ExtendedName && ProgramInfo->ExtendedName[0])
            sprintf (tbuf, "%s\t2\f%c%s\n", tbuf,
               COL2ID (clrWhite), ProgramInfo->ExtendedName);
         else if (ProgramInfo->ShortText && ProgramInfo->ShortText[0])
            sprintf (tbuf, "%s\t2\f%c%s\n", tbuf,
               COL2ID (clrWhite), ProgramInfo->ShortText);
         ProgramInfo = (struct ProgramInfo *) xSucc (ProgramInfo);
      }
#ifndef NO_DATABASE
      else if ((k != -1) && ((k + j) < PQntuples (res_events)))
      {
         sprintf (buf, "SELECT NAME,TYPE,SHDESC,EXDESC FROM events WHERE ID=%s;",
               PQgetvalue(res_events, k+j, 0));
         res_event = PQexec (ddbConn, buf);
         if (res_event && PQresultStatus(res_event) == PGRES_TUPLES_OK &&
              PQntuples(res_event) >= 1)
         {
            Time = atol (PQgetvalue(res_events, k+j, 1));
            StartTime = localtime (&Time);
            sprintf (tbuf, "%s \f%c%2d:%02d\t2\f%c%s\n", tbuf, COL2ID (clrGreen),
                     StartTime->tm_hour, StartTime->tm_min, COL2ID (clrCyan),
                     PQgetvalue(res_event, 0, 0));
            sprintf (tbuf, "%s\t2\f%c%s\n", tbuf, COL2ID (clrMagenta),
               PQgetvalue(res_event, 0, 1));
            sprintf (tbuf, "%s\t2\f%c%s\n", tbuf, COL2ID (clrWhite),
               PQgetvalue(res_event, 0, 3));
         }
         PQclear(res_event);
      }
#endif
      j++;
   }
#ifndef NO_DATABASE
   if (res_events) PQclear(res_events);
#endif
   if (tbuf[0] && (sptr = osdWrapText (0, 0, 0, tbuf)))
      return (sptr);
   return (NULL);
}


char *getChannelMenu (struct Channel *InfoChannel)
{
   struct Channel    *Channel;
   int                WindowSize, Opening, i, j;

   sbuf[0] = '\0'; if (!InfoChannel) return (sbuf);

   if ((WindowSize = GetGlobalOption ("channelMenuWindowSize")) < 1)
      WindowSize = 1;
   if (WindowSize > ((OSD_MENU_END-OSD_MENU_START)/OSD_MENU_FONT_HEIGHT))
      WindowSize = (OSD_MENU_END-OSD_MENU_START)/OSD_MENU_FONT_HEIGHT;
   if (!(WindowSize%2)) WindowSize--;

   Opening = WindowSize/2;
   for (i = 0; i < WindowSize; i++)
   {
      if (i < Opening)
      {
         for (j = 0, Channel = InfoChannel;
                 (j < (Opening-i)) && Channel; j++,
                 Channel = (struct Channel *) xPred (Channel));
         if (Channel)
            sprintf (sbuf, "%s \f%c%d\t2\f%c%s\n", sbuf, COL2ID (clrYellow),
               Channel->ChannelNumber, COL2ID (clrWhite), xName (Channel));
         else sprintf (sbuf, "%s\n", sbuf);
      }
      if (i == Opening)
      {
         sprintf (sbuf, "%s\b%c \f%c%d\t2\f%c%s\n\b%c", sbuf,
             COL2ID (clrWhite), COL2ID (clrBlue), InfoChannel->ChannelNumber,
             COL2ID (clrBlack), xName (InfoChannel), COL2ID (clrBackground));
      }
      if (i > Opening)
      {
         for (j = 0, Channel = InfoChannel;
                 (j < (i-Opening)) && Channel; j++,
                 Channel = (struct Channel *) xSucc (Channel));
         if (Channel)
            sprintf (sbuf, "%s \f%c%d\t2\f%c%s\n", sbuf, COL2ID (clrYellow),
               Channel->ChannelNumber, COL2ID (clrWhite), xName (Channel));
         else sprintf (sbuf, "%s\n", sbuf);
      }
   }
   return (sbuf);
}


char *getUserMenu (struct OutputDevice *OutputDevice)
{
   struct MenuItem         *StartOfScreen, *ActualMenuItem,
                           *UplevelMenu, *MenuItem;
   int                      WindowSize, ScrollThreshold, i, j;
   int                      Size, StartPos, ItemPos;

   sbuf[0] = '\0';

   if (!(ActualMenuItem = OutputDevice->ActualMenuItem) ||
       !(UplevelMenu = ActualMenuItem->UplevelMenu))
      return (sbuf);

   if (!(StartOfScreen = UplevelMenu->StartOfScreen))
      StartOfScreen = UplevelMenu->StartOfScreen =
         (struct MenuItem *) UplevelMenu->Menu->Head;

   if ((WindowSize = GetGlobalOption ("userMenuWindowSize")) < 1)
      WindowSize = 1;
   if (WindowSize > ((OSD_MENU_END-OSD_MENU_START)/OSD_MENU_FONT_HEIGHT))
      WindowSize = (OSD_MENU_END-OSD_MENU_START)/OSD_MENU_FONT_HEIGHT;
   if ((ScrollThreshold = GetGlobalOption ("userMenuScrollThreshold")) < 0)
      ScrollThreshold = 0;
   if (ScrollThreshold > (WindowSize+1)/2-1)
      ScrollThreshold = (WindowSize+1)/2-1;

   Size = 0; StartPos = -1; ItemPos = -1;
   xForeach (UplevelMenu->Menu, MenuItem)
   {
      if (MenuItem == StartOfScreen) StartPos = Size;
      if (MenuItem == ActualMenuItem) ItemPos = Size;
      Size++;
      if ((StartPos != -1) && (ItemPos != -1)) break;
   }
   if ((StartPos == -1) || (ItemPos == -1)) return (sbuf);

   if (ItemPos < (StartPos+ScrollThreshold))
      for (i = 0; (i < (StartPos+ScrollThreshold-ItemPos)) &&
                   xPred (StartOfScreen); i++)
         StartOfScreen = (struct MenuItem *) xPred (StartOfScreen);
   if ((Size-ItemPos-1) < ScrollThreshold) ScrollThreshold = Size-ItemPos-1;
   if (ItemPos > (StartPos+WindowSize-ScrollThreshold-1))
      for (i = 0; i < (ItemPos-StartPos-WindowSize+ScrollThreshold+1); i++)
         StartOfScreen = (struct MenuItem *) xSucc (StartOfScreen);

   UplevelMenu->StartOfScreen = StartOfScreen;
   for (i = 0, MenuItem = StartOfScreen; (i < WindowSize) && MenuItem;
           MenuItem = (struct MenuItem *) xSucc (MenuItem), i++)
   {
      if (MenuItem == ActualMenuItem)
         sprintf (sbuf, "%s\b%c \f%c%s\n\b%c", sbuf,
            COL2ID (clrWhite), COL2ID (clrBlack), xName (MenuItem),
            COL2ID (clrBackground));
      else
         sprintf (sbuf, "%s \f%c%s\n", sbuf,
            COL2ID (clrWhite), xName (MenuItem));
   }

   return (sbuf);
}


struct Channel *getChannelFromNvodItem (struct NvodReferenceItem *NvodItem,
                                        struct Channel *SourceChannel)
{
   struct Channel               *Channel, *GotChannel;

   if (!SourceChannel || !NvodItem)
   {
      logPrintf (0, "getChannelFromNvodItem called with NULL pointer\n");
      return (NULL);
   }

   xForeach (AvailableChannels, GotChannel)
      if (GotChannel->TransportStreamID == NvodItem->TransportStreamID)
         break;
   if (!GotChannel) return (NULL);

   CreateChannel (Channel, SourceChannel->ChannelNumber,
              SourceChannel->ChannelID, NULL, SourceChannel->Provider,
              SourceChannel->Type, NvodItem->TransportStreamID,
              GotChannel->Frequency, GotChannel->Polarisation,
              GotChannel->SymbolRate, NvodItem->ServiceID, 0, 0,
              SourceChannel->Language, SourceChannel->Fec, SourceChannel->Camd);

   return (Channel);
}


struct Channel *getChannelFromLinkageDescriptor (struct Descriptor *Descriptor,
                                                 struct Channel *SourceChannel)
{
   int                           i;
   struct Channel               *Channel, *GotChannel;
   struct LinkageDescriptor     *LinkageDescriptor;

   if (!SourceChannel || !Descriptor)
   {
      logPrintf (0, "getChannelFromLinkageDescriptor called with NULL pointer\n");
      return (NULL);
   }
   LinkageDescriptor = (struct LinkageDescriptor *) Descriptor;

   if ((LinkageDescriptor->TransportStreamID ==
          SourceChannel->TransportStreamID) &&
       (LinkageDescriptor->ServiceID == SourceChannel->ServiceID))
      return (NULL);

   for (i = 0; i < LinkageDescriptor->PrivateDataLength; i++)
      sbuf[i] = LinkageDescriptor->PrivateData[i];
   sbuf[i] = '\0';

   xForeach (AvailableChannels, GotChannel)
      if (GotChannel->TransportStreamID == LinkageDescriptor->TransportStreamID)
         break;
   if (!GotChannel) return (NULL);

   CreateChannel (Channel, SourceChannel->ChannelNumber,
               SourceChannel->ChannelID, sbuf, SourceChannel->Provider,
               SourceChannel->Type, LinkageDescriptor->TransportStreamID,
               GotChannel->Frequency, GotChannel->Polarisation,
               GotChannel->SymbolRate, LinkageDescriptor->ServiceID, 0, 0,
               SourceChannel->Language, SourceChannel->Fec, SourceChannel->Camd);

   return (Channel);
}


int closeDatabase (void)
{
#ifndef NO_DATABASE
   if (ddbConn) 
      PQfinish(ddbConn);

   ddbConn = NULL;
#endif

   return (0);
}
