//////////////////////////////////////////////////////////////
///                                                        ///
/// dtv.c: main functions of dtv                           ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.3 $
// $Date: 2001/06/13 14:12:31 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#include <getopt.h>
#include <stdio.h>
#include <signal.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>


#include "definitions.h"
#include "structures.h"
#include "prototypes.h"


int daemonMode = 0, logLevel = 2;
FILE *logFile = NULL;

static struct option long_options[] = {
   { "daemon",       no_argument,       NULL, 'd' },
   { "help",         no_argument,       NULL, 'h' },
   { "configfile",   required_argument, NULL, 'c' },
   { "logfile",      required_argument, NULL, 'l' },
   { "verbosity",    required_argument, NULL, 'v' },
   { 0 }
};

  
int main (int argc, char **argv)
{
   int           c, option_index = 0, l, end;
   char         *logFileName = LOG_FILE;
   char         *configFileName = "dtv.conf";

   while ((c = getopt_long(argc, argv, "v:dhc:l:",
              long_options, &option_index)) != -1)
   {
      switch (c)
      {
         case 'd':
            daemonMode = 1;
         break;

         case 'c':
            configFileName = optarg;
         break;

         case 'l':
            logFileName = optarg;
         break;

         case 'v':
            if (((l = atoi(optarg)) < 0) || (l > 8))
            {
               fprintf(stderr, "%s: invalid verbosity level: %s\n",
                          argv[0], optarg);
               return (-1);
            }
            else logLevel = l;
         break;

         case 'h':
         default:
            fprintf(stderr, "\nUsage: %s [OPTION]\n\n", argv[0]);
            fprintf(stderr, "  -d,        --daemon            run in daemon mode\n");
            fprintf(stderr, "  -h,        --help              display this help and exit\n");
            fprintf(stderr, "  -c <file>, --configfile=<file> set configfile (default: dtv.conf)\n");
            fprintf(stderr, "  -l <file>, --logfile=<file>    set logfile (default: dtv.log)\n");
            fprintf(stderr, "  -v LEVEL,  --verbosity=LEVEL   set verbosity level (default: 2)\n");
            fprintf(stderr, "                                 0 = no logging, 8 = tedious\n");
            fprintf(stderr, "\n");
            fprintf(stderr, "Report bugs to <hakenes@hippomi.de>\n\n");
            return (0);
         break;
      }
   }

   if (daemonMode)
   {
      pid_t pid;

      if ((pid = fork ()) < 0)
      {
         fprintf(stderr, "%s\n", strerror(errno));
         return (-1);
      }
      if (pid != 0) return 0;    /* parent program exits... */

      // fclose(stdin);
      // fclose(stdout);
      // fclose(stderr);
   }

   if (logFileName)
   {
      if (!daemonMode && !strcmp (logFileName, "-"))
         logFile = stdout;
      else
      {
         if (!(logFile = fopen (logFileName, "a")))
         {
            fprintf(stderr, "Error:   cannot open %s\n", logFileName);
            return (-2);
         }
      }
      logPrintf (0, "dtv started\n");
   }
   signal (SIGINT, safeExit);
   signal (SIGHUP, safeExit);
   signal (SIGTERM, safeExit);

   initDatabase ();
   if (initConfiguration (configFileName) != 0) safeExit (0);
   openInputDevices ();
   while (!execScheduler ()) usleep (10);

   safeExit (0);
}


void safeExit (int sigNum)
{
//   debugUserMenu (logFile, "", ((struct OutputDevice *)OutputDevices->Tail)->UserMenu);
   logPrintf (0, "dtv stopped on signal %d\n", sigNum);
   signal (SIGINT, SIG_DFL);
   signal (SIGHUP, SIG_DFL);
   signal (SIGTERM, SIG_DFL);
   closeInputDevices ();
   closeOutputDevices ();
//   debugChannels ("dtv.dbg");
   closeDatabase ();
   exit (0);
}
