//////////////////////////////////////////////////////////////
///                                                        ///
/// dtv_config.c: Dcl dependent functions of dtv           ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.13 $
// $Date: 2001/06/14 17:03:51 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <dcl.h>

#include "definitions.h"
#include "structures.h"
#include "prototypes.h"


struct LIST *AvailableSatellites = NULL;
struct LIST *AvailableChannels = NULL;
struct LIST *OutputDevices = NULL;
struct LIST *InputDevices = NULL;
struct LIST *CommandQueue = NULL;
struct LIST *GlobalOptions = NULL;

struct MEM_CHUNK *AvChRemember = NULL;
struct MEM_CHUNK *AvSatRemember = NULL;
struct MEM_CHUNK *CommandRemember = NULL;

struct Option *statOption = NULL;

Dcl_Interp *interp = NULL;


int initConfiguration (char *fileName)
{
   GlobalOptions = xNewList (NULL);
   OutputDevices = xNewList (NULL);
   InputDevices = xNewList (NULL);
   CommandQueue = xNewList (NULL);

   AddGlobalOption ("dvbDefaultDiseqcNr", DVB_DEFAULT_DISEQC_NR);
   AddGlobalOption ("dvbDefaultLnbLsof", DVB_DEFAULT_LNB_LSOF);
   AddGlobalOption ("dvbDefaultLnbFreqLow", DVB_DEFAULT_LNB_FREQ_LOW);
   AddGlobalOption ("dvbDefaultLnbFreqHigh", DVB_DEFAULT_LNB_FREQ_HIGH);
   AddGlobalOption ("dvbDefaultClearDelay", DVB_DEFAULT_CLEAR_DELAY);
   AddGlobalOption ("tdtDefaultDelay", TDT_DEFAULT_DELAY);
   AddGlobalOption ("eitAcquisitionNumberOfFails", EIT_ACQUISITION_NUMBER_OF_FAILS);
   AddGlobalOption ("eitAcquisitionDefaultDelay", EIT_ACQUISITION_DEFAULT_DELAY);
   AddGlobalOption ("eitScanDefaultIdleTime", EIT_SCAN_DEFAULT_IDLETIME);
   AddGlobalOption ("eitScanDefaultTimePerTransponder", EIT_SCAN_DEFAULT_TIME_PER_TRANSPONDER);
   AddGlobalOption ("useEitFromDatabase", USE_EIT_FROM_DATABASE);
   AddGlobalOption ("programInfoMaximumGap", PROGRAM_INFO_MAXIMUM_GAP);
   AddGlobalOption ("maxVtxMemory", MAX_VTX_MEMORY);
   AddGlobalOption ("maxEitMemory", MAX_EIT_MEMORY);
   AddGlobalOption ("tcpipDefaultPort", TCPIP_DEFAULT_PORT);
   AddGlobalOption ("disableOsd", DISABLE_OSD);
   AddGlobalOption ("channelMenuWindowSize", CHANNEL_MENU_WINDOW_SIZE);
   AddGlobalOption ("userMenuWindowSize", USER_MENU_WINDOW_SIZE);
   AddGlobalOption ("userMenuScrollThreshold", USER_MENU_SCROLL_THRESHOLD);

   if (!(interp = Dcl_CreateInterp ()) ||
       (Dtv_Init (interp) != DCL_OK))
   {
      logPrintf (0, "error creating DCL interpreter\n");
      return (-1);
   }
   Dcl_SetVar(interp, "dtvConfigPath", CONF_DIR, DCL_GLOBAL_ONLY);
   if (Dcl_EvalFile (interp, fileName) != DCL_OK)
   {
      logPrintf (0, "%s\n", interp->result);
      return (-1);
   }

   //  TODO: check for existance of at least one out/input pair and implication
   return (0);
}


int Dtv_Init (Dcl_Interp *interp)
{
   Dcl_CreateCommand (interp, "define_available_satellites",
                         Dcl_DefineAvailableSatellites, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "dump_available_satellites",
                         Dcl_DumpAvailableSatellites, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "define_available_channels",
                         Dcl_DefineAvailableChannels, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "dump_available_channels",
                         Dcl_DumpAvailableChannels, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "open_output",
                         Dcl_OpenOutput, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "add_channel_list",
                         Dcl_AddChannelList, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "open_input",
                         Dcl_OpenInput, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "add_implication",
                         Dcl_AddImplication, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "add_processor",
                         Dcl_AddProcessor, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "set_osd_language",
                         Dcl_SetOsdLanguage, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "set_option",
                         Dcl_SetOption, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "keypress",
                         Dcl_Keypress, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "add_menu_item",
                         Dcl_AddMenuItem, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "rem_menu_item",
                         Dcl_RemMenuItem, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "out_message",
                         Dcl_OutMessage, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "out_text",
                         Dcl_OutText, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   return DCL_OK;
}


int Dcl_DefineAvailableSatellites (ClientData clientData, Dcl_Interp *interp,
                                 int argc, char **argv)
{
   int                  numberOfSatellites, fieldLength, i, returnValue;
   int                  diseqcnr, lsof, freqlo, freqhi;
   char               **satList, **satField;
   struct Satellite    *Satellite;
   struct MEM_CHUNK   **OriginalKey;

   if (argc != 2) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " {{<name> <diseqc-nr> <lnb-lsof>",
                                " <lnb-flo> <lnb-fhi>}{...}}\"", (char *) NULL);
      return DCL_ERROR;
   }

   if (Dcl_SplitList(interp, argv[1], &numberOfSatellites,
          &satList) != DCL_OK) return DCL_ERROR;

   returnValue = DCL_OK;
   OriginalKey = xGetRemember ();
   xSetRemember (&AvSatRemember);
   if (AvSatRemember != NULL) xMemFreeAll (NULL);
   AvailableSatellites = xNewList (NULL);

   for (i = 0; i < numberOfSatellites; i++)
   {
      if (Dcl_SplitList(interp, satList[i], &fieldLength,
             &satField) != DCL_OK) { returnValue = DCL_ERROR; break; }

      if (fieldLength != 5)
      {
         Dcl_AppendResult (interp, "each field must have 14 entries:",
                                   " {<name> <diseqc-nr> <lnb-lsof>",
                                   " <lnb-flo> <lnb-fhi>}", (char *) NULL);
         returnValue = DCL_ERROR;
      } else if ( (Dcl_GetInt (interp, satField[1], &diseqcnr) != DCL_OK) ||
                  (Dcl_GetInt (interp, satField[2], &lsof) != DCL_OK) ||
                  (Dcl_GetInt (interp, satField[3], &freqlo) != DCL_OK) ||
                  (Dcl_GetInt (interp, satField[4], &freqhi) != DCL_OK))
             { returnValue = DCL_ERROR; }
             else
             {
                if (xFindName (AvailableSatellites, satField[0]))
                {
                   Dcl_AppendResult (interp, "satellite \"", satField[0],
                                         "\" already defined", (char *) NULL);
                   returnValue = DCL_ERROR;
                }
                else
                {
                   CreateSatellite (Satellite, satField[0], diseqcnr,
                                       lsof, freqlo, freqhi);
                   xAddTail (AvailableSatellites, Satellite);
                }
             }
      free ((char *) satField);   // Dcl_Free ???
   }
   free ((char *) satList);   // Dcl_Free ???

   xSetRemember (OriginalKey);
   return returnValue;
}


int Dcl_DumpAvailableSatellites (ClientData clientData, Dcl_Interp *interp,
                    int argc, char **argv)
{
   FILE                   *outfile;
   struct Satellite       *Satellite;

   if (argc != 2) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                           " <file>\"", (char *) NULL);
      return DCL_ERROR;
   }
   if (!(outfile = fopen (argv[1], "w+"))) {
      Dcl_AppendResult (interp, argv[0], ": cannot create ", argv[1],
                           (char *) NULL);
      return DCL_ERROR;
   }
   fprintf (outfile, "define_available_satellites {\n");
   xForeach (AvailableSatellites, Satellite)
   {
      fprintf (outfile, "   {");
      fprintf (outfile, "{%s} ", xName (Satellite));
      fprintf (outfile, "%d ", Satellite->DiseqcNr);
      fprintf (outfile, "%d ", Satellite->LnbLsof);
      fprintf (outfile, "%d ", Satellite->LnbFreqLow);
      fprintf (outfile, "%d ", Satellite->LnbFreqHigh);
      fprintf (outfile, "}\n");
   }
   fprintf (outfile, "}\n");

   fclose (outfile);
   return DCL_OK;
}


int Dcl_DefineAvailableChannels (ClientData clientData, Dcl_Interp *interp,
                                 int argc, char **argv)
{
   int                  numberOfChannels, fieldLength, i, j, returnValue;
   int                  tpid, freq, srate, svid, vpid, apid, ppid;
   char               **channelList, **channelField;
   struct Channel      *Channel, *Chan2;
   struct MEM_CHUNK   **OriginalKey;

   if (argc != 2) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " {{<name> <prov> <type> <tpid> <freq> ",
                                "<pol> <srate> <svid> <vpid> <apid> <ppid> ",
                                "<lang> <fec> <camd> [<satellite>]}{...}}\"",
                                (char *) NULL);
      return DCL_ERROR;
   }

   if (Dcl_SplitList(interp, argv[1], &numberOfChannels,
          &channelList) != DCL_OK) return DCL_ERROR;

   returnValue = DCL_OK;
   OriginalKey = xGetRemember ();
   xSetRemember (&AvChRemember);
   if (AvChRemember != NULL) xMemFreeAll (NULL);
   AvailableChannels = xNewList (NULL);

   for (i = 0; i < numberOfChannels; i++)
   {
      if (Dcl_SplitList(interp, channelList[i], &fieldLength,
             &channelField) != DCL_OK) { returnValue = DCL_ERROR; break; }

      if ((fieldLength != 14) && (fieldLength != 15))
      {
         Dcl_AppendResult (interp, "each field must have 14/15 entries:",
                                   " {<name> <prov> <type> <tpid> <freq> ",
                                   "<pol> <srate> <svid> <vpid> <apid> <ppid> ",
                                   "<lang> <fec> <camd> [<satellite>]}",
                                   (char *) NULL);
         returnValue = DCL_ERROR;
      } else if ( (Dcl_GetInt (interp, channelField[3], &tpid) != DCL_OK) ||
                  (Dcl_GetInt (interp, channelField[4], &freq) != DCL_OK) ||
                  (Dcl_GetInt (interp, channelField[6], &srate) != DCL_OK) ||
                  (Dcl_GetInt (interp, channelField[7], &svid) != DCL_OK) ||
                  (Dcl_GetInt (interp, channelField[8], &vpid) != DCL_OK) ||
                  (Dcl_GetInt (interp, channelField[9], &apid) != DCL_OK) ||
                  (Dcl_GetInt (interp, channelField[10], &ppid) != DCL_OK))
             { returnValue = DCL_ERROR; }
             else
             {
                CreateChannel (Channel, 0, xHashKey (channelField[0]) +      
                                  32768*xHashKey (channelField[1]),
                                  channelField[0], channelField[1],
                                  channelField[2], tpid, freq*1000,
                                  channelField[5][0], srate, svid, vpid,
                                  apid, channelField[11], channelField[12],
                                  channelField[13]);
                Channel->PcrPid = ppid;
                if (fieldLength == 15)
                {
                   if (!(Channel->Satellite = (struct Satellite *)
                      xFindName (AvailableSatellites, channelField[14])))
                   {
                      Dcl_AppendResult (interp, "satellite name \"",
                         channelField[14], "\" not found", (char *) NULL);
                      returnValue = DCL_ERROR;
                   }
                }
                if (!AvailableChannels->Head)
                   xAddTail (AvailableChannels, Channel);
                else
                {
                   xForeachReverse (AvailableChannels, Chan2)
                      if (Chan2->Frequency < Channel->Frequency) break;
                   if (!Chan2)
                      xAddHead (AvailableChannels, Channel);
                   else xJoin (Channel, AvailableChannels, Chan2);
                }
             }
      free ((char *) channelField);   // Dcl_Free ???
   }
   free ((char *) channelList);   // Dcl_Free ???

   xSetRemember (OriginalKey);
   return returnValue;
}


int Dcl_DumpAvailableChannels (ClientData clientData, Dcl_Interp *interp,
                    int argc, char **argv)
{
   FILE                   *outfile;
   struct Channel         *Channel;

   if (argc != 2) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                           " <file>\"", (char *) NULL);
      return DCL_ERROR;
   }
   if (!(outfile = fopen (argv[1], "w+"))) {
      Dcl_AppendResult (interp, argv[0], ": cannot create ", argv[1],
                           (char *) NULL);
      return DCL_ERROR;
   }
   fprintf (outfile, "define_available_channels {\n");
   xForeach (AvailableChannels, Channel)
   {
      fprintf (outfile, "   {");
      fprintf (outfile, "{%s} ", xName (Channel));
      fprintf (outfile, "{%s} ", Channel->Provider);
      fprintf (outfile, "%s ", Channel->Type);
      fprintf (outfile, "%d ", Channel->TransportStreamID);
      fprintf (outfile, "%d ", Channel->Frequency/1000);
      fprintf (outfile, "%c ", Channel->Polarisation);
      fprintf (outfile, "%d ", Channel->SymbolRate);
      fprintf (outfile, "%d ", Channel->ServiceID);
      fprintf (outfile, "%d ", Channel->VideoPid);
      fprintf (outfile, "%d ", Channel->AudioPid);
      fprintf (outfile, "%d ", Channel->PcrPid);
      fprintf (outfile, "%s ", Channel->Language);
      fprintf (outfile, "%s ", Channel->Fec);
      fprintf (outfile, "%s ", Channel->Camd);
      if (Channel->Satellite)
         fprintf (outfile, "%s ", xName (Channel->Satellite));
      fprintf (outfile, "}\n");
   }
   fprintf (outfile, "}\n");

   fclose (outfile);
   return DCL_OK;
}


int Dcl_OpenOutput (ClientData clientData, Dcl_Interp *interp,
                    int argc, char **argv)
{
   int                     id = 0, devnum;
   struct OutputDevice    *OutputDevice;
   char                    buf[32];

   if (argc < 2) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                           " <type> ?<args>?\"", (char *) NULL);
      return DCL_ERROR;
   }
   if (strcasecmp (argv[1], "DVBS"))
   {
      Dcl_AppendResult (interp, "unsupported output device \"", argv[1],
                            "\".\nsupported devices are: DVBS", (char *) NULL);
      return DCL_ERROR;
   }
   if (!strcasecmp (argv[1], "DVBS"))
   {
      if (argc != 3) {
         Dcl_AppendResult (interp, "you have to specify a device number ",
                                   "for DVBS", (char *) NULL);
         return DCL_ERROR;
      }
      if (Dcl_GetInt (interp, argv[2], &devnum) != DCL_OK)
         return DCL_ERROR;

      xForeach (OutputDevices, OutputDevice)
         if (OutputDevice->Identifier >= id)
            id = OutputDevice->Identifier + 1;
      sprintf (buf, "%d", devnum);
      CreateOutputDevice (OutputDevice, buf, id,
                             processDvbCommand, closeDvbDevice);
      xAddTail (OutputDevices, OutputDevice);
      sprintf (buf, "%d", id);
      Dcl_AppendResult (interp, buf, (char *) NULL);
   }
   return DCL_OK;
}


int Dcl_AddChannelList (ClientData clientData, Dcl_Interp *interp,
                        int argc, char **argv)
{
   int                    numberOfChannels, fieldLength, prognr,
                          outputID = -2, i, j, channelID, returnValue;
   char                 **channelList, **channelField;
   struct OutputDevice   *OutputDevice;
   struct Channel        *Channel, *NewChannel;

   if (argc != 3) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <id> {{<prognr> <name> <provider>}{...}}\"",
                                (char *) NULL);
      return DCL_ERROR;
   }
   if (!strncasecmp (argv[1], "-all", 2)) outputID = -1;
   else if (!strncasecmp (argv[1], "-current", 2) && CurrentOutputDevice)
           outputID = CurrentOutputDevice->Identifier;
        else if (Dcl_GetInt (interp, argv[1], &outputID) != DCL_OK)
                return DCL_ERROR;

   xForeach (OutputDevices, OutputDevice)
      if (OutputDevice->Identifier == outputID) break;
   if (!OutputDevice && (outputID != -1))
   {
      Dcl_AppendResult (interp, "no device found for specified id",
                                (char *) NULL);
      return DCL_ERROR;
   }

   if (Dcl_SplitList(interp, argv[2], &numberOfChannels,
          &channelList) != DCL_OK) return DCL_ERROR;

   returnValue = DCL_OK;

   for (i = 0; i < numberOfChannels; i++)
   {
      if (Dcl_SplitList(interp, channelList[i], &fieldLength,
             &channelField) != DCL_OK) { returnValue = DCL_ERROR; break; }

      if (fieldLength != 3)
      {
         Dcl_AppendResult (interp, "each field must have 3 entries:",
                                   " {<prognr> <name> <provider>}",
                                   (char *) NULL);
         returnValue = DCL_ERROR;
      } else if (Dcl_GetInt (interp, channelField[0], &prognr) != DCL_OK)
             { returnValue = DCL_ERROR; }
             else
             {
                channelID = xHashKey (channelField[1]) +      
                            32768*xHashKey (channelField[2]);
                xForeach (AvailableChannels, Channel)
                   if (Channel->ChannelID == channelID)
                      break;
                if (Channel)
                {
                   if (outputID == -1)
                   {
                      xForeach (OutputDevices, OutputDevice)
                      {
                         CloneChannel (NewChannel, Channel, Channel->VideoPid,
                                       0, Channel->AudioPid, 0, xName (Channel));
                         NewChannel->ChannelNumber = prognr;
                         NewChannel->MasterChannel = Channel;
                         xAddTail (OutputDevice->Channels, NewChannel);
                      }
                   }
                   else
                   {
                      CloneChannel (NewChannel, Channel, Channel->VideoPid,
                                    0, Channel->AudioPid, 0, xName (Channel));
                      NewChannel->ChannelNumber = prognr;
                      NewChannel->MasterChannel = Channel;
                      xAddTail (OutputDevice->Channels, NewChannel);
                   }
                }
                else
                {
                   logPrintf (2, "channel {%s} {%s} %s\n",
                                 channelField[1], channelField[2],
                                 "not found in available channels");
                }
             }
      free ((char *) channelField);   // Dcl_Free ???
   }
   free ((char *) channelList);   // Dcl_Free ???
   return returnValue;
}


int Dcl_OpenInput (ClientData clientData, Dcl_Interp *interp,
                    int argc, char **argv)
{
   int                     id = 0, devnum, portNumber;
   struct InputDevice     *InputDevice;
   char                    buf[32];

   if (argc < 2) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                           " <type> ?<args>?\"", (char *) NULL);
      return DCL_ERROR;
   }
   if ((strcasecmp (argv[1], "IR_REC")) &&
       (strcasecmp (argv[1], "LIRCD")) &&
       (strcasecmp (argv[1], "TCPIP")) &&
       (strcasecmp (argv[1], "KEYBOARD")))
   {
      Dcl_AppendResult (interp, "unsupported input device \"", argv[1],
                            "\".\nsupported devices are: IR_REC, ",
                            "LIRCD, ", "KEYBOARD", (char *) NULL);
      return DCL_ERROR;
   }
   if (!strcasecmp (argv[1], "IR_REC"))
   {
      xForeach (InputDevices, InputDevice)
         if (InputDevice->Identifier >= id)
            id = InputDevice->Identifier + 1;
      CreateInputDevice (InputDevice, "/dev/lirc", id,
                            openRemote, closeRemote, getRemoteEvent);
      InputDevice->Type = INPTYP_POLLING;
      xAddTail (InputDevices, InputDevice);
      sprintf (buf, "%d", id);
      Dcl_AppendResult (interp, buf, (char *) NULL);
      return DCL_OK;
   }
   if (!strcasecmp (argv[1], "LIRCD"))
   {
      xForeach (InputDevices, InputDevice)
         if (InputDevice->Identifier >= id)
            id = InputDevice->Identifier + 1;
      CreateInputDevice (InputDevice, "/dev/lircd", id,
                            openLircd, closeLircd, getLircdEvent);
      InputDevice->Type = INPTYP_POLLING;
      xAddTail (InputDevices, InputDevice);
      sprintf (buf, "%d", id);
      Dcl_AppendResult (interp, buf, (char *) NULL);
      return DCL_OK;
   }
   if (!strcasecmp (argv[1], "KEYBOARD"))
   {
      xForeach (InputDevices, InputDevice)
         if (InputDevice->Identifier >= id)
            id = InputDevice->Identifier + 1;
      CreateInputDevice (InputDevice, "keyboard", id,
                            openKeyboard, closeKeyboard, getKeyboardEvent);
      xAddTail (InputDevices, InputDevice);
      sprintf (buf, "%d", id);
      Dcl_AppendResult (interp, buf, (char *) NULL);
      return DCL_OK;
   }
   if (!strcasecmp (argv[1], "TCPIP"))
   {
      if (argc == 3) {
         if (Dcl_GetInt (interp, argv[2], &portNumber) != DCL_OK)
            return DCL_ERROR;
      } else portNumber = GetGlobalOption ("tcpipDefaultPort");

      xForeach (InputDevices, InputDevice)
         if (InputDevice->Identifier >= id)
            id = InputDevice->Identifier + 1;
      sprintf (buf, "%d", portNumber);
      CreateInputDevice (InputDevice, buf, id,
                            openTcpip, closeTcpip, getTcpipEvent);
      InputDevice->Type = INPTYP_POLLING | INPTYP_ACTIVE;
      xAddTail (InputDevices, InputDevice);
      sprintf (buf, "%d", id);
      Dcl_AppendResult (interp, buf, (char *) NULL);
      return DCL_OK;
   }
   return DCL_OK;
}


int Dcl_AddImplication (ClientData clientData, Dcl_Interp *interp,
                        int argc, char **argv)
{
   int                    numberOfEntries, itemLength, value,
                          inputID, outputID, i, j, returnValue;
   char                 **translationTable, **item;
   struct OutputDevice   *OutputDevice;
   struct InputDevice    *InputDevice;
   struct Implication    *Implication;
   struct TranslateItem  *TranslateItem;

   if (argc < 3) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <output_id> <input_id> ?<table>?\"",
                                (char *) NULL);
      return DCL_ERROR;
   }
   if (Dcl_GetInt (interp, argv[1], &outputID) != DCL_OK)
        return DCL_ERROR;
   xForeach (OutputDevices, OutputDevice)
      if (OutputDevice->Identifier == outputID) break;
   if (!OutputDevice)
   {
      Dcl_AppendResult (interp, "no device found for specified output_id",
                                (char *) NULL);
      return DCL_ERROR;
   }
   if (Dcl_GetInt (interp, argv[2], &inputID) != DCL_OK)
        return DCL_ERROR;
   xForeach (InputDevices, InputDevice)
      if (InputDevice->Identifier == inputID) break;
   if (!InputDevice)
   {
      Dcl_AppendResult (interp, "no device found for specified input_id",
                                (char *) NULL);
      return DCL_ERROR;
   }

   if (argc < 4) {
      CreateImplication (Implication, outputID, IMPL_INDEPENDENT);
      xAddTail (InputDevice->Implications, Implication);
      return DCL_OK;
   }

   if (Dcl_SplitList(interp, argv[3], &numberOfEntries,
          &translationTable) != DCL_OK) return DCL_ERROR;

   returnValue = DCL_OK;

   CreateImplication (Implication, outputID, IMPL_INDEPENDENT);
   xAddTail (InputDevice->Implications, Implication);
   Implication->TranslationTable = xNewList (NULL);

   for (i = 0; i < numberOfEntries; i++)
   {
      if (Dcl_SplitList(interp, translationTable[i], &itemLength,
             &item) != DCL_OK) { returnValue = DCL_ERROR; break; }

      if (itemLength != 2)
      {
         Dcl_AppendResult (interp, "each field must have 2 entries:",
                                   " {<value|command> <ctrlchar>}",
                                   (char *) NULL);
         returnValue = DCL_ERROR;
      } else if (Dcl_GetInt (interp, item[0], &value) != DCL_OK)
             {
                Dcl_ResetResult (interp);
                CreateTranslateItem (TranslateItem, 0, item[1][0]);
                TranslateItem->Command = xSetText (item[0]);
                xAddTail (Implication->TranslationTable, TranslateItem);
             }
             else
             {
                CreateTranslateItem (TranslateItem, value, item[1][0]);
                xAddTail (Implication->TranslationTable, TranslateItem);
             }
      free ((char *) item);   // Dcl_Free ???
   }
   free ((char *) translationTable);   // Dcl_Free ???
   return returnValue;
}


int Dcl_AddProcessor (ClientData clientData, Dcl_Interp *interp,
                        int argc, char **argv)
{
   int                    outputID = -2, tdtDelay, eitDelay, inputID;
   struct OutputDevice   *OutputDevice;
   struct InputDevice    *InputDevice;
   struct Implication    *Implication;
   char                   buf[32];

   if (argc < 3) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <output_id> <type> ?<args>?\"",
                                (char *) NULL);
      return DCL_ERROR;
   }
   if (!strncasecmp (argv[1], "-all", 2)) outputID = -1;
   else if (!strncasecmp (argv[1], "-current", 2) && CurrentOutputDevice)
           outputID = CurrentOutputDevice->Identifier;
        else if (Dcl_GetInt (interp, argv[1], &outputID) != DCL_OK)
                return DCL_ERROR;

   xForeach (OutputDevices, OutputDevice)
      if (OutputDevice->Identifier == outputID) break;
   if (!OutputDevice && (outputID != -1))
   {
      Dcl_AppendResult (interp, "no device found for specified id",
                                (char *) NULL);
      return DCL_ERROR;
   }

   if ((strcasecmp (argv[2], "PFO")) &&
       (strcasecmp (argv[2], "TDT")) &&
       (strcasecmp (argv[2], "EIT")) &&
       (strcasecmp (argv[2], "VTX")))
   {
      Dcl_AppendResult (interp, "unsupported processor \"", argv[2],
                            "\".\nsupported processors are: PFO, ",
                            "TDT, EIT, VTX", (char *) NULL);
      return DCL_ERROR;
   }
   if (!strcasecmp (argv[2], "PFO"))
   {
      if (outputID == -1)
      {
         xForeach (OutputDevices, OutputDevice)
         {
            inputID = 0;
            xForeach (InputDevices, InputDevice)
               if (InputDevice->Identifier >= inputID)
                  inputID = InputDevice->Identifier + 1;
            sprintf (buf, "/dev/ost/demux%s", xName (OutputDevice));
            CreateInputDevice (InputDevice, buf, inputID,
                                  openPfo, closeSi, getPfoEvent);
            xAddTail (InputDevices, InputDevice);
            CreateImplication (Implication, OutputDevice->Identifier,
                                  IMPL_DEPENDENT | IMPL_PFO);
            xAddTail (InputDevice->Implications, Implication);
         }
      }
      else
      {
         xForeach (InputDevices, InputDevice)
            if (InputDevice->Identifier >= inputID)
               inputID = InputDevice->Identifier + 1;
         sprintf (buf, "/dev/ost/demux%s", xName (OutputDevice));
         CreateInputDevice (InputDevice, buf, inputID,
                               openPfo, closeSi, getPfoEvent);
         xAddTail (InputDevices, InputDevice);
         CreateImplication (Implication, outputID,
                               IMPL_DEPENDENT | IMPL_PFO);
         xAddTail (InputDevice->Implications, Implication);
      }
      return DCL_OK;
   }
   if (!strcasecmp (argv[2], "TDT"))
   {
      if (argc >= 4) {
         if (Dcl_GetInt (interp, argv[3], &tdtDelay) != DCL_OK)
            return DCL_ERROR;
      } else tdtDelay = GetGlobalOption ("tdtDefaultDelay");

      if (outputID == -1)
      {
         xForeach (OutputDevices, OutputDevice)
         {
            xForeach (InputDevices, InputDevice)
               if (InputDevice->Identifier >= inputID)
                  inputID = InputDevice->Identifier + 1;
            sprintf (buf, "/dev/ost/demux%s", xName (OutputDevice));
            CreateInputDevice (InputDevice, buf, inputID,
                                  openTdt, closeSi, getTdtEvent);
            xAddTail (InputDevices, InputDevice);
            InputDevice->Period = tdtDelay*10;
            CreateImplication (Implication, OutputDevice->Identifier,
               IMPL_DEPENDENT | IMPL_TDT | IMPL_PERIODIC);
            xAddTail (InputDevice->Implications, Implication);
         }
      }
      else
      {
         xForeach (InputDevices, InputDevice)
            if (InputDevice->Identifier >= inputID)
               inputID = InputDevice->Identifier + 1;
         sprintf (buf, "/dev/ost/demux%s", xName (OutputDevice));
         CreateInputDevice (InputDevice, buf, inputID,
                               openTdt, closeSi, getTdtEvent);
         xAddTail (InputDevices, InputDevice);
         InputDevice->Period = tdtDelay*10;
         CreateImplication (Implication, outputID,
            IMPL_DEPENDENT | IMPL_TDT | IMPL_PERIODIC);
         xAddTail (InputDevice->Implications, Implication);
      }
      return DCL_OK;
   }
   if (!strcasecmp (argv[2], "EIT"))
   {
      if (argc >= 4) {
         if (Dcl_GetInt (interp, argv[3], &eitDelay) != DCL_OK)
            return DCL_ERROR;
      } else eitDelay = GetGlobalOption ("eitAcquisitionDefaultDelay");

      if (outputID == -1)
      {
         xForeach (OutputDevices, OutputDevice)
         {
            xForeach (InputDevices, InputDevice)
               if (InputDevice->Identifier >= inputID)
                  inputID = InputDevice->Identifier + 1;
            sprintf (buf, "/dev/ost/demux%s", xName (OutputDevice));
            CreateInputDevice (InputDevice, buf, inputID,
                                  openEit, closeSi, getEitEvent);
            xAddTail (InputDevices, InputDevice);
            InputDevice->Period = eitDelay*10;
            CreateImplication (Implication, OutputDevice->Identifier,
               IMPL_DEPENDENT | IMPL_EIT | IMPL_PERIODIC);
            xAddTail (InputDevice->Implications, Implication);
         }
      }
      else
      {
         xForeach (InputDevices, InputDevice)
            if (InputDevice->Identifier >= inputID)
               inputID = InputDevice->Identifier + 1;
         sprintf (buf, "/dev/ost/demux%s", xName (OutputDevice));
         CreateInputDevice (InputDevice, buf, inputID,
                               openEit, closeSi, getEitEvent);
         xAddTail (InputDevices, InputDevice);
         InputDevice->Period = eitDelay*10;
         CreateImplication (Implication, outputID,
            IMPL_DEPENDENT | IMPL_EIT | IMPL_PERIODIC);
         xAddTail (InputDevice->Implications, Implication);
      }
      return DCL_OK;
   }
   if (!strcasecmp (argv[2], "VTX"))
   {
      if (outputID == -1)
      {
         xForeach (OutputDevices, OutputDevice)
         {
            xForeach (InputDevices, InputDevice)
               if (InputDevice->Identifier >= inputID)
                  inputID = InputDevice->Identifier + 1;
            sprintf (buf, "/dev/ost/demux%s", xName (OutputDevice));
            CreateInputDevice (InputDevice, buf, inputID,
                                  openVtx, closeVtx, getVtxEvent);
            xAddTail (InputDevices, InputDevice);
            CreateImplication (Implication, OutputDevice->Identifier,
                                  IMPL_DEPENDENT | IMPL_VTX);
            xAddTail (InputDevice->Implications, Implication);
         }
      }
      else
      {
         xForeach (InputDevices, InputDevice)
            if (InputDevice->Identifier >= inputID)
               inputID = InputDevice->Identifier + 1;
         sprintf (buf, "/dev/ost/demux%s", xName (OutputDevice));
         CreateInputDevice (InputDevice, buf, inputID,
                               openVtx, closeVtx, getVtxEvent);
         xAddTail (InputDevices, InputDevice);
         CreateImplication (Implication, outputID,
                               IMPL_DEPENDENT | IMPL_VTX);
         xAddTail (InputDevice->Implications, Implication);
      }
      return DCL_OK;
   }
   return DCL_OK;
}


int Dcl_SetOsdLanguage (ClientData clientData, Dcl_Interp *interp,
                        int argc, char **argv)
{
   int                    outputID = -2, osdLanguage = 0;
   struct OutputDevice   *OutputDevice;

   if (argc != 3) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <output_id> <language>\"",
                                (char *) NULL);
      return DCL_ERROR;
   }
   if (!strncasecmp (argv[1], "-all", 2)) outputID = -1;
   else if (!strncasecmp (argv[1], "-current", 2) && CurrentOutputDevice)
           outputID = CurrentOutputDevice->Identifier;
        else if (Dcl_GetInt (interp, argv[1], &outputID) != DCL_OK)
                return DCL_ERROR;

   xForeach (OutputDevices, OutputDevice)
      if (OutputDevice->Identifier == outputID) break;
   if (!OutputDevice && (outputID != -1))
   {
      Dcl_AppendResult (interp, "no device found for specified id",
                                (char *) NULL);
      return DCL_ERROR;
   }

   if ((strncasecmp (argv[2], "english", 2)) &&
       (strncasecmp (argv[2], "german", 2)))
   {
      Dcl_AppendResult (interp, "unsupported languages \"", argv[1],
                            "\".\nsupported languages are: ENGLISH, ",
                            "GERMAN", (char *) NULL);
      return DCL_ERROR;
   }
   if (!strncasecmp (argv[2], "english", 2)) osdLanguage = 0;
   if (!strncasecmp (argv[2], "german", 2)) osdLanguage = 1;

   if (outputID == -1)
   {
      xForeach (OutputDevices, OutputDevice)
         OutputDevice->osdLanguage = osdLanguage;
   }
   else OutputDevice->osdLanguage = osdLanguage;

   return DCL_OK;
}


int Dcl_SetOption (ClientData clientData, Dcl_Interp *interp,
                        int argc, char **argv)
{
   struct Option         *Option;
   char                   buf[32];

   if (argc < 2) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <option> ?<value>?\"", (char *) NULL);
      return DCL_ERROR;
   }
   if (!(Option = (struct Option *) xFindName (GlobalOptions, argv[1])))
   {
      Dcl_AppendResult (interp, "unknown option \"", argv[1],
                                "\"", (char *) NULL);
      return DCL_ERROR;
   }
   if (argc < 3) {
      sprintf (buf, "%d", Option->Value);
      Dcl_AppendResult (interp, buf, (char *) NULL);
      return DCL_OK;
   }
   return (Dcl_GetInt (interp, argv[2], &Option->Value));
}


int Dcl_Keypress (ClientData clientData, Dcl_Interp *interp,
                        int argc, char **argv)
{
   int                    outputID = -2, i, j;
   struct OutputDevice   *OutputDevice;
   char                   buf[32];

   if (argc < 3) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <output_id> <keypress>\"",
                                (char *) NULL);
      return DCL_ERROR;
   }
   if (!strncasecmp (argv[1], "-all", 2)) outputID = -1;
   else if (!strncasecmp (argv[1], "-current", 2) && CurrentOutputDevice)
           outputID = CurrentOutputDevice->Identifier;
        else if (Dcl_GetInt (interp, argv[1], &outputID) != DCL_OK)
                return DCL_ERROR;

   xForeach (OutputDevices, OutputDevice)
      if (OutputDevice->Identifier == outputID) break;
   if (!OutputDevice && (outputID != -1))
   {
      Dcl_AppendResult (interp, "no device found for specified id",
                                (char *) NULL);
      return DCL_ERROR;
   }
   for (i = 2; i < argc; i++)
   {
      for (j = 0; j < strlen (argv[i]); j++)
      {
         if (outputID == -1)
         {
            xForeach (OutputDevices, OutputDevice)
               processInputEvent (OutputDevice, (int) argv[i][j]);
         }
         else processInputEvent (OutputDevice, (int) argv[i][j]);
      }
   }
   return DCL_OK;
}


int Dcl_AddMenuItem (ClientData clientData, Dcl_Interp *interp,
                     int argc, char **argv)
{
   int                    outputID = -2, Position;
   struct OutputDevice   *OutputDevice;
   struct MenuItem       *Item, *NewItem;

   if (argc < 4) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <output_id> <type> <my_tag> ?<dest_tag>? ?<args>?\"",
                                (char *) NULL);
      return DCL_ERROR;
   }
   if (!strncasecmp (argv[1], "-all", 2)) outputID = -1;
   else if (!strncasecmp (argv[1], "-current", 2) && CurrentOutputDevice)
           outputID = CurrentOutputDevice->Identifier;
        else if (Dcl_GetInt (interp, argv[1], &outputID) != DCL_OK)
                return DCL_ERROR;

   xForeach (OutputDevices, OutputDevice)
      if (OutputDevice->Identifier == outputID) break;
   if (!OutputDevice && (outputID != -1))
   {
      Dcl_AppendResult (interp, "no device found for specified id",
                                (char *) NULL);
      return DCL_ERROR;
   }

   if ((strncasecmp (argv[2], "MENU", 2)) &&
       (strncasecmp (argv[2], "CMD", 2)))
   {
      Dcl_AppendResult (interp, "unsupported item type \"", argv[2],
                            "\".\nsupported types are: MENU, ",
                            "CMD", (char *) NULL);
      return DCL_ERROR;
   }
   if (!strncasecmp (argv[2], "MENU", 2))
   {
      if (argc == 4)
      {
         if (OutputDevice->UserMenu->Head)
         {
            Dcl_AppendResult (interp, "toplevel menu tag already defined",
                                 (char *) NULL);
            return DCL_ERROR;
         }
         else
         {
            if (outputID == -1)
            {
               xForeach (OutputDevices, OutputDevice)
               {
                  CreateMenuItem (NewItem, argv[3], MTYP_MENU, NULL);
                  NewItem->Menu = xNewList (NULL);
                  xAddTail (OutputDevice->UserMenu, NewItem);
               }
            }
            else
            {
               CreateMenuItem (NewItem, argv[3], MTYP_MENU, NULL);
               NewItem->Menu = xNewList (NULL);
               xAddTail (OutputDevice->UserMenu, NewItem);
            }
            return DCL_OK;
         }
      }
      if (argc > 5)
      {
         if (Dcl_GetInt (interp, argv[5], &Position) != DCL_OK)
              return DCL_ERROR;
      }
      else Position = 0;

      if (outputID == -1)
      {
         xForeach (OutputDevices, OutputDevice)
         {
            if (FindMenuItem (OutputDevice->UserMenu, argv[3]))
            {
               Dcl_AppendResult (interp, "menu tag \"", argv[3],
                                    "\" already defined", (char *) NULL);
               return DCL_ERROR;
            }
            if (!(Item = FindMenuItem (OutputDevice->UserMenu, argv[4])))
            {
               Dcl_AppendResult (interp, "destination menu tag \"", argv[4],
                                    "\" not found", (char *) NULL);
               return DCL_ERROR;
            }
            if (Item->Type != MTYP_MENU)
            {
               Dcl_AppendResult (interp, "destination \"", argv[4],
                                    "\" is no menu tag", (char *) NULL);
               return DCL_ERROR;
            }
            CreateMenuItem (NewItem, argv[3], MTYP_MENU, Item);
            NewItem->Menu = xNewList (NULL);
            if (Position == 0) xAddTail (Item->Menu, NewItem);
            else xAddHead (Item->Menu, NewItem);
         }
      }
      else
      {
         if (FindMenuItem (OutputDevice->UserMenu, argv[3]))
         {
            Dcl_AppendResult (interp, "menu tag \"", argv[3],
                                 "\" already defined", (char *) NULL);
            return DCL_ERROR;
         }
         if (!(Item = FindMenuItem (OutputDevice->UserMenu, argv[4])))
         {
            Dcl_AppendResult (interp, "destination menu tag \"", argv[4],
                                 "\" not found", (char *) NULL);
            return DCL_ERROR;
         }
         if (Item->Type != MTYP_MENU)
         {
            Dcl_AppendResult (interp, "destination \"", argv[4],
                                 "\" is no menu tag", (char *) NULL);
            return DCL_ERROR;
         }
         CreateMenuItem (NewItem, argv[3], MTYP_MENU, Item);
         NewItem->Menu = xNewList (NULL);
         if (Position == 0) xAddTail (Item->Menu, NewItem);
         else xAddHead (Item->Menu, NewItem);
      }
      return DCL_OK;
   }
   if (!strncasecmp (argv[2], "CMD", 2))
   {
      if (argc < 6)
      {
         Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                 " <output_id> CMD <my_tag> <dest_tag> <cmd> ?<pos>?\"",
                              (char *) NULL);
         return DCL_ERROR;
      }
      if (argc > 6)
      {
         if (Dcl_GetInt (interp, argv[6], &Position) != DCL_OK)
              return DCL_ERROR;
      }
      else Position = 0;

      if (outputID == -1)
      {
         xForeach (OutputDevices, OutputDevice)
         {
            if (FindMenuItem (OutputDevice->UserMenu, argv[3]))
            {
               Dcl_AppendResult (interp, "command tag \"", argv[3],
                                    "\" already defined", (char *) NULL);
               return DCL_ERROR;
            }
            if (!(Item = FindMenuItem (OutputDevice->UserMenu, argv[4])))
            {
               Dcl_AppendResult (interp, "destination menu tag \"", argv[4],
                                    "\" not found", (char *) NULL);
               return DCL_ERROR;
            }
            if (Item->Type != MTYP_MENU)
            {
               Dcl_AppendResult (interp, "destination \"", argv[4],
                                    "\" is no menu tag", (char *) NULL);
               return DCL_ERROR;
            }
            CreateMenuItem (NewItem, argv[3], MTYP_COMMAND, Item);
            NewItem->Command = xSetText (argv[5]);
            if (Position == 0) xAddTail (Item->Menu, NewItem);
            else xAddHead (Item->Menu, NewItem);
         }
      }
      else
      {
         if (FindMenuItem (OutputDevice->UserMenu, argv[3]))
         {
            Dcl_AppendResult (interp, "command tag \"", argv[3],
                                 "\" already defined", (char *) NULL);
            return DCL_ERROR;
         }
         if (!(Item = FindMenuItem (OutputDevice->UserMenu, argv[4])))
         {
            Dcl_AppendResult (interp, "destination menu tag \"", argv[4],
                                 "\" not found", (char *) NULL);
            return DCL_ERROR;
         }
         if (Item->Type != MTYP_MENU)
         {
            Dcl_AppendResult (interp, "destination \"", argv[4],
                                 "\" is no menu tag", (char *) NULL);
            return DCL_ERROR;
         }
         CreateMenuItem (NewItem, argv[3], MTYP_COMMAND, Item);
         NewItem->Command = xSetText (argv[5]);
         if (Position == 0) xAddTail (Item->Menu, NewItem);
         else xAddHead (Item->Menu, NewItem);
      }
      return DCL_OK;
   }
   return DCL_OK;
}


int Dcl_RemMenuItem (ClientData clientData, Dcl_Interp *interp,
                     int argc, char **argv)
{
   int                    outputID = -2;
   struct OutputDevice   *OutputDevice;
   struct MenuItem       *Item;

   if (argc < 3) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <output_id> <tag>\"", (char *) NULL);
      return DCL_ERROR;
   }
   if (!strncasecmp (argv[1], "-all", 2)) outputID = -1;
   else if (!strncasecmp (argv[1], "-current", 2) && CurrentOutputDevice)
           outputID = CurrentOutputDevice->Identifier;
        else if (Dcl_GetInt (interp, argv[1], &outputID) != DCL_OK)
                return DCL_ERROR;

   xForeach (OutputDevices, OutputDevice)
      if (OutputDevice->Identifier == outputID) break;
   if (!OutputDevice && (outputID != -1))
   {
      Dcl_AppendResult (interp, "no device found for specified id",
                                (char *) NULL);
      return DCL_ERROR;
   }

   if (outputID == -1)
   {
      xForeach (OutputDevices, OutputDevice)
      {
         if (!(Item = FindMenuItem (OutputDevice->UserMenu, argv[2])))
         {
            Dcl_AppendResult (interp, "tag to remove not found",
                                 (char *) NULL);
            return DCL_ERROR;
         }
         if (Item->UplevelMenu) xRemove (Item->UplevelMenu->Menu, Item);
         else xRemove (OutputDevice->UserMenu, Item);
         ClearMenuItem (Item);
      }
   }
   else
   {
      if (!(Item = FindMenuItem (OutputDevice->UserMenu, argv[2])))
      {
         Dcl_AppendResult (interp, "tag to remove not found",
                               (char *) NULL);
         return DCL_ERROR;
      }
      if (Item->UplevelMenu) xRemove (Item->UplevelMenu->Menu, Item);
      else xRemove (OutputDevice->UserMenu, Item);
      ClearMenuItem (Item);
   }
   return DCL_OK;
}


int Dcl_OutMessage (ClientData clientData, Dcl_Interp *interp,
                     int argc, char **argv)
{
   int                    outputID = -2, TextArg;
   char                   ColorCode, *buf;
   struct OutputDevice   *OutputDevice;

#define ImplicitOutputID OutputDevice->Identifier

   if ((argc != 3) && (argc != 5)) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <output_id> ?-color <color>? <text>\"",
                                (char *) NULL);
      return DCL_ERROR;
   }
   if (!strncasecmp (argv[1], "-all", 2)) outputID = -1;
   else if (!strncasecmp (argv[1], "-current", 2) && CurrentOutputDevice)
           outputID = CurrentOutputDevice->Identifier;
        else if (Dcl_GetInt (interp, argv[1], &outputID) != DCL_OK)
                return DCL_ERROR;

   xForeach (OutputDevices, OutputDevice)
      if (OutputDevice->Identifier == outputID) break;
   if (!OutputDevice && (outputID != -1))
   {
      Dcl_AppendResult (interp, "no device found for specified id",
                                (char *) NULL);
      return DCL_ERROR;
   }

   TextArg = 2; ColorCode = COL2ID (clrWhite);
   if (!strncasecmp (argv[2], "-color", 2))
   {
      TextArg = 4;
      if (!strncasecmp (argv[3], "black", 3))
         ColorCode = COL2ID (clrBlack);
      else if (!strncasecmp (argv[3], "red", 3))
         ColorCode = COL2ID (clrRed);
      else if (!strncasecmp (argv[3], "green", 3))
         ColorCode = COL2ID (clrGreen);
      else if (!strncasecmp (argv[3], "yellow", 3))
         ColorCode = COL2ID (clrYellow);
      else if (!strncasecmp (argv[3], "blue", 3))
         ColorCode = COL2ID (clrBlue);
      else if (!strncasecmp (argv[3], "magenta", 3))
         ColorCode = COL2ID (clrMagenta);
      else if (!strncasecmp (argv[3], "cyan", 3))
         ColorCode = COL2ID (clrCyan);
      else if (!strncasecmp (argv[3], "white", 3))
         ColorCode = COL2ID (clrWhite);
      else
      {
         Dcl_AppendResult (interp, "wrong color name, must be one of: ",
                                   "black, red, green, yellow, blue, magenta,",
                                   "cyan, white", (char *) NULL);
         return DCL_ERROR;
      }
   }
   xMemAlloc (strlen(argv[TextArg])+10, &buf);
   sprintf (buf, " \f%c%s\f%c\n", ColorCode, argv[TextArg], COL2ID (clrWhite));
   ScheduleDirectText (COMCODE_INFO_MESSAGE, buf);
   xMemFree (buf);
   
#undef ImplicitOutputID

   return DCL_OK;
}


int Dcl_OutText (ClientData clientData, Dcl_Interp *interp,
                     int argc, char **argv)
{
   int                    outputID = -2, TextArg;
   char                   ColorCode, *buf;
   struct OutputDevice   *OutputDevice;

#define ImplicitOutputID OutputDevice->Identifier

   if ((argc != 3) && (argc != 5)) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <output_id> ?-color <color>? <text>\"",
                                (char *) NULL);
      return DCL_ERROR;
   }
   if (!strncasecmp (argv[1], "-all", 2)) outputID = -1;
   else if (!strncasecmp (argv[1], "-current", 2) && CurrentOutputDevice)
           outputID = CurrentOutputDevice->Identifier;
        else if (Dcl_GetInt (interp, argv[1], &outputID) != DCL_OK)
                return DCL_ERROR;

   xForeach (OutputDevices, OutputDevice)
      if (OutputDevice->Identifier == outputID) break;
   if (!OutputDevice && (outputID != -1))
   {
      Dcl_AppendResult (interp, "no device found for specified id",
                                (char *) NULL);
      return DCL_ERROR;
   }

   TextArg = 2; ColorCode = COL2ID (clrWhite);
   if (!strncasecmp (argv[2], "-color", 2))
   {
      TextArg = 4;
      if (!strncasecmp (argv[3], "black", 3))
         ColorCode = COL2ID (clrBlack);
      else if (!strncasecmp (argv[3], "red", 3))
         ColorCode = COL2ID (clrRed);
      else if (!strncasecmp (argv[3], "green", 3))
         ColorCode = COL2ID (clrGreen);
      else if (!strncasecmp (argv[3], "yellow", 3))
         ColorCode = COL2ID (clrYellow);
      else if (!strncasecmp (argv[3], "blue", 3))
         ColorCode = COL2ID (clrBlue);
      else if (!strncasecmp (argv[3], "magenta", 3))
         ColorCode = COL2ID (clrMagenta);
      else if (!strncasecmp (argv[3], "cyan", 3))
         ColorCode = COL2ID (clrCyan);
      else if (!strncasecmp (argv[3], "white", 3))
         ColorCode = COL2ID (clrWhite);
      else
      {
         Dcl_AppendResult (interp, "wrong color name, must be one of: ",
                                   "black, red, green, yellow, blue, magenta,",
                                   "cyan, white", (char *) NULL);
         return DCL_ERROR;
      }
   }
   xMemAlloc (strlen(argv[TextArg])+10, &buf);
   sprintf (buf, " \f%c%s\f%c\n", ColorCode, argv[TextArg], COL2ID (clrWhite));
   ScheduleDirectText (COMCODE_INFO_TEXT, buf);
   xMemFree (buf);
   
#undef ImplicitOutputID

   return DCL_OK;
}


struct MenuItem *FindMenuItem (struct LIST *Menu, char *MenuTag)
{
   struct MenuItem     *MenuItem, *FoundItem;
   unsigned short       HashKey;

   if (!Menu || !MenuTag) return (NULL);

   HashKey = xHashKey (MenuTag);

   xForeach (Menu, MenuItem)
   {
      if (xName (MenuItem) && 
          (HashKey == MenuItem->Node.HashKey) &&
          !strcmp (xName (MenuItem), MenuTag))
         return (MenuItem);
      if ((MenuItem->Type == MTYP_MENU) &&
          (FoundItem = FindMenuItem (MenuItem->Menu, MenuTag)))
         return (FoundItem);
   }
   return (NULL);
}


void ClearMenuItem (struct MenuItem *Item)
{
   struct MenuItem     *MenuItem, *NextItem;

   if (!Item) return;

   if (Item->Type == MTYP_MENU)
   { MenuItem = (struct MenuItem *) Item->Menu->Head;
     do { NextItem = (struct MenuItem *) MenuItem->Node.Succ;
          ClearMenuItem (MenuItem); } while (MenuItem = NextItem);
          xMemFree (Item->Menu); xMemFree (Item); }
   else { xMemFree (Item->Command); xMemFree (Item); }

   return;
}
