//////////////////////////////////////////////////////////////
///                                                        ///
/// dvb_osd.c: OSD dependent functions of dtv              ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.3 $
// $Date: 2001/06/11 18:18:19 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#include <sys/ioctl.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <config.h>

#ifdef USE_DVB_0_8
#include <dvb/dvb.h>
#define OSD_SEND_CMD VIDIOCSOSDCOMMAND
static struct drawcmd dc;
#else
#include <ost/osd.h>
static osd_cmd_t dc;
#endif

#include "definitions.h"
#include "structures.h"
#include "prototypes.h"

static char result_text[4096];

static long int osdColors[clrLast] = {  0x00000000,    // clrTransparent
                                        0x000000FF,    // clrBlack
                                        0xFC1414FF,    // clrRed
                                        0x44FC44FF,    // clrGreen
                                        0xFCC024FF,    // clrYellow
                                        0x8080FFFF,    // clrBlue
                                        0xFF80FFFF,    // clrMagenta
                                        0x00FCFCFF,    // clrCyan
                                        0xFCFCFCFF,    // clrWhite
                                        0x0000007F};   // clrBackground

#include "dvb_font.c"

char *screenMsgs[MAX_SCREEN_MSGS][MAX_OSD_LANGUAGES] = {
   { "could not tune channel",
     "Kanal konnte nicht eingestellt werden" },
   { "(to be scanned)",
     "(wird noch gescanned)" },
   { "video-on-demand available",
     "Video-On-Demand whlbar" },
   { "service is radio",
     "Programm ist nicht anzeigbar !!" },
   { "repeated scan of channel info",
     "Erneutes Scannen der Kanal-Information" },
   { "multiple audio PIDs available",
     "Andere Sprach-Kanle whlbar !!" },
   { "Start",
     "Startzeit" },
   { "more channels available",
     "Weitere Kanle anwhlbar !!" },
   { "service not active",
     "Programm ist zur Zeit nicht aktiv !!" },
   { "no transponder defined",
     "Keine Transponderfrequenzen definiert !!" },
   { "scanning",
     "Suche auf" },
   { "basis channel",
     "ursprnglicher Kanal" },
   { "VTX receiption started",
     "Starte Videotext-Empfang" },
   { "no VTX available",
     "Kein Videotext verfgbar" }
};

int openOsdDevice (struct OutputDevice *OutputDevice)
{
   if (OutputDevice->osdDev < 0)
      return (-1);

   if (osdOpen (OutputDevice->osdDev, OSD_WINDOW_ORG_X, OSD_WINDOW_ORG_Y,
            OSD_WINDOW_WIDTH+OSD_WINDOW_ORG_X,
            OSD_WINDOW_HEIGHT+OSD_WINDOW_ORG_Y, 4, 0) < 0)
   { close (OutputDevice->osdDev); OutputDevice->osdDev = 0; return (-1); }
   osdHide (OutputDevice->osdDev);

   osdSetColor(OutputDevice->osdDev, clrTransparent, clrTransparent);
   osdSetColor(OutputDevice->osdDev, clrBlack, clrBlack);
   osdSetColor(OutputDevice->osdDev, clrRed, clrRed);
   osdSetColor(OutputDevice->osdDev, clrGreen, clrGreen);
   osdSetColor(OutputDevice->osdDev, clrYellow, clrYellow);
   osdSetColor(OutputDevice->osdDev, clrBlue, clrBlue);
   osdSetColor(OutputDevice->osdDev, clrMagenta, clrMagenta);
   osdSetColor(OutputDevice->osdDev, clrCyan, clrCyan);
   osdSetColor(OutputDevice->osdDev, clrWhite, clrWhite);
   osdSetColor(OutputDevice->osdDev, clrBackground, clrBackground);

   CreateOsdTerm(OutputDevice->OsdTerm, OutputDevice->osdDev,
                    clrWhite, clrBackground, OSD_TERMSCREEN_SIZE);
   osdTermClear (OutputDevice->OsdTerm);

   return (0);
}

void closeOsdDevice (struct OutputDevice *OutputDevice)
{
   if (!OutputDevice || !OutputDevice->osdDev)
      return;

   osdClose (OutputDevice->osdDev);
   if (OutputDevice->OsdTerm)
      xMemFree (OutputDevice->OsdTerm->Screen);
   xMemFree (OutputDevice->OsdTerm);
}


int osdClose(int osdDev)
{
   if (!osdDev) return (-1);

   dc.cmd=OSD_Close;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
} 


int osdOpen(int osdDev, int x0, int y0, int x1, int y1,
        int BitPerPixel, int mix) 
{
   if (!osdDev) return (-1);

   dc.cmd=OSD_Open;
   dc.x0=x0;
   dc.y0=y0;
   dc.x1=x1;
   dc.y1=y1;
   dc.color=BitPerPixel&0xf;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdShow(int osdDev) 
{
   if (!osdDev) return (-1);

   dc.cmd=OSD_Show;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdHide(int osdDev) 
{
   if (!osdDev) return (-1);

   dc.cmd=OSD_Hide;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdClear(int osdDev) 
{
   if (!osdDev) return (-1);

   dc.cmd=OSD_Fill;
   dc.color=clrTransparent;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdFill(int osdDev, int color) 
{
   if (!osdDev) return (-1);

   dc.cmd=OSD_Fill;
   dc.color=color;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdSetColor(int osdDev, int colno, int palno) 
{
   if (!osdDev) return (-1);

   dc.cmd=OSD_SetColor;
   dc.color=colno;
   dc.x0=(osdColors[palno] & 0xFF000000) >> 24;
   dc.y0=(osdColors[palno] & 0x00FF0000) >> 16;
   dc.x1=(osdColors[palno] & 0x0000FF00) >> 8;
   dc.y1=(osdColors[palno] & 0x000000FF);
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdText(int osdDev, int x, int y, int size, int color, char *text) 
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_Text;
   dc.x0=x;
   dc.y0=y;
   dc.x1=size; // fontsize (1, 2 or 3)
   dc.data=text;
   dc.color=color;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdSetPalette(int osdDev, int first, int last, unsigned char *data) 
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_SetPalette;
   dc.color=first;
   dc.x0=last;
   dc.data=data;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdSetTrans(int osdDev, int trans)
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_SetTrans;
   dc.color=trans;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdSetPixel(int osdDev, int x, int y, unsigned int color)
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_SetPixel;
   dc.x0=x;
   dc.y0=y;
   dc.color=color;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdGetPixel(int osdDev, int x, int y)
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_GetPixel;
   dc.x0=x;
   dc.y0=y;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdSetRow(int osdDev, int x, int y, int x1, unsigned char *data)
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_SetRow;
   dc.x0=x;
   dc.y0=y;
   dc.x1=x1;
   dc.data=data;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdSetBlock(int osdDev, int x, int y, int x1, int y1, int inc, 
      unsigned char *data)
{
   if (!osdDev) return (-1);

   dc.cmd=OSD_SetBlock;
   dc.x0=x;
   dc.y0=y;
   dc.x1=x1;
   dc.y1=y1;
   dc.color=inc;
   dc.data=data;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdFillRow(int osdDev, int x, int y, int x1, int color)
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_FillRow;
   dc.x0=x;
   dc.y0=y;
   dc.x1=x1;
   dc.color=color;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdFillBlock(int osdDev, int x, int y, int x1, int y1, int color)
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_FillBlock;
   dc.x0=x;
   dc.y0=y;
   dc.x1=x1;
   dc.y1=y1;
   dc.color=color;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdLine(int osdDev, int x, int y, int x1, int y1, int color)
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_Line;
   dc.x0=x;
   dc.y0=y;
   dc.x1=x1;
   dc.y1=y1;
   dc.color=color;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdQuery(int osdDev)
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_Query;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdSetWindow(int osdDev, int win)
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_SetWindow;
   dc.x0=win;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdMoveWindow(int osdDev, int x, int y)
{
   if (!osdDev) return (-1);
   
   dc.cmd=OSD_MoveWindow;
   dc.x0=x;
   dc.y0=y;
   usleep (1000);
   return ioctl(osdDev, OSD_SEND_CMD, &dc);
}

int osdTermClr (struct OsdTerm *OsdTerm, int start)
{
   int i;

   if (!OsdTerm) return (-1);

   if (!OsdTerm->Screen) return (-1);

   for (i = start; i < OSD_TERMSCREEN_SIZE; i++)
      OsdTerm->Screen[i] = OsdTerm->BgColor;

   return (0);
}

int osdFillTermBlock(struct OsdTerm *OsdTerm,
                     int x, int y, int x1, int y1, int color)
{
   int i, j, r;

   if (!OsdTerm) return (-1);

   if (!OsdTerm->Screen) return (-1);

   for (i = y; i < y1; i++)
      for (j = x; j < x1; j++)
         if ((r = i*OSD_WINDOW_WIDTH+j) < OSD_TERMSCREEN_SIZE)
            OsdTerm->Screen[r] = color;

   return (0);
}


long osdTermText (struct OsdTerm *OsdTerm, int x, int y, int font, int fgcol,
                  int bgcol, unsigned short dflag, char *text)
{
   int                lt, lx, ly, lfgcol, lbgcol, i, j;
   unsigned char     *ptr;
   unsigned long      Data, Mask;
   struct osdFont    *osdCurrentChar;

   if (!OsdTerm) return (-1);

   if ((text == NULL) ||
       (font < 0) || (font > 1))
      return (-1);

   if (x < 0) lx = OsdTerm->PosX; else lx = x;
   if (y < 0) ly = OsdTerm->PosY; else ly = y;
   if (fgcol < 0) lfgcol = OsdTerm->FgColor; else lfgcol = fgcol;
   if (bgcol < 0) lbgcol = OsdTerm->BgColor; else lbgcol = bgcol;
   lt = 0;

   ptr = (unsigned char *) text;

   while (*ptr)
   {
      if (*ptr == '\f') { lfgcol = ID2COL(*(++ptr)); ptr++; continue; }
      if (*ptr == '\b') { lbgcol = ID2COL(*(++ptr)); ptr++; continue; }
      if (((*ptr < 32) || (*ptr > 255)) &&
           (*ptr != '\n') && (*ptr != '\r') && (*ptr != '\t'))
         { ptr++; continue; }
      switch (font)
      {
         case 1:
            if (*ptr == '\r')
            { osdFillTermBlock (OsdTerm, lx, ly, OSD_WINDOW_WIDTH, 
                               (ly + ((struct osdFont *)
                               (osdFontFixed[0]))->Height), lbgcol);
              ly += ((struct osdFont *) (osdFontFixed[0]))->Height;
              lx = lt; ptr++; continue; }
            if (*ptr == '\n')
            { osdFillTermBlock (OsdTerm, lx, ly, OSD_WINDOW_WIDTH, 
                               (ly + ((struct osdFont *)
                               (osdFontFixed[0]))->Height), lbgcol);
              ly += ((struct osdFont *) (osdFontFixed[0]))->Height;
              lx = 0; lt = 0; ptr++; continue; }
            if (*ptr == '\t')
            { if (*(ptr+1) >= '0' && *(ptr+1) <= '9')
                 lt = (*(++ptr) - '0') * 40;
              else lt = ((lx/40)+1)*40;
              osdFillTermBlock (OsdTerm, lx, ly, lt,
                               (ly + ((struct osdFont *)
                               (osdFontFixed[0]))->Height), lbgcol);
              lx = lt; ptr++; continue; }
            osdCurrentChar = (struct osdFont *) (osdFontFixed[*ptr-32]);
         break;

         default:
            if (*ptr == '\r')
            { osdFillTermBlock (OsdTerm, lx, ly, OSD_WINDOW_WIDTH, 
                               (ly + ((struct osdFont *)
                               (osdFontProp[0]))->Height), lbgcol);
              ly += ((struct osdFont *) (osdFontProp[0]))->Height;
              lx = lt; ptr++; continue; }
            if (*ptr == '\n')
            { osdFillTermBlock (OsdTerm, lx, ly, OSD_WINDOW_WIDTH, 
                               (ly + ((struct osdFont *)
                               (osdFontProp[0]))->Height), lbgcol);
              ly += ((struct osdFont *) (osdFontProp[0]))->Height;
              lx = 0; lt = 0; ptr++; continue; }
            if (*ptr == '\t')
            { if (*(ptr+1) >= '0' && *(ptr+1) <= '9')
                 lt = (*(++ptr) - '0') * 40;
              else lt = ((lx/40)+1)*40;
              osdFillTermBlock (OsdTerm, lx, ly, lt,
                               (ly + ((struct osdFont *)
                               (osdFontProp[0]))->Height), lbgcol);
              lx = lt; ptr++; continue; }
            osdCurrentChar = (struct osdFont *) (osdFontProp[*ptr-32]);
         break;
      }
      if ((lx + osdCurrentChar->Width) >= OSD_WINDOW_WIDTH)
      {
         if (dflag & PRINT_NOWRAP) { ptr++; continue; }
         else { ly += osdCurrentChar->Height; lx = lt;
            if (lx) { osdFillTermBlock (OsdTerm, 0, ly, lx,
                               (ly + osdCurrentChar->Height), lbgcol); } }
      }
      if ((ly + osdCurrentChar->Height) >= OSD_WINDOW_HEIGHT)
         break;
      for (i = 0; i < osdCurrentChar->Height; i++)
      {
         Data = osdCurrentChar->Data[i];
         Mask = 1 << (osdCurrentChar->Width - 1);
         for (j = 0; j < osdCurrentChar->Width; j++)
         {
            if (Data & Mask)
               OsdTerm->Screen[lx+j+(ly+i)*OSD_WINDOW_WIDTH] = lfgcol;
            else OsdTerm->Screen[lx+j+(ly+i)*OSD_WINDOW_WIDTH] = lbgcol;
            Mask >>= 1;
         }
      }
      lx += osdCurrentChar->Width;
      ptr++;
   }
   if (dflag & PRINT_DIRECT)
   {
      int by = (y < 0) ? OsdTerm->PosY : y;
      int ey = ((((ly - by) + 7) / 8) * 8);

      if (ey > 0)
         osdSetBlock (OsdTerm->osdDev, 0, by, OSD_WINDOW_LAST_X, by+ey-1,
                       OSD_WINDOW_WIDTH, &OsdTerm->Screen[by*OSD_WINDOW_WIDTH]);
   }

   if ((x < 0) || (dflag & UPDATE_POS)) OsdTerm->PosX = lx;
   if ((y < 0) || (dflag & UPDATE_POS)) OsdTerm->PosY = ly;
   
   return (lx | (ly << 16));
}


int osdTermFlush (struct OsdTerm *OsdTerm)
{
   if (!OsdTerm) return (-1);

   osdSetBlock (OsdTerm->osdDev, 0, 0, OSD_WINDOW_LAST_X,
                OSD_WINDOW_LAST_Y, OSD_WINDOW_WIDTH, OsdTerm->Screen);
   return (0);
}


char *osdWrapText (int x, int y, int font, char *text)
{
   int                lt, lx, ly, i, j, len;
   unsigned char     *ptr, *res, *marker = NULL;
   unsigned long      Data, Mask;
   struct osdFont    *osdCurrentChar;

   if ((text == NULL) ||
       (font < 0) || (font > 1))
      return (NULL);

   if (x < 0) return (NULL); else lx = x;
   if (y < 0) return (NULL); else ly = y;
   lt = 0;

   ptr = (unsigned char *) text; len = 0;
   res = (unsigned char *) result_text;

   while (*ptr && (len++ < 4095))
   {
      if (*ptr == '\f') { *(res++) = *(ptr++); *(res++) = *(ptr++); continue; }
      if (*ptr == '\b') { *(res++) = *(ptr++); *(res++) = *(ptr++); continue; }
      if (((*ptr < 32) || (*ptr > 255)) &&
           (*ptr != '\n') && (*ptr != '\r') && (*ptr != '\t'))
         { *(res++) = *(ptr++); continue; }
      switch (font)
      {
         case 1:
            if (*ptr == '\r')
            { ly += ((struct osdFont *) (osdFontFixed[0]))->Height;
              lx = lt; *(res++) = *(ptr++); marker = NULL; continue; }
            if (*ptr == '\n')
            { ly += ((struct osdFont *) (osdFontFixed[0]))->Height;
              lx = 0; lt = 0; *(res++) = *(ptr++); marker = NULL; continue; }
            if (*ptr == '\t')
            { if (*(ptr+1) >= '0' && *(ptr+1) <= '9')
              { lt = (*(ptr+1) - '0') * 40; *(res++) = *(ptr++); }
              else lt = ((lx/40)+1)*40;
              lx = lt; *(res++) = *(ptr++); continue; }
            osdCurrentChar = (struct osdFont *) (osdFontFixed[*ptr-32]);
         break;

         default:
            if (*ptr == '\r')
            { ly += ((struct osdFont *) (osdFontProp[0]))->Height;
              lx = lt; *(res++) = *(ptr++); marker = NULL; continue; }
            if (*ptr == '\n')
            { ly += ((struct osdFont *) (osdFontProp[0]))->Height;
              lx = 0; lt = 0; *(res++) = *(ptr++); marker = NULL; continue; }
            if (*ptr == '\t')
            { if (*(ptr+1) >= '0' && *(ptr+1) <= '9')
              { lt = (*(ptr+1) - '0') * 40; *(res++) = *(ptr++); }
              else lt = ((lx/40)+1)*40;
              lx = lt; *(res++) = *(ptr++); continue; }
            osdCurrentChar = (struct osdFont *) (osdFontProp[*ptr-32]);
         break;
      }
      if (*ptr == ' ') marker = ptr;
      if ((lx + osdCurrentChar->Width) >= OSD_WINDOW_WIDTH)
      {
         ly += osdCurrentChar->Height; lx = lt;
         if (marker)
         {
            res -= (ptr - marker);
            *(res++) = '\r';
            ptr -= (ptr - marker);
            while (*ptr == ' ') ptr++;
            marker = NULL;
         }
      }
      if ((ly + osdCurrentChar->Height) >= OSD_WINDOW_HEIGHT)
      { *res = '\0'; return (result_text); }
      lx += osdCurrentChar->Width;
      *(res++) = *(ptr++);
   }
   *res = '\0';
   return (result_text);
}
