//////////////////////////////////////////////////////////////
///                                                        ///
/// dvb_si.h: local definitons for dvb_si.c                ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.1 $
// $Date: 2001/06/08 09:33:38 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

struct content_type {
   u_char   Nibble1;
   u_char   Nibble2;
   char    *Description;
};

static struct content_type ContentTypes[] = {
   /*   Movie/Drama: */
   { 0x01, 0x00, "movie/drama (general)" },
   { 0x01, 0x01, "detective/thriller" },
   { 0x01, 0x02, "adventure/western/war" },
   { 0x01, 0x03, "science fiction/fantasy/horror" },
   { 0x01, 0x04, "comedy" },
   { 0x01, 0x05, "soap/melodrama/folkloric" },
   { 0x01, 0x06, "romance" },
   { 0x01, 0x07, "serious/classical/religious/historical movie/drama" },
   { 0x01, 0x08, "adult movie/drama" },
   /*   News/Current affairs: */
   { 0x02, 0x00, "news/current affairs (general)" },
   { 0x02, 0x01, "news/weather report" },
   { 0x02, 0x02, "news magazine" },
   { 0x02, 0x03, "documentary" },
   { 0x02, 0x04, "discussion/interview/debate" },
   /*   Show/Game show: */
   { 0x03, 0x00, "show/game show (general)" },
   { 0x03, 0x01, "game show/quiz/contest" },
   { 0x03, 0x02, "variety show" },
   { 0x03, 0x03, "talk show" },
   /*   Sports: */
   { 0x04, 0x00, "sports (general)" },
   { 0x04, 0x01, "special events (Olympic Games, World Cup etc.)" },
   { 0x04, 0x02, "sports magazines" },
   { 0x04, 0x03, "football/soccer" },
   { 0x04, 0x04, "tennis/squash" },
   { 0x04, 0x05, "team sports (excluding football)" },
   { 0x04, 0x06, "athletics" },
   { 0x04, 0x07, "motor sport" },
   { 0x04, 0x08, "water sport" },
   { 0x04, 0x09, "winter sports" },
   { 0x04, 0x0A, "equestrian" },
   { 0x04, 0x0B, "martial sports" },
   /*   Children's/Youth programmes: */
   { 0x05, 0x00, "children's/youth programmes (general)" },
   { 0x05, 0x01, "pre-school children's programmes" },
   { 0x05, 0x02, "entertainment programmes for 6 to14" },
   { 0x05, 0x03, "entertainment programmes for 10 to 16" },
   { 0x05, 0x04, "informational/educational/school programmes" },
   { 0x05, 0x05, "cartoons/puppets" },
   /*   Music/Ballet/Dance: */
   { 0x06, 0x00, "music/ballet/dance (general)" },
   { 0x06, 0x01, "rock/pop" },
   { 0x06, 0x02, "serious music/classical music" },
   { 0x06, 0x03, "folk/traditional music" },
   { 0x06, 0x04, "jazz" },
   { 0x06, 0x05, "musical/opera" },
   { 0x06, 0x06, "ballet" },
   /*   Arts/Culture (without music): */
   { 0x07, 0x00, "arts/culture (without music, general)" },
   { 0x07, 0x01, "performing arts" },
   { 0x07, 0x02, "fine arts" },
   { 0x07, 0x03, "religion" },
   { 0x07, 0x04, "popular culture/traditional arts" },
   { 0x07, 0x05, "literature" },
   { 0x07, 0x06, "film/cinema" },
   { 0x07, 0x07, "experimental film/video" },
   { 0x07, 0x08, "broadcasting/press" },
   { 0x07, 0x09, "new media" },
   { 0x07, 0x0A, "arts/culture magazines" },
   { 0x07, 0x0B, "fashion" },
   /*   Social/Political issues/Economics: */
   { 0x08, 0x00, "social/political issues/economics (general)" },
   { 0x08, 0x01, "magazines/reports/documentary" },
   { 0x08, 0x02, "economics/social advisory" },
   { 0x08, 0x03, "remarkable people" },
   /*   Children's/Youth programmes: */
   /*   Education/ Science/Factual topics: */
   { 0x09, 0x00, "education/science/factual topics (general)" },
   { 0x09, 0x01, "nature/animals/environment" },
   { 0x09, 0x02, "technology/natural sciences" },
   { 0x09, 0x03, "medicine/physiology/psychology" },
   { 0x09, 0x04, "foreign countries/expeditions" },
   { 0x09, 0x05, "social/spiritual sciences" },
   { 0x09, 0x06, "further education" },
   { 0x09, 0x07, "languages" },
   /*   Leisure hobbies: */
   { 0x0A, 0x00, "leisure hobbies (general)" },
   { 0x0A, 0x01, "tourism/travel" },
   { 0x0A, 0x02, "handicraft" },
   { 0x0A, 0x03, "motoring" },
   { 0x0A, 0x04, "fitness & health" },
   { 0x0A, 0x05, "cooking" },
   { 0x0A, 0x06, "advertisement/shopping" },
   { 0x0A, 0x07, "gardening" },
   { 0x0B, 0x00, "original language" },
   { 0x0B, 0x01, "black & white" },
   { 0x0B, 0x02, "unpublished" },
   { 0x0B, 0x03, "live broadcast" }
};
#define CONTENT_TYPE_NUMBER 79

