//////////////////////////////////////////////////////////////
///                                                        ///
/// dvb_vtx.h: local definitons for dvb_vtx.c              ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.2 $
// $Date: 2001/06/12 18:02:27 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
/* This file is copied from Ralph Metzler's vbidecode package. */

#ifndef _DVB_VTX_H
#define _DVB_VTX_H

unsigned char invtab[256] = {
  0x00, 0x80, 0x40, 0xc0, 0x20, 0xa0, 0x60, 0xe0, 
  0x10, 0x90, 0x50, 0xd0, 0x30, 0xb0, 0x70, 0xf0, 
  0x08, 0x88, 0x48, 0xc8, 0x28, 0xa8, 0x68, 0xe8, 
  0x18, 0x98, 0x58, 0xd8, 0x38, 0xb8, 0x78, 0xf8, 
  0x04, 0x84, 0x44, 0xc4, 0x24, 0xa4, 0x64, 0xe4, 
  0x14, 0x94, 0x54, 0xd4, 0x34, 0xb4, 0x74, 0xf4, 
  0x0c, 0x8c, 0x4c, 0xcc, 0x2c, 0xac, 0x6c, 0xec, 
  0x1c, 0x9c, 0x5c, 0xdc, 0x3c, 0xbc, 0x7c, 0xfc, 
  0x02, 0x82, 0x42, 0xc2, 0x22, 0xa2, 0x62, 0xe2, 
  0x12, 0x92, 0x52, 0xd2, 0x32, 0xb2, 0x72, 0xf2, 
  0x0a, 0x8a, 0x4a, 0xca, 0x2a, 0xaa, 0x6a, 0xea, 
  0x1a, 0x9a, 0x5a, 0xda, 0x3a, 0xba, 0x7a, 0xfa, 
  0x06, 0x86, 0x46, 0xc6, 0x26, 0xa6, 0x66, 0xe6, 
  0x16, 0x96, 0x56, 0xd6, 0x36, 0xb6, 0x76, 0xf6, 
  0x0e, 0x8e, 0x4e, 0xce, 0x2e, 0xae, 0x6e, 0xee, 
  0x1e, 0x9e, 0x5e, 0xde, 0x3e, 0xbe, 0x7e, 0xfe, 
  0x01, 0x81, 0x41, 0xc1, 0x21, 0xa1, 0x61, 0xe1, 
  0x11, 0x91, 0x51, 0xd1, 0x31, 0xb1, 0x71, 0xf1, 
  0x09, 0x89, 0x49, 0xc9, 0x29, 0xa9, 0x69, 0xe9, 
  0x19, 0x99, 0x59, 0xd9, 0x39, 0xb9, 0x79, 0xf9, 
  0x05, 0x85, 0x45, 0xc5, 0x25, 0xa5, 0x65, 0xe5, 
  0x15, 0x95, 0x55, 0xd5, 0x35, 0xb5, 0x75, 0xf5, 
  0x0d, 0x8d, 0x4d, 0xcd, 0x2d, 0xad, 0x6d, 0xed, 
  0x1d, 0x9d, 0x5d, 0xdd, 0x3d, 0xbd, 0x7d, 0xfd, 
  0x03, 0x83, 0x43, 0xc3, 0x23, 0xa3, 0x63, 0xe3, 
  0x13, 0x93, 0x53, 0xd3, 0x33, 0xb3, 0x73, 0xf3, 
  0x0b, 0x8b, 0x4b, 0xcb, 0x2b, 0xab, 0x6b, 0xeb, 
  0x1b, 0x9b, 0x5b, 0xdb, 0x3b, 0xbb, 0x7b, 0xfb, 
  0x07, 0x87, 0x47, 0xc7, 0x27, 0xa7, 0x67, 0xe7, 
  0x17, 0x97, 0x57, 0xd7, 0x37, 0xb7, 0x77, 0xf7, 
  0x0f, 0x8f, 0x4f, 0xcf, 0x2f, 0xaf, 0x6f, 0xef, 
  0x1f, 0x9f, 0x5f, 0xdf, 0x3f, 0xbf, 0x7f, 0xff, 
};

unsigned char unhamtab[256] = {
  0x01, 0xff, 0x81, 0x01, 0xff, 0x00, 0x01, 0xff, 
  0xff, 0x02, 0x01, 0xff, 0x0a, 0xff, 0xff, 0x07, 
  0xff, 0x00, 0x01, 0xff, 0x00, 0x80, 0xff, 0x00, 
  0x06, 0xff, 0xff, 0x0b, 0xff, 0x00, 0x03, 0xff, 
  0xff, 0x0c, 0x01, 0xff, 0x04, 0xff, 0xff, 0x07, 
  0x06, 0xff, 0xff, 0x07, 0xff, 0x07, 0x07, 0x87, 
  0x06, 0xff, 0xff, 0x05, 0xff, 0x00, 0x0d, 0xff, 
  0x86, 0x06, 0x06, 0xff, 0x06, 0xff, 0xff, 0x07, 
  0xff, 0x02, 0x01, 0xff, 0x04, 0xff, 0xff, 0x09, 
  0x02, 0x82, 0xff, 0x02, 0xff, 0x02, 0x03, 0xff, 
  0x08, 0xff, 0xff, 0x05, 0xff, 0x00, 0x03, 0xff, 
  0xff, 0x02, 0x03, 0xff, 0x03, 0xff, 0x83, 0x03, 
  0x04, 0xff, 0xff, 0x05, 0x84, 0x04, 0x04, 0xff, 
  0xff, 0x02, 0x0f, 0xff, 0x04, 0xff, 0xff, 0x07, 
  0xff, 0x05, 0x05, 0x85, 0x04, 0xff, 0xff, 0x05, 
  0x06, 0xff, 0xff, 0x05, 0xff, 0x0e, 0x03, 0xff, 
  0xff, 0x0c, 0x01, 0xff, 0x0a, 0xff, 0xff, 0x09, 
  0x0a, 0xff, 0xff, 0x0b, 0x8a, 0x0a, 0x0a, 0xff, 
  0x08, 0xff, 0xff, 0x0b, 0xff, 0x00, 0x0d, 0xff, 
  0xff, 0x0b, 0x0b, 0x8b, 0x0a, 0xff, 0xff, 0x0b, 
  0x0c, 0x8c, 0xff, 0x0c, 0xff, 0x0c, 0x0d, 0xff, 
  0xff, 0x0c, 0x0f, 0xff, 0x0a, 0xff, 0xff, 0x07, 
  0xff, 0x0c, 0x0d, 0xff, 0x0d, 0xff, 0x8d, 0x0d, 
  0x06, 0xff, 0xff, 0x0b, 0xff, 0x0e, 0x0d, 0xff, 
  0x08, 0xff, 0xff, 0x09, 0xff, 0x09, 0x09, 0x89, 
  0xff, 0x02, 0x0f, 0xff, 0x0a, 0xff, 0xff, 0x09, 
  0x88, 0x08, 0x08, 0xff, 0x08, 0xff, 0xff, 0x09, 
  0x08, 0xff, 0xff, 0x0b, 0xff, 0x0e, 0x03, 0xff, 
  0xff, 0x0c, 0x0f, 0xff, 0x04, 0xff, 0xff, 0x09, 
  0x0f, 0xff, 0x8f, 0x0f, 0xff, 0x0e, 0x0f, 0xff, 
  0x08, 0xff, 0xff, 0x05, 0xff, 0x0e, 0x0d, 0xff, 
  0xff, 0x0e, 0x0f, 0xff, 0x0e, 0x8e, 0xff, 0x0e, 
};

// this table generates the parity checks for hamm24/18 decoding.
// bit 0 is for test A, 1 for B, ...
// thanks to R. Gancarz for this fine table *g*

static char hamm24par[3][256] =
{
    { // parities of first byte
	 0, 33, 34,  3, 35,  2,  1, 32, 36,  5,  6, 39,  7, 38, 37,  4,
	37,  4,  7, 38,  6, 39, 36,  5,  1, 32, 35,  2, 34,  3,  0, 33,
	38,  7,  4, 37,  5, 36, 39,  6,  2, 35, 32,  1, 33,  0,  3, 34,
	 3, 34, 33,  0, 32,  1,  2, 35, 39,  6,  5, 36,  4, 37, 38,  7,
	39,  6,  5, 36,  4, 37, 38,  7,  3, 34, 33,  0, 32,  1,  2, 35,
	 2, 35, 32,  1, 33,  0,  3, 34, 38,  7,  4, 37,  5, 36, 39,  6,
	 1, 32, 35,  2, 34,  3,  0, 33, 37,  4,  7, 38,  6, 39, 36,  5,
	36,  5,  6, 39,  7, 38, 37,  4,  0, 33, 34,  3, 35,  2,  1, 32,
	40,  9, 10, 43, 11, 42, 41,  8, 12, 45, 46, 15, 47, 14, 13, 44,
	13, 44, 47, 14, 46, 15, 12, 45, 41,  8, 11, 42, 10, 43, 40,  9,
	14, 47, 44, 13, 45, 12, 15, 46, 42, 11,  8, 41,  9, 40, 43, 10,
	43, 10,  9, 40,  8, 41, 42, 11, 15, 46, 45, 12, 44, 13, 14, 47,
	15, 46, 45, 12, 44, 13, 14, 47, 43, 10,  9, 40,  8, 41, 42, 11,
	42, 11,  8, 41,  9, 40, 43, 10, 14, 47, 44, 13, 45, 12, 15, 46,
	41,  8, 11, 42, 10, 43, 40,  9, 13, 44, 47, 14, 46, 15, 12, 45,
	12, 45, 46, 15, 47, 14, 13, 44, 40,  9, 10, 43, 11, 42, 41,  8
    }, { // parities of second byte
	 0, 41, 42,  3, 43,  2,  1, 40, 44,  5,  6, 47,  7, 46, 45,  4,
	45,  4,  7, 46,  6, 47, 44,  5,  1, 40, 43,  2, 42,  3,  0, 41,
	46,  7,  4, 45,  5, 44, 47,  6,  2, 43, 40,  1, 41,  0,  3, 42,
	 3, 42, 41,  0, 40,  1,  2, 43, 47,  6,  5, 44,  4, 45, 46,  7,
	47,  6,  5, 44,  4, 45, 46,  7,  3, 42, 41,  0, 40,  1,  2, 43,
	 2, 43, 40,  1, 41,  0,  3, 42, 46,  7,  4, 45,  5, 44, 47,  6,
	 1, 40, 43,  2, 42,  3,  0, 41, 45,  4,  7, 46,  6, 47, 44,  5,
	44,  5,  6, 47,  7, 46, 45,  4,  0, 41, 42,  3, 43,  2,  1, 40,
	48, 25, 26, 51, 27, 50, 49, 24, 28, 53, 54, 31, 55, 30, 29, 52,
	29, 52, 55, 30, 54, 31, 28, 53, 49, 24, 27, 50, 26, 51, 48, 25,
	30, 55, 52, 29, 53, 28, 31, 54, 50, 27, 24, 49, 25, 48, 51, 26,
	51, 26, 25, 48, 24, 49, 50, 27, 31, 54, 53, 28, 52, 29, 30, 55,
	31, 54, 53, 28, 52, 29, 30, 55, 51, 26, 25, 48, 24, 49, 50, 27,
	50, 27, 24, 49, 25, 48, 51, 26, 30, 55, 52, 29, 53, 28, 31, 54,
	49, 24, 27, 50, 26, 51, 48, 25, 29, 52, 55, 30, 54, 31, 28, 53,
	28, 53, 54, 31, 55, 30, 29, 52, 48, 25, 26, 51, 27, 50, 49, 24
    }, { // parities of third byte
	63, 14, 13, 60, 12, 61, 62, 15, 11, 58, 57,  8, 56,  9, 10, 59,
	10, 59, 56,  9, 57,  8, 11, 58, 62, 15, 12, 61, 13, 60, 63, 14,
	 9, 56, 59, 10, 58, 11,  8, 57, 61, 12, 15, 62, 14, 63, 60, 13,
	60, 13, 14, 63, 15, 62, 61, 12,  8, 57, 58, 11, 59, 10,  9, 56,
	 8, 57, 58, 11, 59, 10,  9, 56, 60, 13, 14, 63, 15, 62, 61, 12,
	61, 12, 15, 62, 14, 63, 60, 13,  9, 56, 59, 10, 58, 11,  8, 57,
	62, 15, 12, 61, 13, 60, 63, 14, 10, 59, 56,  9, 57,  8, 11, 58,
	11, 58, 57,  8, 56,  9, 10, 59, 63, 14, 13, 60, 12, 61, 62, 15,
	31, 46, 45, 28, 44, 29, 30, 47, 43, 26, 25, 40, 24, 41, 42, 27,
	42, 27, 24, 41, 25, 40, 43, 26, 30, 47, 44, 29, 45, 28, 31, 46,
	41, 24, 27, 42, 26, 43, 40, 25, 29, 44, 47, 30, 46, 31, 28, 45,
	28, 45, 46, 31, 47, 30, 29, 44, 40, 25, 26, 43, 27, 42, 41, 24,
	40, 25, 26, 43, 27, 42, 41, 24, 28, 45, 46, 31, 47, 30, 29, 44,
	29, 44, 47, 30, 46, 31, 28, 45, 41, 24, 27, 42, 26, 43, 40, 25,
	30, 47, 44, 29, 45, 28, 31, 46, 42, 27, 24, 41, 25, 40, 43, 26,
	43, 26, 25, 40, 24, 41, 42, 27, 31, 46, 45, 28, 44, 29, 30, 47
    }
};

// table to extract the lower 4 bit from hamm24/18 encoded bytes

static char hamm24val[256] =
{
      0,  0,  0,  0,  1,  1,  1,  1,  0,  0,  0,  0,  1,  1,  1,  1,
      2,  2,  2,  2,  3,  3,  3,  3,  2,  2,  2,  2,  3,  3,  3,  3,
      4,  4,  4,  4,  5,  5,  5,  5,  4,  4,  4,  4,  5,  5,  5,  5,
      6,  6,  6,  6,  7,  7,  7,  7,  6,  6,  6,  6,  7,  7,  7,  7,
      8,  8,  8,  8,  9,  9,  9,  9,  8,  8,  8,  8,  9,  9,  9,  9,
     10, 10, 10, 10, 11, 11, 11, 11, 10, 10, 10, 10, 11, 11, 11, 11,
     12, 12, 12, 12, 13, 13, 13, 13, 12, 12, 12, 12, 13, 13, 13, 13,
     14, 14, 14, 14, 15, 15, 15, 15, 14, 14, 14, 14, 15, 15, 15, 15,
      0,  0,  0,  0,  1,  1,  1,  1,  0,  0,  0,  0,  1,  1,  1,  1,
      2,  2,  2,  2,  3,  3,  3,  3,  2,  2,  2,  2,  3,  3,  3,  3,
      4,  4,  4,  4,  5,  5,  5,  5,  4,  4,  4,  4,  5,  5,  5,  5,
      6,  6,  6,  6,  7,  7,  7,  7,  6,  6,  6,  6,  7,  7,  7,  7,
      8,  8,  8,  8,  9,  9,  9,  9,  8,  8,  8,  8,  9,  9,  9,  9,
     10, 10, 10, 10, 11, 11, 11, 11, 10, 10, 10, 10, 11, 11, 11, 11,
     12, 12, 12, 12, 13, 13, 13, 13, 12, 12, 12, 12, 13, 13, 13, 13,
     14, 14, 14, 14, 15, 15, 15, 15, 14, 14, 14, 14, 15, 15, 15, 15
};



// mapping from parity checks made by table hamm24par to error
// results return by hamm24.
// (0 = no error, 0x0100 = single bit error, 0x1000 = double error)

static short hamm24err[64] =
{
    0x0000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000,
    0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000,
    0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000,
    0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000,
    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
    0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000, 0x1000,
};

// mapping from parity checks made by table hamm24par to faulty bit
// in the decoded 18 bit word.

static int hamm24cor[64] =
{
    0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000,
    0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000,
    0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000,
    0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000,
    0x00000, 0x00000, 0x00000, 0x00001, 0x00000, 0x00002, 0x00004, 0x00008,
    0x00000, 0x00010, 0x00020, 0x00040, 0x00080, 0x00100, 0x00200, 0x00400,
    0x00000, 0x00800, 0x01000, 0x02000, 0x04000, 0x08000, 0x10000, 0x20000,
    0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000, 0x00000,
};



static u_char lang_chars[1+8+8][16] =
{
    { 0, 0x23,0x24,0x40,0x5b,0x5c,0x5d,0x5e,0x5f,0x60,0x7b,0x7c,0x7d,0x7e },

    // for latin-1 font
    // English (100%)
    { 0,  '', '$', '@', '', '', '', '', '#', '', '', '', '', '' },
    // German (100%)
    { 0,  '#', '$', '', '', '', '', '^', '_', '', '', '', '', '' },
    // Swedish/Finnish/Hungarian (100%)
    { 0,  '#', '', '', '', '', '', '', '_', '', '', '', '', '' },
    // Italian (100%)
    { 0,  '', '$', '', '', '', '', '', '#', '', '', '', '', '' },
    // French (100%)
    { 0,  '', '', '', '', '', '', '', '#', '', '', '', '', '' },
    // Portuguese/Spanish (100%)
    { 0,  '', '$', '', '', '', '', '', '', '', '', '', '', '' },
    // Czech/Slovak (60%)
    { 0,  '#', 'u', 'c', 't', 'z', '', '', 'r', '', '', 'e', '', 's' },
    // reserved (English mapping)
    { 0,  '', '$', '@', '', '', '', '', '#', '', '', '', '', '' },

    // for latin-2 font
    // Polish (100%)
    { 0,  '#', '', '', '', '', '', '', '', '', '', '', '', '' },
    // German (100%)
    { 0,  '#', '$', '', '', '', '', '^', '_', '', '', '', '', '' },
    // Estonian (100%)
    { 0,  '#', '', '', '', '', '', '', '', '', '', '', '', '' },
    // Lettish/Lithuanian (90%)
    { 0,  '#', '$', '', '', '', '', '', '', '', '', 'u', '', 'i' },
    // French (90%)
    { 0,  '', 'i', 'a', '', '', 'u', '', '#', 'e', '', '', 'u', '' },
    // Serbian/Croation/Slovenian (100%)
    { 0,  '#', '', '', '', '', '', '', '', '', '', '', '', '' },
    // Czech/Slovak (100%)
    { 0,  '#', '', '', '', '', '', '', '', '', '', '', '', '' },
    // Rumanian (95%)
    { 0,  '#', '', '', '', '', '', '', 'i', '', '', '', '', '' },
};

static char *mylat = " !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~";


static struct mark { u_char *g0, *latin1, *latin2; } marks[16] =
{
    /* none */          { "#",
                          "",
                          "$"                                        },
    /* grave - ` */     { " aeiouAEIOU",
                          "`",
                          "`aeiouAEIOU"                                },
    /* acute - ' */     { " aceilnorsuyzACEILNORSUYZ",
                          "'clnrszCLNRSZ",
                          "'ݬ"                },
    /* cirumflex - ^ */ { " aeiouAEIOU",
                          "^",
                          "^euEU"                                },
    /* tilde - ~ */     { " anoANO",
                          "~",
                          "~anoANO"                                },
    /* ??? -  */       { "",
                          "",
                          ""                                        },
    /* breve - u */     { "aA",
                          "aA",
                          ""                                        },
    /* abovedot -  */  { "zZ",
                          "zZ",
                          ""                                        },
    /* diaeresis  */   { "aeiouAEIOU",
                          "",
                          "iI"                                },
    /* ??? - . */       { "",
                          "",
                          ""                                        },
    /* ringabove -  */ { " auAU",
                          "uU",
                          "aA"                                },
    /* cedilla -  */   { "cstCST",
                          "stST",
                          "Ǫ"                                },
    /* ??? - _ */       { " ",
                          "_",
                          "_"                                        },
    /* dbl acute - " */ { " ouOU",
                          "\"ouOU",
                          "\""                                },
    /* ogonek - \, */   { "aeAE",
                          "aeAE",
                          ""                                },
    /* caron - v */     { "cdelnrstzCDELNRSTZ",
                          "cdelnrstzCDELNRSTZ",
                          "̥ة"                        },
};

static u_char g2map_latin1[] =
   /*0123456789abcdef*/
    " $#'\"    "
    "׵'\""
    " `^~   ._\"  "
    "_            "
    " ЪH ILL TNn"
    "Kdhiill tn\x7f";

static u_char g2map_latin2[] =
   /*0123456789abcdef*/
    " icL$Y#'\"<    "
    "   u  '\">    "
    " `^~ ._"
    "- RC            "
    "  aH iLO opTNn"
    "K dhiilo ptn\x7f";

static int latin1 = 1;


#define font1_width 352
#define font1_height 120
static char font1_bits[] = {
 0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,
 0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,
 0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,
 0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,
 0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,
 0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,
 0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,
 0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,
 0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,
 0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,
 0x0f,0x80,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,
 0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0x80,0xff,0xff,0x00,0xf8,0x00,0xfc,
 0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,
 0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,
 0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
 0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xc1,0xff,0xff,0xff,0xff,
 0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,
 0x3f,0xfc,0xc1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,
 0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,
 0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,
 0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,
 0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,
 0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,
 0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,
 0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
 0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,
 0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,
 0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
 0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,
 0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0xc0,
 0x07,0x3e,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,
 0x0f,0x7c,0xe0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0xc0,0x07,
 0x3e,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,0x0f,
 0x7c,0xe0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0xc0,0x07,0x3e,
 0xf0,0x81,0x0f,0x7c,0xe0,0x03,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,0x0f,0x7c,
 0xe0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,
 0x81,0x0f,0x7c,0xe0,0x03,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,0x0f,0x7c,0xe0,
 0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,
 0x0f,0x7c,0xe0,0x03,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,0x0f,0x7c,0xe0,0x03,
 0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x80,0x33,0x00,0x00,0x07,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,
 0x83,0x33,0x00,0x80,0x0f,0x00,0xe0,0x03,0x03,0xf0,0xc0,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0xf8,0xc0,0x03,0x3e,0xf0,0x01,0x0c,0xff,0xe1,0xc3,
 0x7f,0xf8,0xc0,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0xc0,0x87,
 0x33,0xb0,0xe1,0x38,0x00,0x60,0x03,0x03,0x38,0x80,0x03,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0xce,0xe0,0x83,0xe3,0x1c,0x07,0x0f,0x07,0x60,0xc0,0x71,
 0x8e,0x73,0x1c,0x00,0x00,0x00,0x0c,0x00,0x38,0xc0,0x71,0x00,0xc0,0x03,0x12,
 0xbc,0xe7,0x30,0x87,0x61,0xc3,0x01,0x18,0x00,0x87,0x21,0x00,0x00,0x00,0x00,
 0x00,0x00,0x60,0x87,0xf3,0x03,0xe0,0x00,0x87,0x0f,0x07,0x38,0x00,0x70,0x8e,
 0x73,0x1c,0x1e,0xf0,0x00,0x07,0x7f,0x60,0xc0,0x71,0x00,0xc0,0x03,0x00,0xfc,
 0xe7,0x0f,0xc7,0xe1,0x0d,0x00,0x18,0x80,0x83,0x33,0xe0,0x00,0x00,0x00,0x00,
 0x00,0x70,0xb7,0x83,0x03,0x30,0xe0,0xe7,0x0c,0x7f,0xf8,0x03,0x70,0xfe,0xf3,
 0x1f,0x0c,0x60,0x80,0x03,0x7f,0xc0,0x01,0x18,0x00,0x80,0x01,0x00,0xb0,0x81,
 0x3f,0x70,0xf8,0x0f,0x00,0x18,0x80,0x43,0xff,0xfc,0x01,0x00,0xff,0x01,0x00,
 0x1c,0xf7,0x83,0x03,0x1c,0xe0,0xe1,0x3f,0xff,0xf9,0x0f,0x1c,0xf8,0xc0,0x1f,
 0x00,0x00,0xe0,0x00,0x00,0x80,0x03,0x0e,0x00,0xc0,0x03,0x00,0xb0,0x01,0x38,
 0x38,0xb8,0x03,0x00,0x18,0x80,0xc3,0xff,0xfc,0x01,0x00,0xff,0x01,0x00,0x0e,
 0xb7,0x83,0x03,0x0e,0x00,0xe7,0x3f,0xc0,0x39,0x0e,0x0e,0x8e,0x03,0x1c,0x00,
 0x00,0xe0,0x00,0x7f,0x00,0x03,0x1e,0x00,0x00,0x00,0x00,0xfc,0x67,0x38,0x1c,
 0x38,0x03,0x00,0x18,0x00,0x87,0x3b,0xe0,0x00,0x03,0x00,0x00,0x00,0x07,0x87,
 0x83,0x83,0x03,0x00,0x07,0x0c,0xc0,0x39,0x0e,0x07,0x8e,0x03,0x1c,0x0c,0x60,
 0x80,0x03,0x7f,0xc0,0x01,0x00,0x00,0x80,0x01,0x00,0xfc,0xe7,0x38,0xc7,0x39,
 0x03,0x00,0x38,0x80,0x83,0x21,0x60,0x80,0x07,0x00,0xc0,0xc0,0x01,0x8f,0x83,
 0x81,0xe3,0x1c,0x07,0x0c,0xc7,0x39,0x0e,0x0e,0x8e,0x03,0x1c,0x1e,0xf0,0x00,
 0x07,0x00,0x60,0x00,0x0c,0x00,0xc0,0x03,0x00,0xb0,0xc1,0x1f,0xc3,0xf1,0x0f,
 0x00,0x70,0xc0,0x00,0x00,0x00,0x00,0x07,0x00,0xe0,0xc1,0x00,0xfc,0xf0,0x87,
 0xff,0xfc,0x03,0x3f,0xff,0xf0,0x07,0x0f,0xfc,0xc1,0x07,0x00,0xe0,0x00,0x0c,
 0x00,0x38,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x80,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x01,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x01,0x00,0x00,0x80,
 0x83,0x3f,0xf0,0xe1,0x0f,0xff,0xf9,0x0f,0x1f,0x8e,0xc3,0x07,0xfc,0x3c,0xe7,
 0x87,0xc3,0x39,0x0e,0x1f,0xfe,0xc0,0x87,0x3f,0xf0,0xf1,0x3f,0xc7,0x1d,0xee,
 0x70,0x87,0x3b,0xdc,0xff,0xf0,0x01,0x00,0x7c,0x60,0x03,0x00,0xf8,0xc0,0x07,
 0xe6,0x30,0x87,0x0d,0xcc,0x61,0x0e,0x73,0x8e,0x83,0x01,0x30,0x30,0x87,0x81,
 0xe7,0x79,0xce,0x71,0x98,0x73,0x1c,0xe6,0x1c,0x77,0x3b,0xc7,0x1d,0xee,0x70,
 0x87,0x3b,0xdc,0xe1,0x30,0x60,0x00,0x30,0x38,0x0e,0x00,0x8e,0x63,0x0c,0xe6,
 0x1c,0x86,0x39,0x8c,0x61,0xcc,0x61,0x8e,0x83,0x03,0x30,0x30,0x87,0x81,0xff,
 0xf9,0xcf,0x71,0x98,0x73,0x1c,0xe6,0x1c,0x17,0x37,0xc7,0x1d,0xee,0x70,0xce,
 0x38,0x5c,0x30,0x30,0xe0,0x00,0x38,0x00,0x00,0x00,0xae,0x73,0x1c,0xfe,0x1c,
 0x80,0x39,0x6c,0x60,0xc3,0x01,0xfe,0x83,0x03,0x30,0xb0,0x81,0x81,0xff,0xf9,
 0xcf,0x71,0xf8,0x73,0x1c,0xee,0xf0,0x00,0x07,0xc7,0x1d,0xee,0x70,0x78,0x70,
 0x06,0x1c,0x30,0xe0,0x01,0x38,0x00,0x00,0x00,0xee,0xf3,0x1f,0x3e,0x1c,0x80,
 0x39,0x7c,0xe0,0xc3,0x7d,0xfe,0x83,0x03,0x30,0xf0,0x80,0x81,0xdb,0xb9,0xcf,
 0x71,0xf8,0x70,0x1c,0x3e,0xe0,0x01,0x07,0xc7,0x1d,0xee,0x76,0x30,0xc0,0x03,
 0x0e,0x30,0x80,0x07,0x38,0x00,0x00,0x00,0xee,0xf3,0x1f,0xe6,0x1c,0x80,0x39,
 0x2c,0x60,0xc1,0x7d,0x8e,0x83,0x83,0x33,0xf0,0x81,0x81,0xc3,0x39,0xce,0x71,
 0x18,0x70,0x1c,0xe6,0x00,0x07,0x07,0xc7,0x1d,0xee,0x76,0x78,0x80,0x81,0x03,
 0x30,0x00,0x0f,0x38,0x00,0x00,0x00,0xee,0x73,0x1c,0xe6,0x1c,0x86,0x39,0x8c,
 0x61,0xc0,0x71,0x8e,0x83,0x83,0x33,0x30,0x87,0xb1,0xc3,0x39,0xce,0x71,0x18,
 0x70,0x1d,0xe6,0x1c,0x07,0x07,0xc7,0x1d,0xee,0x7f,0xce,0x80,0xc3,0xc1,0x30,
 0x00,0x3e,0x38,0x00,0x00,0x00,0x0e,0x70,0x1c,0xe6,0x1c,0x87,0x39,0xcc,0x61,
 0xc0,0x71,0x8e,0x83,0x81,0x33,0x30,0x87,0xb9,0xc3,0x39,0xce,0x71,0x18,0x70,
 0x1f,0xe6,0x1c,0x07,0x03,0xc7,0xf9,0xc3,0x79,0x87,0x83,0xc1,0xe1,0x30,0x00,
 0x38,0x30,0x00,0x00,0x00,0xfc,0x70,0x9c,0x7f,0xf0,0xe3,0x0f,0xff,0xf9,0x01,
 0x6f,0x8e,0xc3,0x03,0x3f,0x3c,0xe7,0xbf,0xc3,0x39,0x8e,0x3f,0x7e,0xe0,0x8f,
 0xe7,0xf8,0x83,0x07,0xfe,0xe0,0xc1,0x19,0x87,0xc3,0xc3,0xff,0xf0,0x01,0x30,
 0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0xe0,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x00,
 0x80,0x07,0x00,0x00,0x0f,0x00,0xe0,0x03,0x00,0x1e,0xc0,0x03,0x30,0x3c,0x80,
 0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0xe0,0x81,0x07,0x0f,0xe0,0x0e,0x00,0x00,0x00,0x00,
 0x06,0x00,0x00,0x0c,0x00,0x60,0x03,0x00,0x18,0x80,0x03,0x30,0x30,0x00,0x07,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x70,0x00,0x07,0x38,0xb8,0xc3,0x7f,0x00,0xc0,0x01,0x06,
 0xe0,0x00,0x0c,0x38,0x60,0x02,0x66,0x98,0x00,0x00,0x08,0x30,0x06,0x07,0x00,
 0x98,0x01,0x0e,0x66,0x80,0x99,0x21,0xe0,0xa0,0x0f,0x00,0x00,0x00,0x00,0x01,
 0x03,0x00,0x8c,0xe0,0x00,0x07,0x1c,0x00,0xc0,0x7f,0x00,0xc0,0x07,0x3e,0xfc,
 0x87,0x0f,0xff,0xf9,0xc0,0x7f,0xf8,0xc3,0x03,0x3c,0x30,0x07,0x87,0xe7,0xf9,
 0xcf,0x7f,0xfe,0xf3,0x9f,0xff,0xfc,0xe7,0x0f,0x67,0x1c,0xee,0x70,0x87,0x73,
 0x9c,0xff,0x7c,0x00,0x07,0x78,0x00,0xc0,0x7f,0x00,0x80,0x06,0xe6,0x1c,0xe6,
 0x0c,0xc7,0xf9,0xc1,0x19,0xb8,0x83,0x03,0x30,0xb0,0x01,0x87,0xff,0x61,0xce,
 0x71,0x98,0x73,0x06,0xee,0x1c,0x06,0x03,0x67,0x1c,0xee,0x70,0xce,0x70,0x9c,
 0x31,0x3c,0x00,0x07,0x78,0x00,0xc0,0x7f,0x00,0xf0,0x07,0xe6,0x1c,0xe0,0x0c,
 0xff,0x61,0xc0,0x19,0x98,0x83,0x03,0x30,0xf0,0x00,0x87,0xdb,0x61,0xce,0x71,
 0x98,0x73,0x06,0xe6,0xf0,0x00,0x07,0x67,0x1c,0xee,0x76,0x78,0x70,0x1c,0x1c,
 0xe0,0x00,0x07,0x1c,0x00,0xc0,0x7f,0x00,0x70,0x06,0xe6,0x1c,0xe0,0x0c,0x07,
 0x60,0xc0,0x19,0x98,0x83,0x03,0x30,0xb0,0x01,0x87,0xdb,0x61,0xce,0x71,0x98,
 0x73,0x06,0x06,0xe0,0x01,0x07,0x67,0x1c,0xee,0x76,0x78,0x70,0x1c,0x0e,0xe0,
 0x00,0x07,0x38,0x00,0xc0,0x7f,0x00,0x70,0x06,0xe6,0x1c,0xe7,0x0c,0xc7,0x61,
 0xc0,0x19,0x98,0x83,0x01,0x30,0x30,0x07,0x83,0xdb,0x61,0xce,0x71,0x98,0x73,
 0x06,0x06,0x1c,0x87,0x33,0x67,0xf8,0xe3,0x7f,0xce,0x70,0x9c,0xe3,0x70,0x00,
 0x07,0x38,0x00,0xc0,0x7f,0x00,0xe0,0x1f,0x7e,0xf8,0xc7,0x3f,0xfe,0xf9,0x81,
 0x1f,0x9e,0xc3,0x03,0x30,0x3c,0x87,0x87,0xdb,0x61,0x8e,0x3f,0xf8,0xe1,0x87,
 0x1f,0xfc,0x07,0x3f,0xfe,0xe1,0xc1,0x39,0x87,0xe3,0x9f,0xff,0xe0,0x81,0x07,
 0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,
 0x00,0x00,0x80,0x33,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x06,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x19,0x00,
 0x00,0x80,0x33,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x06,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
 0x00,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x80,0x1f,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,
 0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,
 0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,
 0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,
 0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,
 0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,
 0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,
 0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,
 0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,
 0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,
 0x0f,0x80,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,
 0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0x80,0xff,0xff,0x00,0xf8,0x00,0xfc,
 0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,
 0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,
 0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
 0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xc1,0xff,0xff,0xff,0xff,
 0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,
 0x3f,0xfc,0xc1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,
 0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,
 0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,
 0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,
 0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,
 0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,
 0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,
 0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
 0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,
 0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,
 0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
 0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xe0,0x07,0x3f,0xf8,0xc1,0xff,
 0xff,0xff,0xff,0xff,0xff,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,
 0xfe,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,
 0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7e,0xf0,0x83,0x1f,0xfc,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xf0,
 0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xf0,0x87,
 0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xe0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xf0,0x87,0x3f,
 0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,
 0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,
 0x04,0x00,0x1e,0xe0,0x00,0x00,0x00,0x38,0x03,0x1f,0x00,0x00,0x00,0x1e,0x00,
 0x00,0x00,0x00,0x00,0xc0,0x7f,0x70,0x00,0x00,0x1e,0xfc,0x81,0x01,0x00,0x00,
 0x00,0x00,0x00,0xc3,0x00,0x1e,0x00,0xe0,0x00,0x07,0xf8,0x01,0x00,0x70,0xc4,
 0x03,0x1c,0xb0,0x01,0x80,0xc3,0x39,0xc3,0x71,0xf8,0xc0,0x07,0x38,0x00,0x80,
 0x07,0x00,0xe0,0x03,0x00,0xd8,0x00,0x80,0x3b,0xc0,0xe0,0x00,0x00,0xf8,0x0f,
 0x00,0x80,0xf3,0x80,0x3b,0x00,0xe0,0x00,0x07,0xc0,0x01,0x0f,0x20,0x84,0x83,
 0x7f,0x30,0x63,0x30,0x67,0x38,0x03,0x03,0xfe,0x70,0x1c,0x1f,0x00,0x80,0x0f,
 0x00,0x38,0x0e,0x00,0xd8,0x00,0x00,0x0c,0x60,0x00,0x00,0x00,0xdc,0x0e,0x00,
 0xc0,0xc0,0x80,0x31,0x00,0xe0,0x30,0x87,0xe1,0x0d,0x0e,0x77,0x05,0xc0,0xe1,
 0x3c,0xe0,0x3a,0x3c,0x38,0x03,0x1e,0xb7,0x33,0x9b,0x33,0x40,0xe0,0x1f,0x00,
 0x98,0x0c,0x00,0x70,0x80,0x03,0x03,0xcc,0x01,0x00,0x67,0xdc,0x0e,0x00,0x70,
 0xc0,0x80,0x1f,0x40,0xe0,0x38,0xc7,0xc9,0x0e,0x00,0xff,0xc7,0xc3,0x01,0xfc,
 0x80,0x8f,0xff,0x39,0xc3,0x31,0xff,0xb3,0x1b,0x1e,0x70,0x60,0x0b,0x00,0xd8,
 0x0d,0x00,0x00,0xf0,0x87,0x3b,0xfc,0x00,0x00,0x67,0xfc,0x0e,0x00,0x78,0xf0,
 0x01,0x0e,0xc0,0xe1,0x0c,0x67,0x38,0x03,0x0e,0x20,0x84,0xc1,0x01,0x30,0xe0,
 0xb8,0xff,0x39,0xc3,0x71,0x79,0xb3,0x98,0x11,0x3c,0x07,0x87,0xff,0x5b,0x0d,
 0x00,0x00,0xf0,0x87,0x1f,0x70,0x00,0x00,0x67,0xf8,0x0e,0x06,0x9e,0xf3,0x83,
 0x1d,0x9c,0x07,0x07,0x38,0xc0,0x01,0x07,0x70,0xc4,0xc3,0xc1,0x30,0xe0,0xb8,
 0xff,0x39,0xc3,0x71,0x87,0xb3,0x9b,0x1f,0xfc,0x07,0x87,0xff,0xdb,0x0d,0x00,
 0x00,0x80,0x01,0x00,0x00,0x00,0x00,0x67,0xc0,0x0e,0x0f,0xfe,0x03,0x80,0x1f,
 0xfc,0x87,0x33,0x1c,0xe0,0xcc,0x01,0x70,0xc4,0xc7,0xff,0x30,0xe0,0xb8,0xff,
 0x39,0x03,0x1f,0xff,0xb3,0x1b,0x00,0x3c,0x07,0x07,0x00,0x18,0x0d,0x00,0x00,
 0x80,0x01,0x00,0x00,0x00,0x00,0x7f,0xc0,0x0e,0x06,0xee,0x03,0x00,0x00,0x9c,
 0xe7,0x3c,0xc7,0x39,0xcf,0x71,0x20,0xc4,0x87,0x3e,0x3c,0x87,0x0f,0x18,0x38,
 0x03,0x1e,0xff,0x33,0x18,0x00,0x70,0x80,0x07,0x00,0x18,0x0c,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0xdf,0xc1,0x0e,0x00,0xf0,0x00,0x00,0x00,0xc0,0x61,
 0x3a,0xf3,0x9b,0xce,0x71,0xff,0xc7,0x03,0x1c,0xfc,0xe7,0x3a,0x3c,0x38,0xc3,
 0x71,0xfc,0xe0,0x0f,0x00,0x40,0x00,0x00,0x00,0xf0,0x07,0x00,0x00,0xf0,0x07,
 0x00,0x00,0x00,0x00,0x87,0xe1,0x0e,0x00,0x70,0x00,0x00,0x00,0x40,0x00,0x3f,
 0x90,0xc3,0x8f,0x3f,0x70,0x04,0x00,0x00,0x00,0x60,0x30,0x00,0x38,0x83,0x3f,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x80,0x03,0x00,0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,0x38,0x40,
 0x00,0x0e,0x00,0x70,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x00,0x00,0x00,0x00,0x00,0x38,0xf8,0x03,
 0x0e,0x00,0x70,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x60,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x38,0x80,0x07,0x1c,0x70,0xe7,0x38,0x7c,0x00,0x00,0x00,0x78,0x80,0x07,0x1c,
 0x1c,0x87,0x01,0x78,0xe0,0xc1,0x19,0x00,0xc0,0x1d,0x06,0x80,0x01,0x07,0xdc,
 0x39,0x0e,0x00,0x00,0xc3,0x00,0x30,0xf0,0xe1,0x38,0x38,0xf8,0x01,0x00,0xe0,
 0xc0,0x01,0x36,0xdc,0x01,0x00,0x6c,0x00,0x00,0x00,0x60,0x80,0x01,0x36,0x00,
 0x00,0x07,0x1c,0x38,0x03,0x00,0x00,0x70,0x07,0x1c,0xe0,0x80,0x0d,0x77,0x00,
 0x00,0x00,0x80,0x83,0x03,0x1c,0xb0,0x01,0x00,0x0c,0x60,0x00,0x00,0x30,0x00,
 0x03,0x1c,0x00,0x00,0x07,0x38,0xe0,0x0f,0x00,0xfe,0xf3,0x9f,0xff,0xfc,0x07,
 0x00,0x00,0x00,0x00,0x1f,0xf8,0x70,0x1c,0x3e,0xf0,0x81,0x0f,0x7c,0xe0,0x03,
 0x00,0xf8,0x70,0x9c,0xe3,0x1c,0xe7,0xb8,0xc3,0xe1,0x03,0x1f,0xf8,0xc0,0x07,
 0x3e,0xf0,0x81,0x0f,0x7c,0x60,0x03,0x1f,0x98,0xc3,0x1c,0xe6,0x30,0x87,0x0f,
 0x7c,0xe0,0x03,0x06,0xd8,0xf0,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x00,
 0xce,0x73,0x9c,0xe3,0x1c,0xe7,0xb8,0xc3,0x61,0x0e,0x1b,0x8c,0x61,0x0c,0x63,
 0x18,0xc3,0x18,0xc6,0x38,0x83,0x71,0x18,0xc3,0x18,0xc6,0x30,0x06,0x03,0x18,
 0xc0,0x00,0x0e,0x98,0xf3,0x9f,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0xce,0x71,0xce,
 0x73,0x9c,0xe3,0x1c,0xe7,0xb8,0xc3,0x61,0xce,0x71,0x8e,0x73,0x9c,0xe3,0x1c,
 0xe7,0x38,0xc7,0xf9,0xcf,0x61,0xd8,0xc0,0x06,0x36,0xb0,0x01,0x07,0x38,0xc0,
 0x01,0x0e,0x9e,0xf3,0x9f,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x1b,0xee,0x73,
 0x9c,0xe3,0x1c,0xe7,0x38,0x67,0xe0,0xcf,0x79,0xfe,0xf3,0x9f,0xff,0xfc,0xe7,
 0x3f,0xff,0xf9,0xcf,0x01,0xf8,0xc0,0x07,0x3e,0xf0,0x01,0x07,0x38,0xc0,0x01,
 0x0e,0xfe,0x73,0x9f,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x0e,0xae,0x73,0x9c,
 0xe3,0x1c,0xe7,0x38,0x3c,0xe0,0xc3,0x1f,0xfe,0xf3,0x9f,0xff,0xfc,0xe7,0x3f,
 0xff,0x39,0xc3,0x01,0x58,0xc0,0x02,0x16,0xb0,0x00,0x07,0x38,0xc0,0x01,0x0e,
 0xbe,0x73,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x0e,0xbe,0x73,0x9c,0xe3,
 0x1c,0xe7,0x38,0x18,0x60,0xc0,0x1d,0x8e,0x73,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,
 0x39,0xc3,0x61,0x18,0xc3,0x18,0xc6,0x30,0x06,0x07,0x38,0xc0,0x01,0x0e,0x98,
 0x73,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x1b,0xbe,0x73,0x9c,0xe3,0x1c,
 0xe7,0x38,0x38,0x60,0xc0,0x71,0x8e,0x73,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,
 0xc3,0x71,0x98,0xc3,0x1c,0xe6,0x30,0x07,0x03,0x18,0xc0,0x00,0x06,0x98,0x73,
 0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0xce,0x71,0x9e,0x73,0x9c,0xe3,0x1c,0xe7,
 0x38,0x18,0x60,0xc0,0x75,0x8e,0x73,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0x0f,
 0x3f,0xfe,0xf3,0x9f,0xff,0xfc,0x87,0x07,0x3c,0xe0,0x01,0x0f,0xf8,0x70,0x1c,
 0x7f,0xf8,0xc3,0x1f,0xfe,0xf0,0xc7,0x60,0xf8,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,
 0x3c,0xf8,0xc1,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0xc0,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,
 0x80,0x07,0x1c,0x00,0x00,0x00,0x38,0x00,0x00,0x00,0x18,0x00,0x06,0x1c,0x00,
 0xe0,0x00,0x60,0xc0,0x01,0x00,0x00,0x00,0x00,0x06,0xe0,0x01,0x07,0x00,0x00,
 0x00,0x00,0x00,0xc0,0x00,0x3c,0xe0,0x00,0x00,0x78,0x00,0x00,0x00,0x70,0xc0,
 0x01,0x3e,0x70,0xe7,0x0c,0x6c,0x00,0x00,0x00,0x70,0x80,0x03,0x3e,0x1c,0x87,
 0x01,0x38,0xe0,0xc3,0x19,0xf0,0xc0,0x1d,0x1c,0x70,0x80,0x0f,0xdc,0x39,0x0e,
 0x00,0x00,0x80,0x03,0x0e,0xf0,0xe1,0x0c,0x1c,0x00,0xc0,0x71,0xe0,0x40,0x00,
 0x22,0xcc,0x01,0x00,0x38,0x00,0x00,0x00,0x60,0x80,0x01,0x22,0x00,0x00,0x07,
 0x18,0x38,0x03,0x00,0xc0,0x70,0x07,0x18,0x10,0x80,0x08,0x73,0x00,0x00,0x00,
 0x00,0x03,0x03,0x06,0x9c,0x01,0x00,0x0c,0xf8,0x01,0x00,0x08,0x00,0x01,0x08,
 0x00,0x80,0x03,0x04,0x18,0x02,0x0e,0x00,0x00,0x00,0x08,0xe0,0x00,0x00,0x00,
 0x00,0x00,0x01,0xe0,0x03,0x00,0x00,0xc0,0x00,0x02,0x00,0xc0,0x01,0x0f,0xb0,
 0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x00,0x00,0xf8,0xc0,0x07,0x3e,0xf0,
 0x81,0x0f,0x7c,0xf8,0xcf,0x7f,0xfe,0xf3,0x9f,0xff,0xfc,0x87,0x07,0x3c,0xe0,
 0x01,0x0f,0xd8,0xf0,0x9f,0xff,0xfc,0xe7,0x3f,0xff,0xf9,0x0f,0x06,0xfe,0x70,
 0x86,0x33,0x9c,0xe1,0x0c,0xc7,0xe1,0xcf,0x71,0xd0,0x80,0x06,0x34,0xa0,0x01,
 0x0d,0x68,0xe0,0xcc,0x61,0x8e,0x73,0x9c,0xe3,0x1c,0x07,0x07,0x38,0xc0,0x01,
 0x0e,0xfe,0xc0,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0xce,0x1f,0xce,0x73,0x86,
 0x33,0x9c,0xe1,0x0c,0xc7,0x61,0xce,0x71,0xfe,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,
 0x7f,0xf8,0xcf,0x01,0xfe,0xf3,0x9f,0xff,0xfc,0x07,0x07,0x38,0xc0,0x01,0x0e,
 0xce,0xc0,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0xce,0x1f,0xee,0x73,0x86,0x33,
 0x9c,0xe1,0x0c,0xc7,0x61,0xce,0x71,0xce,0x70,0x86,0x33,0x9c,0xe1,0x0c,0x67,
 0xfc,0xc3,0x01,0x0e,0x70,0x80,0x03,0x1c,0x00,0x07,0x38,0xc0,0x01,0x0e,0xce,
 0xc0,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x06,0xbe,0x73,0x86,0x33,0x9c,
 0xe1,0x0c,0xc7,0x61,0xce,0x71,0xce,0x70,0x86,0x33,0x9c,0xe1,0x0c,0x67,0xdc,
 0xc1,0x71,0x8e,0x73,0x9c,0xe3,0x1c,0x07,0x03,0x18,0xc0,0x00,0x06,0xce,0xc0,
 0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x0f,0x9e,0x73,0x86,0x33,0x9c,0xe1,
 0x0c,0xc7,0x61,0xce,0x71,0xfc,0xe3,0x1f,0xff,0xf8,0xc7,0x3f,0xfe,0x79,0x8f,
 0x7f,0xfc,0xe3,0x1f,0xff,0xf8,0x87,0x07,0x3c,0xe0,0x01,0x0f,0xfc,0xc3,0x1c,
 0x7f,0xf8,0xc3,0x1f,0xfe,0xf0,0x07,0x00,0xf8,0xe1,0x1f,0xff,0xf8,0xc7,0x3f,
 0xfe,0xe1,0x87,0x7f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,
 0x61,0x00,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,
 0x00,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0xf8,0xc1,
 0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};
#define font2_width 352
#define font2_height 120
static char font2_bits[] = {
 0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,
 0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,
 0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,
 0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,
 0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,
 0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,
 0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,
 0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,
 0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,
 0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,
 0x0f,0x80,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,
 0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0x80,0xff,0xff,0x00,0xf8,0x00,0xfc,
 0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,
 0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,
 0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
 0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xc1,0xff,0xff,0xff,0xff,
 0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,
 0x3f,0xfc,0xc1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,
 0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,
 0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,
 0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,
 0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,
 0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,
 0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,
 0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
 0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,
 0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,
 0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
 0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,
 0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0xc0,
 0x07,0x3e,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,
 0x0f,0x7c,0xe0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0xc0,0x07,
 0x3e,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,0x0f,
 0x7c,0xe0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0xc0,0x07,0x3e,
 0xf0,0x81,0x0f,0x7c,0xe0,0x03,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,0x0f,0x7c,
 0xe0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,
 0x81,0x0f,0x7c,0xe0,0x03,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,0x0f,0x7c,0xe0,
 0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,
 0x0f,0x7c,0xe0,0x03,0x1f,0xf8,0xc0,0x07,0x3e,0xf0,0x81,0x0f,0x7c,0xe0,0x03,
 0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x80,0x33,0x00,0x00,0x07,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,
 0x83,0x33,0x00,0x80,0x0f,0x00,0xe0,0x03,0x03,0xf0,0xc0,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0xf8,0xc0,0x03,0x3e,0xf0,0x01,0x0c,0xff,0xe1,0xc3,
 0x7f,0xf8,0xc0,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0xc0,0x87,
 0x33,0xb0,0xe1,0x38,0x00,0x60,0x03,0x03,0x38,0x80,0x03,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0xce,0xe0,0x83,0xe3,0x1c,0x07,0x0f,0x07,0x60,0xc0,0x71,
 0x8e,0x73,0x1c,0x00,0x00,0x00,0x0c,0x00,0x38,0xc0,0x71,0x00,0xc0,0x03,0x12,
 0xbc,0xe7,0x30,0x87,0x61,0xc3,0x01,0x18,0x00,0x87,0x21,0x00,0x00,0x00,0x00,
 0x00,0x00,0x60,0x87,0xf3,0x03,0xe0,0x00,0x87,0x0f,0x07,0x38,0x00,0x70,0x8e,
 0x73,0x1c,0x1e,0xf0,0x00,0x07,0x7f,0x60,0xc0,0x71,0x00,0xc0,0x03,0x00,0xfc,
 0xe7,0x0f,0xc7,0xe1,0x0d,0x00,0x18,0x80,0x83,0x33,0xe0,0x00,0x00,0x00,0x00,
 0x00,0x70,0xb7,0x83,0x03,0x30,0xe0,0xe7,0x0c,0x7f,0xf8,0x03,0x70,0xfe,0xf3,
 0x1f,0x0c,0x60,0x80,0x03,0x7f,0xc0,0x01,0x18,0x00,0x80,0x01,0x00,0xb0,0x81,
 0x3f,0x70,0xf8,0x0f,0x00,0x18,0x80,0x43,0xff,0xfc,0x01,0x00,0xff,0x01,0x00,
 0x1c,0xf7,0x83,0x03,0x1c,0xe0,0xe1,0x3f,0xff,0xf9,0x0f,0x1c,0xf8,0xc0,0x1f,
 0x00,0x00,0xe0,0x00,0x00,0x80,0x03,0x0e,0x00,0xc0,0x03,0x00,0xb0,0x01,0x38,
 0x38,0xb8,0x03,0x00,0x18,0x80,0xc3,0xff,0xfc,0x01,0x00,0xff,0x01,0x00,0x0e,
 0xb7,0x83,0x03,0x0e,0x00,0xe7,0x3f,0xc0,0x39,0x0e,0x0e,0x8e,0x03,0x1c,0x00,
 0x00,0xe0,0x00,0x7f,0x00,0x03,0x1e,0x00,0x00,0x00,0x00,0xfc,0x67,0x38,0x1c,
 0x38,0x03,0x00,0x18,0x00,0x87,0x3b,0xe0,0x00,0x03,0x00,0x00,0x00,0x07,0x87,
 0x83,0x83,0x03,0x00,0x07,0x0c,0xc0,0x39,0x0e,0x07,0x8e,0x03,0x1c,0x0c,0x60,
 0x80,0x03,0x7f,0xc0,0x01,0x00,0x00,0x80,0x01,0x00,0xfc,0xe7,0x38,0xc7,0x39,
 0x03,0x00,0x38,0x80,0x83,0x21,0x60,0x80,0x07,0x00,0xc0,0xc0,0x01,0x8f,0x83,
 0x81,0xe3,0x1c,0x07,0x0c,0xc7,0x39,0x0e,0x0e,0x8e,0x03,0x1c,0x1e,0xf0,0x00,
 0x07,0x00,0x60,0x00,0x0c,0x00,0xc0,0x03,0x00,0xb0,0xc1,0x1f,0xc3,0xf1,0x0f,
 0x00,0x70,0xc0,0x00,0x00,0x00,0x00,0x07,0x00,0xe0,0xc1,0x00,0xfc,0xf0,0x87,
 0xff,0xfc,0x03,0x3f,0xff,0xf0,0x07,0x0f,0xfc,0xc1,0x07,0x00,0xe0,0x00,0x0c,
 0x00,0x38,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x80,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x01,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x01,0x00,0x00,0x80,
 0x83,0x3f,0xf0,0xe1,0x0f,0xff,0xf9,0x0f,0x1f,0x8e,0xc3,0x07,0xfc,0x3c,0xe7,
 0x87,0xc3,0x39,0x0e,0x1f,0xfe,0xc0,0x87,0x3f,0xf0,0xf1,0x3f,0xc7,0x1d,0xee,
 0x70,0x87,0x3b,0xdc,0xff,0xf0,0x01,0x00,0x7c,0x60,0x03,0x00,0xf8,0xc0,0x07,
 0xe6,0x30,0x87,0x0d,0xcc,0x61,0x0e,0x73,0x8e,0x83,0x01,0x30,0x30,0x87,0x81,
 0xe7,0x79,0xce,0x71,0x98,0x73,0x1c,0xe6,0x1c,0x77,0x3b,0xc7,0x1d,0xee,0x70,
 0x87,0x3b,0xdc,0xe1,0x30,0x60,0x00,0x30,0x38,0x0e,0x00,0x8e,0x63,0x0c,0xe6,
 0x1c,0x86,0x39,0x8c,0x61,0xcc,0x61,0x8e,0x83,0x03,0x30,0x30,0x87,0x81,0xff,
 0xf9,0xcf,0x71,0x98,0x73,0x1c,0xe6,0x1c,0x17,0x37,0xc7,0x1d,0xee,0x70,0xce,
 0x38,0x5c,0x30,0x30,0xe0,0x00,0x38,0x00,0x00,0x00,0xae,0x73,0x1c,0xfe,0x1c,
 0x80,0x39,0x6c,0x60,0xc3,0x01,0xfe,0x83,0x03,0x30,0xb0,0x81,0x81,0xff,0xf9,
 0xcf,0x71,0xf8,0x73,0x1c,0xee,0xf0,0x00,0x07,0xc7,0x1d,0xee,0x70,0x78,0x70,
 0x06,0x1c,0x30,0xe0,0x01,0x38,0x00,0x00,0x00,0xee,0xf3,0x1f,0x3e,0x1c,0x80,
 0x39,0x7c,0xe0,0xc3,0x7d,0xfe,0x83,0x03,0x30,0xf0,0x80,0x81,0xdb,0xb9,0xcf,
 0x71,0xf8,0x70,0x1c,0x3e,0xe0,0x01,0x07,0xc7,0x1d,0xee,0x76,0x30,0xc0,0x03,
 0x0e,0x30,0x80,0x07,0x38,0x00,0x00,0x00,0xee,0xf3,0x1f,0xe6,0x1c,0x80,0x39,
 0x2c,0x60,0xc1,0x7d,0x8e,0x83,0x83,0x33,0xf0,0x81,0x81,0xc3,0x39,0xce,0x71,
 0x18,0x70,0x1c,0xe6,0x00,0x07,0x07,0xc7,0x1d,0xee,0x76,0x78,0x80,0x81,0x03,
 0x30,0x00,0x0f,0x38,0x00,0x00,0x00,0xee,0x73,0x1c,0xe6,0x1c,0x86,0x39,0x8c,
 0x61,0xc0,0x71,0x8e,0x83,0x83,0x33,0x30,0x87,0xb1,0xc3,0x39,0xce,0x71,0x18,
 0x70,0x1d,0xe6,0x1c,0x07,0x07,0xc7,0x1d,0xee,0x7f,0xce,0x80,0xc3,0xc1,0x30,
 0x00,0x3e,0x38,0x00,0x00,0x00,0x0e,0x70,0x1c,0xe6,0x1c,0x87,0x39,0xcc,0x61,
 0xc0,0x71,0x8e,0x83,0x81,0x33,0x30,0x87,0xb9,0xc3,0x39,0xce,0x71,0x18,0x70,
 0x1f,0xe6,0x1c,0x07,0x03,0xc7,0xf9,0xc3,0x79,0x87,0x83,0xc1,0xe1,0x30,0x00,
 0x38,0x30,0x00,0x00,0x00,0xfc,0x70,0x9c,0x7f,0xf0,0xe3,0x0f,0xff,0xf9,0x01,
 0x6f,0x8e,0xc3,0x03,0x3f,0x3c,0xe7,0xbf,0xc3,0x39,0x8e,0x3f,0x7e,0xe0,0x8f,
 0xe7,0xf8,0x83,0x07,0xfe,0xe0,0xc1,0x19,0x87,0xc3,0xc3,0xff,0xf0,0x01,0x30,
 0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0xe0,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x00,
 0x80,0x07,0x00,0x00,0x0f,0x00,0xe0,0x03,0x00,0x1e,0xc0,0x03,0x30,0x3c,0x80,
 0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0xe0,0x81,0x07,0x0f,0xe0,0x0e,0x00,0x00,0x00,0x00,
 0x06,0x00,0x00,0x0c,0x00,0x60,0x03,0x00,0x18,0x80,0x03,0x30,0x30,0x00,0x07,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x70,0x00,0x07,0x38,0xb8,0xc3,0x7f,0x00,0xc0,0x01,0x06,
 0xe0,0x00,0x0c,0x38,0x60,0x02,0x66,0x98,0x00,0x00,0x08,0x30,0x06,0x07,0x00,
 0x98,0x01,0x0e,0x66,0x80,0x99,0x21,0xe0,0xa0,0x0f,0x00,0x00,0x00,0x00,0x01,
 0x03,0x00,0x8c,0xe0,0x00,0x07,0x1c,0x00,0xc0,0x7f,0x00,0xc0,0x07,0x3e,0xfc,
 0x87,0x0f,0xff,0xf9,0xc0,0x7f,0xf8,0xc3,0x03,0x3c,0x30,0x07,0x87,0xe7,0xf9,
 0xcf,0x7f,0xfe,0xf3,0x9f,0xff,0xfc,0xe7,0x0f,0x67,0x1c,0xee,0x70,0x87,0x73,
 0x9c,0xff,0x7c,0x00,0x07,0x78,0x00,0xc0,0x7f,0x00,0x80,0x06,0xe6,0x1c,0xe6,
 0x0c,0xc7,0xf9,0xc1,0x19,0xb8,0x83,0x03,0x30,0xb0,0x01,0x87,0xff,0x61,0xce,
 0x71,0x98,0x73,0x06,0xee,0x1c,0x06,0x03,0x67,0x1c,0xee,0x70,0xce,0x70,0x9c,
 0x31,0x3c,0x00,0x07,0x78,0x00,0xc0,0x7f,0x00,0xf0,0x07,0xe6,0x1c,0xe0,0x0c,
 0xff,0x61,0xc0,0x19,0x98,0x83,0x03,0x30,0xf0,0x00,0x87,0xdb,0x61,0xce,0x71,
 0x98,0x73,0x06,0xe6,0xf0,0x00,0x07,0x67,0x1c,0xee,0x76,0x78,0x70,0x1c,0x1c,
 0xe0,0x00,0x07,0x1c,0x00,0xc0,0x7f,0x00,0x70,0x06,0xe6,0x1c,0xe0,0x0c,0x07,
 0x60,0xc0,0x19,0x98,0x83,0x03,0x30,0xb0,0x01,0x87,0xdb,0x61,0xce,0x71,0x98,
 0x73,0x06,0x06,0xe0,0x01,0x07,0x67,0x1c,0xee,0x76,0x78,0x70,0x1c,0x0e,0xe0,
 0x00,0x07,0x38,0x00,0xc0,0x7f,0x00,0x70,0x06,0xe6,0x1c,0xe7,0x0c,0xc7,0x61,
 0xc0,0x19,0x98,0x83,0x01,0x30,0x30,0x07,0x83,0xdb,0x61,0xce,0x71,0x98,0x73,
 0x06,0x06,0x1c,0x87,0x33,0x67,0xf8,0xe3,0x7f,0xce,0x70,0x9c,0xe3,0x70,0x00,
 0x07,0x38,0x00,0xc0,0x7f,0x00,0xe0,0x1f,0x7e,0xf8,0xc7,0x3f,0xfe,0xf9,0x81,
 0x1f,0x9e,0xc3,0x03,0x30,0x3c,0x87,0x87,0xdb,0x61,0x8e,0x3f,0xf8,0xe1,0x87,
 0x1f,0xfc,0x07,0x3f,0xfe,0xe1,0xc1,0x39,0x87,0xe3,0x9f,0xff,0xe0,0x81,0x07,
 0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,
 0x00,0x00,0x80,0x33,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x06,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x19,0x00,
 0x00,0x80,0x33,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x06,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
 0x00,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0x80,0x1f,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,
 0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,
 0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,
 0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,
 0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,
 0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,
 0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,
 0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,
 0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,
 0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,
 0x0f,0x80,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,
 0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0x80,0xff,0xff,0x00,0xf8,0x00,0xfc,
 0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,
 0xc0,0xff,0xff,0x00,0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,
 0xf8,0x00,0xfc,0xff,0x0f,0x80,0x0f,0xc0,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
 0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xc1,0xff,0xff,0xff,0xff,
 0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,
 0x3f,0xfc,0xc1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,
 0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,
 0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,
 0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,
 0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,
 0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,
 0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,
 0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
 0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,
 0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,
 0xe0,0x03,0xf0,0x87,0x3f,0xfc,0xe1,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
 0x00,0x00,0x00,0xf0,0x81,0x0f,0x7c,0xe0,0x03,0xe0,0x07,0x3f,0xf8,0xc1,0xff,
 0xff,0xff,0xff,0xff,0xff,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,
 0xfe,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,
 0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7e,0xf0,0x83,0x1f,0xfc,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xf0,
 0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xf0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xf0,0x87,
 0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xe0,0x87,0x3f,0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xf0,0x87,0x3f,
 0xfc,0xe1,0x0f,0x7f,0xf8,0xc3,0x1f,0xfe,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 0xff,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x01,0x00,0x00,0x70,0x06,0x00,
 0x9c,0x01,0x06,0x00,0x38,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,
 0x00,0xc0,0x19,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,
 0x04,0x80,0x33,0x00,0x00,0x00,0x00,0xc0,0x00,0x1f,0x8e,0xc3,0x03,0x00,0xf0,
 0x00,0x03,0x00,0xe0,0x01,0x00,0x70,0x00,0x00,0x00,0x00,0x80,0x01,0x00,0x00,
 0x00,0x0f,0x00,0x03,0x00,0x00,0x00,0x0e,0x00,0xcc,0x01,0x00,0x00,0x70,0x84,
 0x03,0x1e,0xfc,0x00,0x00,0xdf,0xe1,0xc3,0x71,0x00,0xc0,0x07,0x3e,0xfe,0xf7,
 0x3f,0x00,0xfc,0xef,0x7f,0xd8,0x00,0x00,0x00,0xf0,0xe0,0x00,0xbc,0x03,0x03,
 0x06,0x80,0x03,0x00,0x00,0xe0,0x0e,0x0c,0x67,0x00,0x00,0x1e,0x20,0xc4,0x07,
 0x00,0x30,0x60,0x30,0xcc,0x39,0x0e,0x03,0x00,0x70,0x9c,0xe3,0x6e,0x77,0x38,
 0x00,0x1c,0xee,0x70,0xd8,0x00,0x00,0x00,0xe0,0x00,0x00,0xb8,0xc3,0x01,0x00,
 0xc0,0xc0,0x06,0x00,0x60,0x07,0x87,0x3b,0x38,0x03,0x0c,0x77,0x65,0x0c,0x00,
 0xb0,0xe0,0x3a,0x6c,0x38,0x0e,0x1e,0x00,0x70,0x9c,0xe3,0xe2,0x16,0x0c,0x00,
 0x04,0x23,0x18,0x70,0xc0,0x01,0x00,0xe0,0x01,0x00,0xd8,0x01,0x00,0x00,0x70,
 0x80,0x03,0x1c,0xf4,0x00,0x30,0x00,0xe0,0x09,0x60,0xff,0x77,0x1c,0x00,0xf0,
 0x80,0x0f,0x0c,0xe0,0xc1,0x71,0x00,0xc0,0x03,0x1e,0xe0,0x00,0x07,0x00,0xc0,
 0xc1,0x1e,0x00,0xc0,0x07,0x00,0xe0,0x00,0x00,0x38,0xf8,0x0f,0x00,0x78,0xf0,
 0x9f,0xff,0xfc,0xe1,0x3f,0x00,0xf8,0xcf,0x7f,0x20,0xf4,0x1f,0x00,0x70,0xe0,
 0x38,0x0c,0xc0,0xc3,0x71,0x00,0x80,0x07,0x3c,0xe0,0x80,0x83,0xff,0xe3,0xc0,
 0x1f,0x00,0x80,0x06,0x00,0x70,0x00,0x00,0x38,0x38,0x0c,0x00,0x9e,0x73,0x98,
 0xc3,0x60,0x60,0x0c,0x00,0x18,0xc3,0x18,0x70,0xf4,0x1f,0x00,0x3c,0xe0,0x38,
 0x0c,0x00,0xce,0x71,0x00,0x00,0x1c,0xe0,0xe0,0xe0,0x80,0xff,0x3b,0x80,0x01,
 0x00,0xf0,0x07,0x00,0xfc,0x00,0x00,0x38,0xe0,0x01,0x00,0xfe,0xc3,0x03,0x1e,
 0xe0,0x00,0x07,0x00,0xc0,0x01,0x0e,0x70,0x74,0x1c,0x00,0x3e,0xe6,0x38,0x8c,
 0x39,0x0e,0x1f,0x00,0x70,0x9c,0xe3,0xe0,0x70,0x30,0x00,0x1c,0xec,0x60,0x00,
 0x70,0x06,0x00,0xfc,0x00,0x00,0x38,0xc0,0x03,0x00,0xee,0x83,0x07,0x3c,0xe0,
 0x80,0x03,0x00,0xe0,0x00,0x07,0x20,0x74,0x1c,0x00,0x32,0x87,0x0f,0xcc,0x39,
 0x0e,0x1e,0x00,0x70,0x9c,0xe3,0x60,0x70,0x38,0x00,0x1c,0xee,0x70,0x00,0x70,
 0x06,0x00,0x60,0x00,0x00,0x18,0x38,0x0e,0x00,0xf0,0x70,0x9c,0xe3,0x70,0xe6,
 0x38,0x00,0x38,0xce,0x71,0xff,0x77,0x1c,0x00,0xfc,0xe7,0x3a,0xff,0xf1,0xc7,
 0x71,0x00,0xe0,0x0f,0x7f,0xf0,0xf0,0x3f,0x00,0xfc,0xef,0x7f,0x00,0xe0,0x1d,
 0x38,0xf0,0x00,0x00,0x3c,0xf8,0x0f,0x00,0x70,0xf0,0x9f,0x3f,0xe0,0xe7,0x3f,
 0x00,0xf8,0xcf,0x7f,0x70,0x04,0x06,0x00,0x00,0x60,0x30,0x00,0x00,0x80,0x3f,
 0x00,0x00,0x00,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x0e,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0xe0,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x70,0x04,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x3c,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x00,0x00,0x3e,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x70,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x70,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0xc0,0x00,0x1c,0x1c,0x1c,0xe7,0x38,0x78,0x00,0x03,0x00,0x98,0x83,0x07,0x00,
 0x1c,0x87,0x39,0x78,0xe0,0xc1,0x19,0x00,0x80,0x87,0x33,0x80,0x01,0x07,0xcc,
 0x39,0x0e,0x00,0xce,0x80,0x03,0x30,0x60,0xe7,0x38,0x38,0x00,0x00,0x00,0x70,
 0x00,0x06,0x36,0xf0,0x01,0x00,0x18,0xc0,0x01,0x00,0xf0,0x80,0x01,0x00,0x00,
 0x00,0x0f,0x1c,0x38,0x03,0x0f,0x00,0x80,0x01,0x1e,0xe0,0x80,0x0d,0x67,0x00,
 0x00,0x00,0x78,0xc0,0x06,0x1c,0xb0,0x01,0x00,0x0c,0x00,0x00,0x00,0xfe,0x00,
 0x00,0x1c,0x00,0x00,0x07,0x7f,0xe0,0x03,0x00,0xf0,0xf0,0x9f,0xff,0xfc,0xe7,
 0x3f,0x00,0x00,0xc0,0x0f,0xf8,0x70,0x9c,0xe3,0xf0,0x81,0x0f,0x7c,0xe0,0x03,
 0x00,0xfe,0x70,0x9d,0xe3,0x1c,0xe7,0xb8,0xc3,0xfd,0x0f,0x1f,0x98,0xc3,0x07,
 0x3e,0xf0,0x81,0x0f,0x0c,0x60,0x0e,0x1f,0x98,0xc3,0x1c,0xe6,0x30,0x87,0x39,
 0x7c,0xe0,0x03,0x1b,0xd8,0xf0,0x9c,0xe7,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x00,
 0x98,0x73,0x9c,0xe3,0x1c,0xe7,0xb8,0xc3,0xdd,0x0e,0x1b,0x98,0x63,0x0c,0x63,
 0x18,0xc3,0x18,0x0c,0x38,0x8c,0x71,0x0e,0xc3,0x18,0xc6,0x30,0x86,0x31,0x18,
 0xc0,0x00,0x73,0x98,0xf3,0x9f,0xff,0x1c,0xe7,0x38,0xc7,0x39,0xce,0x71,0x98,
 0x73,0x9c,0xe3,0x1c,0xe7,0xb8,0xc3,0xc5,0xcd,0x71,0xb8,0x73,0x9c,0xe3,0x1c,
 0xe7,0x38,0x0c,0x38,0xc0,0x61,0x0e,0xc0,0x06,0x36,0xb0,0x81,0x0d,0x38,0xc0,
 0x01,0x73,0x9e,0xf3,0x9f,0xff,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x1b,0xb8,0x73,
 0x9c,0xe3,0x1c,0xe7,0x38,0x67,0xc0,0xc1,0x79,0xf8,0xf0,0x9f,0xff,0xfc,0xe7,
 0x3f,0x0c,0x38,0xc0,0x01,0x0e,0xc0,0x07,0x3e,0xf0,0x81,0x0f,0x38,0xc0,0x01,
 0x73,0xfe,0x73,0x9f,0xfb,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x0e,0xf8,0x70,0x9c,
 0xe3,0x1c,0xe7,0x38,0x3c,0xc0,0xc1,0x1f,0x98,0xf3,0x9f,0xff,0xfc,0xe7,0x3f,
 0x0c,0x38,0xc0,0x01,0x0e,0xc0,0x02,0x16,0xb0,0x80,0x05,0x38,0xc0,0x01,0x73,
 0xbe,0x73,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x0e,0x98,0x73,0x9c,0xe3,
 0x1c,0xe7,0x38,0x18,0xc0,0xc1,0x1d,0x98,0x73,0x9c,0xe3,0x1c,0xe7,0x38,0x8c,
 0x39,0xcc,0x61,0x0e,0xc3,0x18,0xc6,0x30,0x86,0x31,0x38,0xc0,0x01,0x73,0x98,
 0x73,0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x1b,0x98,0x73,0x9c,0xe3,0x1c,
 0xe7,0x38,0x38,0xc0,0xc1,0x71,0x98,0x73,0x9c,0xe3,0x1c,0xe7,0x38,0xcc,0x39,
 0xce,0x71,0x8e,0xc3,0x1c,0xe6,0x30,0x87,0x39,0x18,0xc0,0x00,0x73,0x98,0x73,
 0x9c,0xe3,0x1c,0xe7,0x38,0xc7,0x39,0xce,0x71,0x98,0x73,0x9c,0xe3,0x1c,0xe7,
 0x38,0x18,0xc0,0xc0,0x75,0x9e,0x73,0x9c,0xe3,0x1c,0xe7,0x38,0xff,0xe1,0x07,
 0x3f,0xf8,0xf1,0x9f,0xff,0xfc,0xe7,0x3f,0x3c,0xe0,0xc1,0x1f,0xf8,0x70,0x9c,
 0xe3,0xf8,0xc3,0x1f,0xfe,0xf0,0xc7,0x60,0x9e,0xe3,0x0f,0x7f,0xf8,0xc3,0x1f,
 0x3c,0xe0,0xc1,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,
 0x00,0x00,0x00,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0xc3,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x00,
 0x00,0x00,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,
 0xc3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x80,0x07,0x1c,0x00,0x00,0x00,0x1c,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,
 0x00,0x00,0x60,0xc0,0xc1,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,
 0x00,0x00,0x00,0xc0,0x03,0x3c,0x00,0x00,0x00,0x78,0x00,0x00,0x1e,0x00,0xc0,
 0x01,0x3e,0x9c,0xe1,0x0c,0x00,0x00,0x03,0x00,0x00,0x80,0x03,0x00,0x1c,0x07,
 0x00,0x38,0xe0,0xc3,0x1d,0xf0,0x00,0x06,0x00,0x80,0x81,0x0f,0xcc,0x39,0x0e,
 0x00,0x00,0x60,0x06,0x0e,0x30,0xe7,0x0c,0x1c,0xc0,0x01,0x00,0x70,0x40,0x00,
 0x22,0xf0,0x00,0x00,0x3c,0xc0,0x01,0x00,0xce,0x80,0x01,0x00,0x00,0x80,0x39,
 0x18,0x38,0x03,0x1b,0xc0,0x80,0x03,0xe6,0xe0,0x80,0x08,0x67,0x00,0x00,0x00,
 0x98,0x43,0x02,0x06,0x9c,0x01,0x00,0x0c,0xc0,0x00,0x00,0x7a,0x00,0x01,0x08,
 0x00,0x80,0x03,0x38,0x00,0x00,0x0e,0x78,0x00,0x00,0x1c,0xe0,0x00,0x0f,0x00,
 0x00,0x00,0x18,0xe0,0x33,0x80,0x3c,0x00,0x00,0x02,0x18,0xc0,0x01,0x0f,0xf2,
 0x80,0x03,0x00,0x00,0x00,0x00,0x00,0xe8,0x03,0x00,0xee,0xc3,0x07,0x3e,0xf0,
 0x81,0x0f,0x38,0xf8,0xcf,0x7f,0xfe,0xf3,0x9f,0xff,0xfc,0xe7,0x3f,0x3c,0xe0,
 0x01,0x1f,0xd8,0xf0,0x9f,0xfb,0xfc,0xe7,0x3f,0xff,0xf9,0x0f,0x06,0xee,0x73,
 0x86,0x33,0x9c,0xe1,0x0c,0xc7,0xf9,0x03,0x00,0xb8,0x83,0x06,0x34,0xa0,0x01,
 0x0d,0x38,0x38,0xcc,0x61,0x0e,0x73,0x9c,0xe3,0x1c,0xe7,0x3a,0x38,0xc0,0xc1,
 0x19,0xfe,0xc0,0x1c,0xe6,0x1c,0xe7,0x38,0xc7,0x39,0xce,0x1f,0xb8,0x73,0x86,
 0x33,0x9c,0xe1,0x0c,0xc7,0xc1,0x00,0x00,0x98,0xf3,0x87,0x3f,0xfc,0xe1,0x0f,
 0x38,0x38,0xc0,0x01,0x0e,0xf0,0x9f,0xff,0xfc,0xe7,0x3f,0x38,0xc0,0xc1,0x19,
 0xce,0xc0,0x1c,0xe6,0x1c,0xe7,0x38,0xc7,0x39,0xce,0x1f,0x98,0x73,0x86,0x33,
 0x9c,0xe1,0x0c,0xc7,0xc1,0x01,0x00,0x18,0x70,0x86,0x33,0x9c,0xe1,0x0c,0x38,
 0x38,0xc0,0x01,0x0e,0x70,0x80,0x03,0x1c,0xe0,0x00,0x38,0xc0,0xc1,0x19,0xce,
 0xc0,0x1c,0xe6,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x06,0x18,0x70,0x86,0x33,0x9c,
 0xe1,0x0c,0xc7,0xc1,0x01,0x00,0x18,0x70,0x86,0x33,0x9c,0xe1,0x0c,0x18,0x38,
 0xce,0x71,0x8e,0x73,0x9c,0xe3,0x1c,0xe7,0x38,0x18,0xc0,0xc0,0x19,0xce,0xc0,
 0x1c,0xe6,0x1c,0xe7,0x38,0xc7,0x39,0x0e,0x0f,0x18,0x70,0x86,0x33,0x9c,0xe1,
 0x0c,0xc7,0xe1,0x0c,0x00,0x7e,0xe0,0x1f,0xff,0xf8,0xc7,0x3f,0x3c,0xf0,0x8f,
 0x7f,0xfc,0xe3,0x1f,0xff,0xf8,0xc7,0x3f,0x3c,0xe0,0x81,0x7f,0xfc,0xc3,0x1c,
 0xe6,0xf8,0xc3,0x1f,0xfe,0xf0,0x07,0x00,0x7e,0xe0,0x1f,0xff,0xf8,0xc7,0x3f,
 0xfe,0xc1,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,
 0x00,0x00,0x00,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc0,
 0x01,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x00,
 0x00,0x00,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0xe0,
 0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};

#define font_width	font1_width
#define font_height	font1_height
#define CW		(font_width/32)        /* pixel width of a character */
#define CH		(font_height/8)        /* pixel height of a character */
#define WW	(W*CW)			/* pixel width of window */
#define WH	(H*CH)			/* pixel hegiht of window */

#endif
