//////////////////////////////////////////////////////////////
///                                                        ///
/// prototypes.h: prototypes for non-static functions      ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.9 $
// $Date: 2001/06/14 17:03:51 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#include <stdio.h>
#include <time.h>

#include <liblx.h>
#include <libsi.h>
#include <dcl.h>


/* dtv.c */

extern int logLevel;
extern FILE *logFile;

int main (int, char **);
void safeExit (int);

/* dtv.c */

extern struct LIST *AvailableSatellites;
extern struct LIST *AvailableChannels;
extern struct LIST *OutputDevices;
extern struct LIST *InputDevices;
extern struct LIST *CommandQueue;
extern struct LIST *GlobalOptions;

extern struct MEM_CHUNK *AvChRemember;
extern struct MEM_CHUNK *AvSatRemember;
extern struct MEM_CHUNK *AvTpRemember;
extern struct MEM_CHUNK *CommandRemember;

extern struct Option *statOption;

extern Dcl_Interp *interp;

int initConfiguration (char *);
int Dtv_Init (Dcl_Interp *);
int Dcl_DefineAvailableSatellites (ClientData, Dcl_Interp *, int, char **);
int Dcl_DumpAvailableSatellites (ClientData, Dcl_Interp *, int, char **);
int Dcl_DefineAvailableChannels (ClientData, Dcl_Interp *, int, char **);
int Dcl_DumpAvailableChannels (ClientData, Dcl_Interp *, int, char **);
int Dcl_OpenOutput (ClientData, Dcl_Interp *, int, char **);
int Dcl_AddChannelList (ClientData, Dcl_Interp *, int, char **);
int Dcl_OpenInput (ClientData, Dcl_Interp *, int, char **);
int Dcl_AddImplication (ClientData, Dcl_Interp *, int, char **);
int Dcl_AddProcessor (ClientData, Dcl_Interp *, int, char **);
int Dcl_SetOsdLanguage (ClientData, Dcl_Interp *, int, char **);
int Dcl_SetOption (ClientData, Dcl_Interp *, int, char **);
int Dcl_Keypress (ClientData, Dcl_Interp *, int, char **);
int Dcl_AddMenuItem (ClientData, Dcl_Interp *, int, char **);
int Dcl_RemMenuItem (ClientData, Dcl_Interp *, int, char **);
int Dcl_OutMessage (ClientData, Dcl_Interp *, int, char **);
int Dcl_OutText (ClientData, Dcl_Interp *, int, char **);
struct MenuItem *FindMenuItem (struct LIST *, char *);
void ClearMenuItem (struct MenuItem *);


/* scheduler.c */

int execScheduler (void);
int collectInputEvents (void);
int openInputDevices (void);
int closeOutputDevices (void);
int closeInputDevices (void);
int processCommands (void);

/* database.c */

int initDatabase (void);
char *getPresentFollowingInfo (struct Channel *);
char *getExtendedInfo (struct Channel *);
char *getChannelMenu (struct Channel *);
char *getUserMenu (struct OutputDevice *);
struct Channel *getChannelFromNvodItem (struct NvodReferenceItem *, struct Channel *);
struct Channel *getChannelFromLinkageDescriptor (struct Descriptor *, struct Channel *);
int closeDatabase (void);

/* debug.c */

void debugChannels (char *);
void debugProgramInfoList (FILE *, char *, struct LIST *);
void debugUserMenu (FILE *, char *, struct LIST *);
void logPrintf(int, char *, ...);

/* input.c */

int openKeyboard(struct InputDevice *);
void closeKeyboard(struct InputDevice *);
int getKeyboardEvent (struct InputDevice *);
int openRemote(struct InputDevice *);
void closeRemote(struct InputDevice *);
int getRemoteEvent (struct InputDevice *);
int openLircd(struct InputDevice *);
void closeLircd(struct InputDevice *);
int getLircdEvent (struct InputDevice *);
int openTcpip(struct InputDevice *);
void closeTcpip(struct InputDevice *);
int getTcpipEvent (struct InputDevice *);
int getTcpipClientEvent (struct InputDevice *);
int processInputEvent (struct OutputDevice *, int);

/* dvb_si.c */

int openPfo(struct InputDevice *);
int openEit(struct InputDevice *);
int openTdt(struct InputDevice *);
void closeSi(struct InputDevice *);
int getPfoEvent (struct InputDevice *);
int getEitEvent (struct InputDevice *);
int parseEventList (struct InputDevice *);
int getTdtEvent (struct InputDevice *);

/* dvb_vtx.c */

int openVtx(struct InputDevice *);
void closeVtx(struct InputDevice *);
int getVtxEvent (struct InputDevice *);
void vtxParse (struct OutputDevice *, u_char *);
unsigned char unham8 (unsigned char *);
unsigned char unham16 (unsigned char *);
int unham24 (unsigned char *);
void lang_init (void);
void conv2latin (u_char *, int, int);
void init_enhance (struct VtxPage *);
void add_enhance (struct VtxPage *, int, u_int *);
void enhance (struct VtxPage *);
void fmt_page(struct VtxPage *);
unsigned char *prepare_osd(struct VideoText *, struct VtxPage *);
unsigned char *prepare_osd_header(struct VideoText *, struct VtxPage *);

/* dvb_front.c */

extern struct OutputDevice *CurrentOutputDevice;

int openDvbDevice (struct OutputDevice *);
void closeDvbDevice (struct OutputDevice *);
int setDvbChannel (struct OutputDevice *, struct Channel *);
int setDvbAudioPid (struct OutputDevice *, int);
int processDvbCommand (struct OutputDevice *, struct Command *);

/* dvb_osd.c */

extern char *screenMsgs[MAX_SCREEN_MSGS][MAX_OSD_LANGUAGES];

int openOsdDevice (struct OutputDevice *);
void closeOsdDevice (struct OutputDevice *);
int osdClose(int);
int osdOpen(int, int, int, int, int, int, int);
int osdShow(int);
int osdHide(int); 
int osdClear(int); 
int osdFill(int, int); 
int osdSetColor(int, int, int);
int osdText(int, int, int, int, int, char *);
int osdSetPalette(int, int, int, unsigned char *);
int osdSetTrans(int, int);
int osdSetPixel(int, int, int, unsigned int);
int osdGetPixel(int, int, int);
int osdSetRow(int, int, int, int, unsigned char *);
int osdSetBlock(int, int, int, int, int, int, unsigned char *);
int osdFillRow(int, int, int, int, int);
int osdFillBlock(int, int, int, int, int, int);
int osdLine(int, int, int, int, int, int);
int osdQuery(int);
int osdSetWindow(int, int);
int osdMoveWindow(int, int, int);

int osdTermClr(struct OsdTerm *, int);
#define osdTermClear(osdtrm) osdTermClr (osdtrm, 0)
#define osdTermClrEot(osdtrm) \
   if (osdtrm) osdTermClr (osdtrm, (osdtrm)->PosY*OSD_WINDOW_WIDTH)
#define osdClearEow(odev) \
   if ((odev) && (odev)->OsdTerm) osdFillBlock ((odev)->osdDev, 0, \
     (odev)->OsdTerm->PosY,OSD_WINDOW_LAST_X, OSD_WINDOW_LAST_Y, clrTransparent)
#define osdClearButInfo(osddev) \
   osdFillBlock (osddev, 0, OSD_CHANNEL_INFO_END, OSD_WINDOW_LAST_X, \
                            OSD_MESSAGE_START-1, clrTransparent)

#define osdTermHome(osdterm) \
   if (osdterm) do { (osdterm)->PosX = 0; (osdterm)->PosY = 0; } while (0)
#define osdTermNew(osdterm) if (osdterm) do { (osdterm)->PosX = 0; \
   (osdterm)->PosY = 0; osdTermClr (osdterm, 0); } while (0)
int osdFillTermBlock(struct OsdTerm *, int, int, int, int, int);
int osdTermFlush(struct OsdTerm *);
long osdTermText(struct OsdTerm *,int,int,int,int,int,unsigned short,char *);
char *osdWrapText (int,int,int,char *);

#define osdTermPrint(osdterm, x) \
   osdTermText (osdterm, -1,-1,0,-1,-1,PRINT_LATER,(x))
#define osdTermOut(osdterm, x) \
   osdTermText (osdterm, -1,-1,0,-1,-1,PRINT_DIRECT,(x))
#define osdTermChannelOut(osdterm, x) \
   osdTermText (osdterm, 0,0,0,-1,-1,PRINT_NOWRAP,(x))
#define osdTermTimeOut(osdterm, x) \
   osdTermText (osdterm,OSD_TIME_START,0,0,-1,-1,PRINT_DIRECT|PRINT_NOWRAP,(x))
#define osdTermMenuOut(osdterm,x) \
   osdTermText (osdterm,0,OSD_MENU_START,0,-1,-1,PRINT_DIRECT|PRINT_NOWRAP|UPDATE_POS,(x))
#define osdTermExtendedInfoOut(osdterm,x) \
   osdTermText (osdterm,0,-1,0,-1,-1,PRINT_DIRECT|UPDATE_POS,(x))
#define osdTermPresentFollowingOut(osdterm,x) \
   osdTermText (osdterm,0,OSD_PRESENT_FOLLOWING_START,0,-1,-1,PRINT_DIRECT|UPDATE_POS,\
   (osdWrapText (0,OSD_PRESENT_FOLLOWING_START,0,(x))))
#define osdTermMessageOut(odev,x) \
   if (odev) do { \
      osdFillBlock ((odev)->osdDev, 0, OSD_MENU_END, OSD_WINDOW_LAST_X, OSD_WINDOW_LAST_Y, clrTransparent);\
      osdTermText ((odev)->OsdTerm,0,OSD_MESSAGE_START,0,-1,-1,PRINT_DIRECT|PRINT_NOWRAP,(x)); \
   } while (0)
#define osdVideoTextOut(odev,x) \
   if (odev) osdSetBlock ((odev)->osdDev, OSD_VTX_WINDOW_FIRST_X, OSD_VTX_WINDOW_FIRST_Y, OSD_VTX_WINDOW_LAST_X, OSD_VTX_WINDOW_LAST_Y, OSD_VTX_WINDOW_WIDTH, x)
#define osdVideoTextHeaderOut(odev,x) \
   if (odev) osdSetBlock ((odev)->osdDev, OSD_VTX_WINDOW_FIRST_X, OSD_VTX_WINDOW_FIRST_Y, OSD_VTX_WINDOW_LAST_X, OSD_VTX_WINDOW_LAST_HEADER_Y, OSD_VTX_WINDOW_WIDTH, x)
