//////////////////////////////////////////////////////////////
///                                                        ///
/// debug.c: debugging functions for dtv_scan              ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.1 $
// $Date: 2001/06/08 08:50:18 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv_scan is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv_scan is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv_scan; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#include <stdio.h>
#include <stdarg.h>
#include <time.h>

#include <libsi.h>

#include "definitions.h"
#include "structures.h"
#include "prototypes.h"

void debugChannels (char *FileName)
{
   struct OutputDevice *OutputDevice;
   struct Channel      *Channel;
   FILE                *OutFile;

   if (!(OutFile = fopen (FileName, "w+")))
    { logPrintf (1, "unable to open %s\n", FileName); return; }

   xForeach (OutputDevices, OutputDevice)
   {
      fprintf (OutFile, "Device: %s\n", xName (OutputDevice));

      xForeach (OutputDevice->Channels, Channel)
      {
         fprintf (OutFile," Channel: %s\n", xName (Channel));
         fprintf (OutFile,"  ChannelNumber: %d\n", Channel->ChannelNumber);
         fprintf (OutFile,"  Provider: %s\n", Channel->Provider);
         fprintf (OutFile,"  Type: %s\n", Channel->Type);
         fprintf (OutFile,"  UsedFlag: %d\n", Channel->UsedFlag);
         fprintf (OutFile,"  TransportStreamID: %d\n", Channel->TransportStreamID);
         fprintf (OutFile,"  Frequency: %d\n", Channel->Frequency);
         fprintf (OutFile,"  Polarisation: %c\n", Channel->Polarisation);
         fprintf (OutFile,"  SymbolRate: %d\n", Channel->SymbolRate);
         fprintf (OutFile,"  ServiceID: %d\n", Channel->ServiceID);
         fprintf (OutFile,"  VideoPid: %d\n", Channel->VideoPid);
         fprintf (OutFile,"  AudioPid: %d\n", Channel->AudioPid);
         fprintf (OutFile,"  Language: %s\n", Channel->Language);
         fprintf (OutFile,"  Fec: %s\n", Channel->Fec);
         fprintf (OutFile,"  Camd: %s\n", Channel->Camd);
         debugProgramInfoList (OutFile, "   ", Channel->ProgramInfos);
      }
   }
   fclose (OutFile);
   return;
}

void debugProgramInfoList (FILE *OutFile, char *Prepend,
                           struct LIST *ProgramInfoList)
{
   struct ProgramInfo *ProgramInfo;

   if (!ProgramInfoList) return;

   xForeach (ProgramInfoList, ProgramInfo)
   {
      fprintf (OutFile, "%sProgramInfo\n%s===========\n", Prepend, Prepend);
      fprintf (OutFile, "%s   EventID: %d\n", Prepend, ProgramInfo->EventID);
      fprintf (OutFile, "%s   StartTime: %s", Prepend,
                         ctime (&ProgramInfo->StartTime));
      fprintf (OutFile, "%s   Duration: %d Minuten\n", Prepend,
                         ProgramInfo->Duration/60);
      fprintf (OutFile, "%s   Status: ", Prepend);
      switch (GetRunningStatus (ProgramInfo->Status))
      {
         case RUNNING_STATUS_NOT_RUNNING:
            fprintf (OutFile, "RUNNING_STATUS_NOT_RUNNING\n");
         break;

         case RUNNING_STATUS_AWAITING:
            fprintf (OutFile, "RUNNING_STATUS_AWAITING\n");
         break;

         case RUNNING_STATUS_PAUSING:
            fprintf (OutFile, "RUNNING_STATUS_PAUSING\n");
         break;

         case RUNNING_STATUS_RUNNING:
            fprintf (OutFile, "RUNNING_STATUS_RUNNING\n");
         break;
      }
      fprintf (OutFile, "%s   ShortName: %s\n", Prepend,
                          ProgramInfo->ShortName);
      fprintf (OutFile, "%s   ShortText: %s\n", Prepend,
                          ProgramInfo->ShortText);
      fprintf (OutFile, "%s   ExtendedName: %s\n", Prepend,
                          ProgramInfo->ExtendedName);
      fprintf (OutFile, "%s   ExtendedText: %s\n", Prepend,
                          ProgramInfo->ExtendedText);
   }
   return;
}


void logPrintf(int lLevel, char *format, ...)
{
   va_list ap;
   time_t tt;
   struct tm *ct;
   char *tbuf;

   va_start(ap, format);

   if ((logLevel >= (lLevel)) && logFile)
   {
      tt = time (NULL); ct = localtime (&tt);
      fprintf (logFile, "%02d/%02d/%02d %02d:%02d.%02d: ",
                  ct->tm_mday, ct->tm_mon+1, ct->tm_year%100,
                  ct->tm_hour, ct->tm_min, ct->tm_sec);
      vfprintf (logFile, format, ap);
      if (logFile == stdout) fprintf (logFile, "\r");
      fflush (logFile);
   }
   va_end(ap);
   
   return;
}


