//////////////////////////////////////////////////////////////
///                                                        ///
/// definitions.h: definitions used by more than one       ///
///                program module in dtv_scan              ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.2 $
// $Date: 2001/06/08 08:50:18 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv_scan is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv_scan is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv_scan; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#include <config.h>
#include <liblx.h>

#define MAX_MEMORY_USAGE                33554432    /* 32 MB usage allowed */
#define MAX_PIDS                        128
#define MAX_MESSAGE_LEN                 256
#define MAX_VTX_BUFFER                  (256*184)


#define COMMAND_PENDING     0x0000
#define COMMAND_DONE        0x0001
#define COMMAND_UNKNOWN     0x0002
#define COMMAND_EXEC_ERR    0x0003
#define COMMAND_TIMEOUT     0x0004

#define COMTYPE_DIRECT      0x0000
#define COMTYPE_DELAYED     0x0001

#define COMCODE_NONE                     0x0000
#define COMCODE_CHANNEL_SET              0x0001
#define COMCODE_CHANNEL_UP               0x0002
#define COMCODE_CHANNEL_DOWN             0x0003
#define COMCODE_ON                       0x0004
#define COMCODE_OFF                      0x0005
#define COMCODE_CHANNEL_INFO             0x0006
#define COMCODE_INFO_MESSAGE             0x0007
#define COMCODE_INFO_TEXT                0x0008
#define COMCODE_PROGRAM_INFO             0x0009
#define COMCODE_CLEAR_INFO               0x000a
#define COMCODE_ENTER_CHANNEL_MENU       0x000b
#define COMCODE_CHANNEL_MENU_DOWN        0x000c
#define COMCODE_CHANNEL_MENU_UP          0x000d
#define COMCODE_QUIT_CHANNEL_MENU        0x000e
#define COMCODE_SHOW_CHANNEL_MENU        0x000f
#define COMCODE_USE_CHANNEL_MENU         0x0010
#define COMCODE_ENTER_LANGUAGE_MENU      0x0011
#define COMCODE_SHOW_LANGUAGE_MENU       0x0012
#define COMCODE_LANGUAGE_MENU_DOWN       0x0013
#define COMCODE_LANGUAGE_MENU_UP         0x0014
#define COMCODE_QUIT_LANGUAGE_MENU       0x0015
#define COMCODE_USE_LANGUAGE_MENU        0x0016
#define COMCODE_ENTER_NVOD_MENU          0x0017
#define COMCODE_SHOW_NVOD_MENU           0x0018
#define COMCODE_NVOD_MENU_DOWN           0x0019
#define COMCODE_NVOD_MENU_UP             0x001a
#define COMCODE_QUIT_NVOD_MENU           0x001b
#define COMCODE_USE_NVOD_MENU            0x001c
#define COMCODE_ENTER_LINK_MENU          0x001d
#define COMCODE_SHOW_LINK_MENU           0x001e
#define COMCODE_LINK_MENU_DOWN           0x001f
#define COMCODE_LINK_MENU_UP             0x0020
#define COMCODE_QUIT_LINK_MENU           0x0021
#define COMCODE_USE_LINK_MENU            0x0022
#define COMCODE_OPEN_DEPENDENT_DEVICES   0x0023
#define COMCODE_OPEN_VIDEOTEXT           0x0024
#define COMCODE_ENTER_VIDEOTEXT          0x0025
#define COMCODE_SHOW_VIDEOTEXT           0x0026
#define COMCODE_QUIT_VIDEOTEXT           0x0027
#define COMCODE_TRANSPONDER_SCAN         0x0028
#define COMCODE_OPEN_EIT                 0x0029
#define COMCODE_ENTER_USER_MENU          0x002a
#define COMCODE_SHOW_USER_MENU           0x002b
#define COMCODE_USER_MENU_DOWN           0x002c
#define COMCODE_USER_MENU_UP             0x002d
#define COMCODE_QUIT_USER_MENU           0x002e
#define COMCODE_USE_USER_MENU            0x002f
#define COMCODE_VTX_PAGE_UP              0x0030
#define COMCODE_VTX_PAGE_DOWN            0x0031
#define COMCODE_VTX_SET_PAGE             0x0032
#define COMCODE_QUIT_PROGRAM             0xffff


#define INPTYP_NORMAL                    0x0000
#define INPTYP_POLLING                   0x0001

#define INPDEV_DISABLED                  0x0000
#define INPDEV_RUNNING                   0x0001

#define INPDEV_GET_SDT                   0x0001
#define INPDEV_GET_PAT                   0x0002
#define INPDEV_GET_TV_PMT                0x0003
#define INPDEV_GET_TV_EIT                0x0004
#define INPDEV_GET_NVOD_EIT              0x0005
#define INPDEV_FINISHED                  0x0006
#define INPDEV_ERROR                     0x0007
#define INPDEV_GET_EIT_ACT               0x0010
#define INPDEV_GET_EIT_OTH               0x0011
#define INPDEV_GET_EIT_ACT_SCH           0x0012
#define INPDEV_GET_EIT_OTH_SCH           0x0013

#define IMPL_INDEPENDENT    0x0000
#define IMPL_DEPENDENT      0x0001
#define IMPL_PERIODIC       0x0002
#define IMPL_PFO            0x0100
#define IMPL_TDT            0x0200
#define IMPL_EIT            0x0400
#define IMPL_EIT_SCAN       0x0800
#define IMPL_VTX            0x1000
#define IMPL_SCAN           0x2000
#define IMPL_ALL            0xFF00

#define IMPL_DISABLED       0x0000
#define IMPL_RUNNING        0x0001
#define IMPL_ERROR          0x0002


#define OUTDEV_DISABLED                0x0000
#define OUTDEV_RUNNING                 0x0001
#define OUTDEV_ERROR                   0x0002

#define OUTST_OFF                      0x0000
#define OUTST_IDLE                     0x0001
#define OUTST_CHANNEL_MENU             0x0002
#define OUTST_LANGUAGE_MENU            0x0003
#define OUTST_NVOD_MENU                0x0004
#define OUTST_LINK_MENU                0x0005
#define OUTST_VIDEOTEXT                0x0006
#define OUTST_USER_MENU                0x0007

#define MTYP_UNKNOWN                   0x0000
#define MTYP_COMMAND                   0x0001
#define MTYP_MENU                      0x0002

enum eDvbColor {
   clrTransparent = 0, // Farbe: a
   clrBlack,           // Farbe: b
   clrRed,             // Farbe: c
   clrGreen,           // Farbe: d
   clrYellow,          // Farbe: e
   clrBlue,            // Farbe: f
   clrMagenta,         // Farbe: g
   clrCyan,            // Farbe: h
   clrWhite,           // Farbe: i
   clrBackground,      // Farbe: j
   clrLast
};

#define COL2ID(x)             (((x)&0xF) + 'a')
#define ID2COL(x)             (((x) - 'a')&0xF)

#define OSD_SCREEN_WIDTH      720
#define OSD_SCREEN_HEIGHT     576
#define OSD_WINDOW_ORG_X      120
#define OSD_WINDOW_ORG_Y      84
#define OSD_WINDOW_WIDTH      (((OSD_SCREEN_WIDTH - 2*OSD_WINDOW_ORG_X)/8)*8)
#define OSD_WINDOW_HEIGHT     (((OSD_SCREEN_HEIGHT - 2*OSD_WINDOW_ORG_Y)/8)*8)
#define OSD_WINDOW_LAST_X     (OSD_WINDOW_WIDTH-1)
#define OSD_WINDOW_LAST_Y     (OSD_WINDOW_HEIGHT-1)
#define OSD_TERMSCREEN_SIZE   (OSD_WINDOW_WIDTH*OSD_WINDOW_HEIGHT)

#define OSD_VTX_WINDOW_WIDTH    480     // has to be a multiple of 8
#define OSD_VTX_WINDOW_HEIGHT   400     // has to be a multiple of 8
#define OSD_VTX_WINDOW_FIRST_X  ((OSD_WINDOW_WIDTH-OSD_VTX_WINDOW_WIDTH)/2)
#define OSD_VTX_WINDOW_FIRST_Y  ((OSD_WINDOW_HEIGHT-OSD_VTX_WINDOW_HEIGHT)/2)
#define OSD_VTX_WINDOW_LAST_X   (OSD_VTX_WINDOW_FIRST_X+OSD_VTX_WINDOW_WIDTH-1)
#define OSD_VTX_WINDOW_LAST_Y   (OSD_VTX_WINDOW_FIRST_Y+OSD_VTX_WINDOW_HEIGHT-1)
#define OSD_VTX_WINDOW_LAST_HEADER_Y   (OSD_VTX_WINDOW_FIRST_Y+16-1)

#define OSD_CHANNEL_INFO_END          28
#define OSD_MENU_START                0
#define OSD_PRESENT_FOLLOWING_START   49
#define OSD_MENU_END                  359
#define OSD_MESSAGE_START             370
#define OSD_TIME_START                408
#define OSD_MENU_FONT_HEIGHT          27

#define PRINT_LATER           0x00
#define PRINT_DIRECT          0x10
#define PRINT_NOWRAP          0x20
#define UPDATE_POS            0x40
#define WRAP_MASK             0x0F


#define MAX_OSD_LANGUAGES                       2
#define MAX_SCREEN_MSGS                         14

#define COULD_NOT_TUNE_CHANNEL                  0
#define TO_BE_SCANNED                           1
#define VOD_AVAILABLE                           2
#define SERVICE_IS_RADIO                        3
#define REPEATED_SCAN                           4
#define MULTIPLE_AUDIO_PIDS                     5
#define TIME_TO_START                           6
#define MORE_CHANNELS_AVAILABLE                 7
#define SERVICE_NOT_ACTIVE                      8
#define NO_TRANSPONDERS_DEFINED                 9
#define SCANNING                                10
#define BASIS_CHANNEL                           11
#define OPEN_VTX                                12
#define CANT_OPEN_VTX                           13


#define W                 40
#define H                 25
#define BAD_CHAR          0xb8        // substitute for chars with bad parity

#define PG_SUPPHEADER     0x01  // C7  row 0 is not to be displayed
#define PG_UPDATE         0x02  // C8  row 1-28 has modified (editors flag)
#define PG_OUTOFSEQ       0x04  // C9  page out of numerical order
#define PG_NODISPLAY      0x08  // C10 rows 1-24 is not to be displayed
#define PG_MAGSERIAL      0x10  // C11 serial trans. (any pkt0 terminates page)
#define PG_SUBTITLE       0x80  // C6  box it and insert into normal video pict.
// my flags
#define PG_ACTIVE        0x100  // currently fetching this page
#define PG_READY         0x200  // formatted once (at least)
#define PG_CHANGED       0x400  // changed since display

#define ANY_SUB         0x3f7f  // universal subpage number


#define EA_DOUBLE	1	// double height char
#define EA_HDOUBLE	2	// single height char in double height line
#define EA_BLINK	4	// blink
#define EA_CONCEALED	8	// concealed
#define EA_GRAPHIC	16	// graphic symbol
#define EA_SEPARATED	32	// use separated graphic symbol

#define E_DEF_FG	7
#define E_DEF_BG	0
#define E_DEF_ATTR	0


#define DVB_DEFAULT_DISEQC_NR                    0
#define DVB_DEFAULT_LNB_LSOF                     11700
#define DVB_DEFAULT_LNB_FREQ_LOW                 9750
#define DVB_DEFAULT_LNB_FREQ_HIGH                10600
#define DVB_DEFAULT_CLEAR_DELAY                  4
#define TDT_DEFAULT_DELAY                        3600
#define EIT_ACQUISITION_NUMBER_OF_FAILS          10
#define EIT_ACQUISITION_DEFAULT_DELAY            300
#define EIT_SCAN_DEFAULT_IDLETIME                21600
#define EIT_SCAN_DEFAULT_TIME_PER_TRANSPONDER    30
#define USE_EIT_FROM_DATABASE                    1
#define PROGRAM_INFO_MAXIMUM_GAP                 600
#define MAX_VTX_MEMORY                           8192
#define MAX_EIT_MEMORY                           8192
#define TCPIP_DEFAULT_PORT                       30003
#define DISABLE_OSD                              0
#define CHANNEL_MENU_WINDOW_SIZE                 3
#define USER_MENU_WINDOW_SIZE                    7
#define USER_MENU_SCROLL_THRESHOLD               2

#define SCAN_TIMEOUT                             180
