//////////////////////////////////////////////////////////////
///                                                        ///
/// dtv_config.c: DCL dependant code of dtv_scan           ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.3 $
// $Date: 2001/06/08 08:50:18 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv_scan is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv_scan is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv_scan; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <dcl.h>

#include "definitions.h"
#include "structures.h"
#include "prototypes.h"


struct LIST *AvailableSatellites = NULL;
struct LIST *AvailableChannels = NULL;
struct LIST *AvailableTransponders = NULL;
struct LIST *OutputDevices = NULL;
struct LIST *InputDevices = NULL;
struct LIST *CommandQueue = NULL;
struct LIST *GlobalOptions = NULL;

struct MEM_CHUNK *AvChRemember = NULL;
struct MEM_CHUNK *AvTpRemember = NULL;
struct MEM_CHUNK *AvSatRemember = NULL;
struct MEM_CHUNK *CommandRemember = NULL;

struct Option *statOption = NULL;

Dcl_Interp *interp = NULL;


int initConfiguration (char *fileName)
{
   GlobalOptions = xNewList (NULL);
   OutputDevices = xNewList (NULL);
   InputDevices = xNewList (NULL);
   CommandQueue = xNewList (NULL);

   AddGlobalOption ("dvbDefaultDiseqcNr", DVB_DEFAULT_DISEQC_NR);
   AddGlobalOption ("dvbDefaultLnbLsof", DVB_DEFAULT_LNB_LSOF);
   AddGlobalOption ("dvbDefaultLnbFreqLow", DVB_DEFAULT_LNB_FREQ_LOW);
   AddGlobalOption ("dvbDefaultLnbFreqHigh", DVB_DEFAULT_LNB_FREQ_HIGH);
   AddGlobalOption ("scanTimeout", SCAN_TIMEOUT);

   if (!(interp = Dcl_CreateInterp ()) ||
       (Dtv_Init (interp) != DCL_OK))
   {
      logPrintf (0, "error creating DCL interpreter\n");
      return (-1);
   }
   Dcl_SetVar(interp, "dtvConfigPath", CONF_DIR, DCL_GLOBAL_ONLY);
   if (Dcl_EvalFile (interp, fileName) != DCL_OK)
   {
      logPrintf (0, "%s\n", interp->result);
      return (-1);
   }

   //  TODO: check for existance of at least one out/input pair and implication
   return (0);
}


int Dtv_Init (Dcl_Interp *interp)
{
   Dcl_CreateCommand (interp, "define_available_satellites",
                         Dcl_DefineAvailableSatellites, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "define_available_transponders",
                         Dcl_DefineAvailableTransponders, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "open_output",
                         Dcl_OpenOutput, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   Dcl_CreateCommand (interp, "set_option",
                         Dcl_SetOption, (ClientData) NULL,
                        (Dcl_CmdDeleteProc *) NULL);
   return DCL_OK;
}


int Dcl_DefineAvailableSatellites (ClientData clientData, Dcl_Interp *interp,
                                 int argc, char **argv)
{
   int                  numberOfSatellites, fieldLength, i, returnValue;
   int                  diseqcnr, lsof, freqlo, freqhi;
   char               **satList, **satField;
   struct Satellite    *Satellite;
   struct MEM_CHUNK   **OriginalKey;

   if (argc != 2) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " {{<name> <diseqc-nr> <lnb-lsof>",
                                " <lnb-flo> <lnb-fhi>}{...}}\"", (char *) NULL);
      return DCL_ERROR;
   }

   if (Dcl_SplitList(interp, argv[1], &numberOfSatellites,
          &satList) != DCL_OK) return DCL_ERROR;

   returnValue = DCL_OK;
   OriginalKey = xGetRemember ();
   xSetRemember (&AvSatRemember);
   if (AvSatRemember != NULL) xMemFreeAll (NULL);
   AvailableSatellites = xNewList (NULL);

   for (i = 0; i < numberOfSatellites; i++)
   {
      if (Dcl_SplitList(interp, satList[i], &fieldLength,
             &satField) != DCL_OK) { returnValue = DCL_ERROR; break; }

      if (fieldLength != 5)
      {
         Dcl_AppendResult (interp, "each field must have 5 entries:",
                                   " {<name> <diseqc-nr> <lnb-lsof>",
                                   " <lnb-flo> <lnb-fhi>}", (char *) NULL);
         returnValue = DCL_ERROR;
      } else if ( (Dcl_GetInt (interp, satField[1], &diseqcnr) != DCL_OK) ||
                  (Dcl_GetInt (interp, satField[2], &lsof) != DCL_OK) ||
                  (Dcl_GetInt (interp, satField[3], &freqlo) != DCL_OK) ||
                  (Dcl_GetInt (interp, satField[4], &freqhi) != DCL_OK))
             { returnValue = DCL_ERROR; }
             else
             {
                if (xFindName (AvailableSatellites, satField[0]))
                {
                   Dcl_AppendResult (interp, "satellite \"", satField[0],
                                         "\" already defined", (char *) NULL);
                   returnValue = DCL_ERROR;
                }
                else
                {
                   CreateSatellite (Satellite, satField[0], diseqcnr,
                                       lsof, freqlo, freqhi);
                   xAddTail (AvailableSatellites, Satellite);
                }
             }
      free ((char *) satField);   // Dcl_Free ???
   }
   free ((char *) satList);   // Dcl_Free ???

   xSetRemember (OriginalKey);
   return returnValue;
}


int Dcl_DefineAvailableTransponders (ClientData clientData, Dcl_Interp *interp,
                                 int argc, char **argv)
{
   int                  numberOfTransponders, fieldLength, i, j, returnValue;
   int                  freq, srate;
   char               **transponderList, **transponderField;
   struct Transponder  *Transponder;
   struct Satellite    *Satellite = NULL;
   struct MEM_CHUNK   **OriginalKey;

   if ((argc != 2) && (argc != 3)) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
         " [<satellite>] {{<freq> <pol> <srate>}{...}}\"", (char *) NULL);
      return DCL_ERROR;
   }

   if (argc == 3)
   {
      if (!(Satellite = (struct Satellite *)
         xFindName (AvailableSatellites, argv[1])))
      {
         Dcl_AppendResult (interp, "satellite name \"",
            argv[1], "\" not found", (char *) NULL);
         return DCL_ERROR;
      }
      if (Dcl_SplitList(interp, argv[2], &numberOfTransponders,
          &transponderList) != DCL_OK) return DCL_ERROR;
   }
   else if (Dcl_SplitList(interp, argv[1], &numberOfTransponders,
          &transponderList) != DCL_OK) return DCL_ERROR;

   returnValue = DCL_OK;
   OriginalKey = xGetRemember ();
   xSetRemember (&AvTpRemember);
   if (!AvailableTransponders)
      AvailableTransponders = xNewList (NULL);

   for (i = 0; i < numberOfTransponders; i++)
   {
      if (Dcl_SplitList(interp, transponderList[i], &fieldLength,
             &transponderField) != DCL_OK) { returnValue = DCL_ERROR; break; }

      if (fieldLength != 3)
      {
         Dcl_AppendResult (interp, "each field must have 3 entries:",
                                   " {<freq> <pol> <srate>}", (char *) NULL);
         returnValue = DCL_ERROR;
      } else if ( (Dcl_GetInt (interp, transponderField[0], &freq) != DCL_OK) ||
                  (Dcl_GetInt (interp, transponderField[2], &srate) != DCL_OK))
             { returnValue = DCL_ERROR; }
             else
             {
                CreateTransponder (Transponder, freq*1000,
                                      transponderField[1][0], srate);
                Transponder->Satellite = Satellite;
                xAddTail (AvailableTransponders, Transponder);
             }
      free ((char *) transponderField);   // Dcl_Free ???
   }
   free ((char *) transponderList);   // Dcl_Free ???

   xSetRemember (OriginalKey);
   return returnValue;
}


int Dcl_OpenOutput (ClientData clientData, Dcl_Interp *interp,
                    int argc, char **argv)
{
   int                     id = 0, devnum;
   struct OutputDevice    *OutputDevice;
   char                    buf[32];

   if (argc < 2) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                           " <type> ?<args>?\"", (char *) NULL);
      return DCL_ERROR;
   }
   if (strcasecmp (argv[1], "DVBS"))
   {
      Dcl_AppendResult (interp, "unsupported output device \"", argv[1],
                            "\".\nsupported devices are: DVBS", (char *) NULL);
      return DCL_ERROR;
   }
   if (!strcasecmp (argv[1], "DVBS"))
   {
      if (argc != 3) {
         Dcl_AppendResult (interp, "you have to specify a device number ",
                                   "for DVBS", (char *) NULL);
         return DCL_ERROR;
      }
      if (Dcl_GetInt (interp, argv[2], &devnum) != DCL_OK)
         return DCL_ERROR;

      xForeach (OutputDevices, OutputDevice)
         if (OutputDevice->Identifier >= id)
            id = OutputDevice->Identifier + 1;
      sprintf (buf, "%d", devnum);
      CreateOutputDevice (OutputDevice, buf, id,
                             processDvbCommand, closeDvbDevice);
      xAddTail (OutputDevices, OutputDevice);
      sprintf (buf, "%d", id);
      Dcl_AppendResult (interp, buf, (char *) NULL);
   }
   return DCL_OK;
}


int Dcl_SetOption (ClientData clientData, Dcl_Interp *interp,
                        int argc, char **argv)
{
   struct Option         *Option;
   char                   buf[32];

   if (argc < 2) {
      Dcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
                                " <option> ?<value>?\"", (char *) NULL);
      return DCL_ERROR;
   }
   if (!(Option = (struct Option *) xFindName (GlobalOptions, argv[1])))
   {
      Dcl_AppendResult (interp, "unknown option \"", argv[1],
                                "\"", (char *) NULL);
      return DCL_ERROR;
   }
   if (argc < 3) {
      sprintf (buf, "%d", Option->Value);
      Dcl_AppendResult (interp, buf, (char *) NULL);
      return DCL_OK;
   }
   return (Dcl_GetInt (interp, argv[2], &Option->Value));
}

