//////////////////////////////////////////////////////////////
///                                                        ///
/// dtv_scan.c: main program routines of dtv_scan          ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.2 $
// $Date: 2001/06/15 10:24:34 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv_scan is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv_scan is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv_scan; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.


#include <getopt.h>
#include <stdio.h>
#include <signal.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>


#include "definitions.h"
#include "structures.h"
#include "prototypes.h"


int logLevel = 2;
FILE *logFile = NULL;
FILE *outFile = NULL;
FILE *vdrFile = NULL;

static struct option long_options[] = {
   { "help",         no_argument,       NULL, 'h' },
   { "configfile",   required_argument, NULL, 'c' },
   { "logfile",      required_argument, NULL, 'l' },
   { "outfile",      required_argument, NULL, 'o' },
   { "vdrfile",      optional_argument, NULL, 'f' },
   { "verbosity",    required_argument, NULL, 'v' },
   { 0 }
};

  
int main (int argc, char **argv)
{
   int           c, option_index = 0, l, end, createVdrFile = 0;
   char         *logFileName = "-";
   char         *outFileName = "available_channels.dcl";
   char         *configFileName = "dtv_scan.conf";
   char         *vdrFileName = "channels.conf";

   while ((c = getopt_long(argc, argv, "v:o:hc:l:f::",
              long_options, &option_index)) != -1)
   {
      switch (c)
      {
         case 'c':
            configFileName = optarg;
         break;

         case 'l':
            logFileName = optarg;
         break;

         case 'o':
            outFileName = optarg;
         break;

         case 'f':
            if (optarg)
               vdrFileName = optarg;
            createVdrFile = 1;
         break;

         case 'v':
            if (((l = atoi(optarg)) < 0) || (l > 8))
            {
               fprintf(stderr, "%s: invalid verbosity level: %s\n",
                          argv[0], optarg);
               return (-1);
            }
            else logLevel = l;
         break;

         case 'h':
         default:
            fprintf(stderr, "\nUsage: %s [OPTION]\n\n", argv[0]);
            fprintf(stderr, "  -h,          --help              display this help and exit\n");
            fprintf(stderr, "  -c <file>,   --configfile=<file> set configfile (default: dtv_scan.conf)\n");
            fprintf(stderr, "  -l <file>,   --logfile=<file>    set logfile (default: -)\n");
            fprintf(stderr, "  -o <file>,   --outfile=<file>    set outfile (default: available_channels.dcl)\n");
            fprintf(stderr, "  -f [<file>], --vdrfile[=<file>]  enable vdrfile creation and/or\n");
            fprintf(stderr, "                                   set vdrfile name (default: channels.conf)\n");
            fprintf(stderr, "  -v LEVEL,    --verbosity=LEVEL   set verbosity level (default: 2)\n");
            fprintf(stderr, "                                   0 = no logging, 8 = tedious\n");
            fprintf(stderr, "\n");
            fprintf(stderr, "Report bugs to <hakenes@hippomi.de>\n\n");
            return (0);
         break;
      }
   }

   if (logFileName)
   {
      if (!strcmp (logFileName, "-"))
         logFile = stdout;
      else
      {
         if (!(logFile = fopen (logFileName, "a")))
         {
            fprintf(stderr, "Error:   cannot open %s\n", logFileName);
            return (-2);
         }
      }
      logPrintf (0, "dtv_scan started\n");
   }
   if (outFileName)
   {
      if (!strcmp (outFileName, "-"))
         outFile = stdout;
      else
      {
         if (!(outFile = fopen (outFileName, "w+")))
         {
            fprintf(stderr, "Error:   cannot open %s\n", outFileName);
            return (-2);
         }
      }
      logPrintf (0, "outputfile %s opened\n", outFileName);
   }
   if (createVdrFile && vdrFileName)
   {
      if (!(vdrFile = fopen (vdrFileName, "w+")))
      {
         fprintf(stderr, "Error:   cannot open %s\n", vdrFileName);
         return (-2);
      }
      logPrintf (0, "vdr outputfile %s opened\n", vdrFileName);
   }
   signal (SIGINT, safeExit);
   signal (SIGHUP, safeExit);
   signal (SIGTERM, safeExit);

   if (initConfiguration (configFileName) != 0) safeExit (0);
   openInputDevices ();
   while (!execScheduler ()) usleep (10);

   safeExit (0);
}


void safeExit (int sigNum)
{
   logPrintf (0, "dtv_scan stopped on signal %d\n", sigNum);
   signal (SIGINT, SIG_DFL);
   signal (SIGHUP, SIG_DFL);
   signal (SIGTERM, SIG_DFL);
   closeInputDevices ();
   closeOutputDevices ();
   fclose (logFile);
   fclose (outFile);
//   debugChannels ("dtv_scan.dbg");
   exit (0);
}
