#!/usr/local/bin/perl
##############################################################
###                                                        ###
### get_digital_transponders.pl: get transponders from net ###
###                                                        ###
##############################################################

## $Revision: 1.3 $
## $Date: 2001/06/08 08:50:18 $
## $Author: hakenes $
##
##   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
##
## dtv_scan is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## dtv_scan is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You may have received a copy of the GNU General Public License
## along with dtv_scan; see the file COPYING.  If not, write to the
## Free Software Foundation, Inc., 59 Temple Place - Suite 330,
## Boston, MA 02111-1307, USA.
#
#

use HTML::Entities;
use HTML::Parser;
use LWP::UserAgent;
use IO::Handle;

STDOUT->autoflush(1);

#######################################################################
#######################################################################
#
#  Filename to dump transponders into:
#
$filename = "astra19_transponders.dcl";
#
#######################################################################
#
#  The following array determines the satellite to scan. For other
#  than descripted ones please look at www.lyngsat.com for the
#  appropriate link:
#
#
#  1) Astra 19.2 East
#
@files_to_fetch = (["http://www.lyngsat.com/astra19.shtml","*"]);
#
#
#  2) Astra 28.2 East
#
# @files_to_fetch = (["http://www.lyngsat.com/28east.shtml","*"]);
#
#
#  3) Hotbird 13 East
#
# @files_to_fetch = (["http://www.lyngsat.com/hotbird.shtml","*"]);
#
#
#  4) Thor 1 West
#
# @files_to_fetch = (["http://www.lyngsat.com/1west.shtml","*"]);
#
#
#  5) Sirius 5 East
#
# @files_to_fetch = (["http://www.lyngsat.com/sirius.shtml","*"]);
#
#######################################################################

$ua = new LWP::UserAgent;
$ua->agent("Mozilla/9.1 " . $ua->agent);

$dig_clear_color = "#ffffdd";
$dig_encrypted_color = "#ffccbb";
$interactive_color = "#ffaaff";

$table = 0; $tr = 0; $td = 0;
$row = 0; $col = 0; $mcol = 0;
$table_is_valid = 0; $br_has_occurred = 0; $href_to_add = 0;
$act_href = ""; $act_prov = "";

@table_text = ();
@row_valid = ();
@row_provider = ();
@chandb = ();

sub parser_start {
   my($tagname, $attr_t) = @_;
   my(%attr) = %$attr_t; my($i);

   if ($tagname eq "table") {
      if ($table == 1) { print "warning: nested tables\n"; }
      $table = 1;
   }
   if ($tagname eq "tr") {
      if ($tr == 1) { print "warning: nested tr\n"; }
      $tr = 1;
   }
   if ($tagname eq "td") {
      if ($td == 1) { print "warning: nested td\n"; }
      $td = 1;
      foreach $key (keys %attr)
      {
         if ($key eq "colspan") {
            $i = 1;
            while ($i < $attr{$key}) {
               $table_text[$row][$col+$i++] = "-";
            }
         }
         if ($key eq "rowspan") {
            $i = 1;
            while ($i < $attr{$key}) {
               $table_text[$row+$i++][$col] = "-";
            }
         }
         if ($col == 2) {
            if ($key eq "bgcolor") {
               if ($attr{$key} eq $dig_clear_color) {
                  if ($row_valid[$row] eq ".") { $row_valid[$row] = "digital_clear"; }
               }
               if ($attr{$key} eq $dig_encrypted_color) {
                  if ($row_valid[$row] eq ".") { $row_valid[$row] = "digital_encrypted"; }
               }
#               if ($attr{$key} eq $interactive_color) {
#                  if ($row_valid[$row] eq ".") { $row_valid[$row] = "interactive"; }
#               }
            }
         }
      }
      $table_text[$row][$col] = "*";
   }
   if ($tagname eq "br") {
      $br_has_occurred = 1;
   }
   if ($tagname eq "a") {
      if ($href_to_add == 0) { $act_href = $attr{href}; }
   }
   if ($tagname eq "img") {
      if ($attr{alt} eq "Digital package chart") {
         $flag = 0;
         foreach $tmphref (@files_to_fetch) {
            @href = @$tmphref;
            if ($href[0] eq $act_href) { $flag = 1; }
         }
         if ($flag == 0) {
         #   push @files_to_fetch, [$act_href,"*"];
            $href_to_add = 1;
         }
      }
   }
}

sub parser_end {
   my($tagname) = @_;

   if ($tagname eq "table") {
      $table = 0; $table_is_valid = 0;
   }
   if ($tagname eq "tr") {
      if ($row_valid[$row] ne ".") {
         $row_is_channel = 0;

         @tmptab = split(/&/, $table_text[$row][0]);
         foreach $tmpitem (@tmptab) {
            if ($tmpitem =~ /(1[012][0-9][0-9][0-9])[ ]+([VH])/i) {
               $act_freq = $1;
               $act_pol = $2;
            } else {
               if ($tmpitem =~ /tp ([0-9]+)/i) {
                  $act_tpid = $1;
               } else {
                  if ($tmpitem =~ /SR (2[27][05]00)/i) {
                     $act_srate = $1;
                  } else {
                     if ($tmpitem =~ /FEC ([1-8]\/[1-8])/i) {
                        $act_fec = $1;
                     }
                  }
               }
            }
         }
         if ($table_text[$row][2] =~ /^ /) {
               $act_type = "Audio";
               $act_name = substr ($table_text[$row][2], 2);
         } else {
            if ($table_text[$row][2] =~ /^@ /) {
               $act_type = "Daten";
               $act_name = substr ($table_text[$row][2], 2);
            } else {
               $act_type = "Video";
               $act_name = $table_text[$row][2];
            }
         }
         if ($row_valid[$row] eq "digital_encrypted") { $act_camd = $table_text[$row][4]; }
         else { $act_camd = "FTA"; }
         @tmptab = split(/&/, $table_text[$row][5]);
         foreach $tmpitem (@tmptab) {
            if ($tmpitem =~ /(2[27][05]00)[ ]+-[ ]+([1-8]\/[1-8])/) {
               $act_prov = $table_text[$row][2];
               $act_srate = $1;
               $act_fec = $2;
            } else {
               if ($tmpitem =~ /([0-9]+)/) {
                  $act_svid = $1;
                  $row_is_channel = 1;
               }
            }
         }
         $row_provider[$row] = $act_prov;
         if (($table_text[$row][6] ne "*") && ($table_text[$row][6] ne "-")) 
            { $act_vpid = $table_text[$row][6]; }
         else { $act_vpid = ""; }
         @tmptab = split(/&/, $table_text[$row][7]);
         foreach $tmpitem (@tmptab) {
            if ($tmpitem =~ /([0-9]+)[ ]+([^0-9]+)/) {
               $act_apid = $1;
               $act_lang = $2;
            } else {
               if ($tmpitem =~ /([0-9]+)/) {
                  $act_apid = $1;
                  $act_lang = "unbekannt";
               }
            }
            if ($row_is_channel == 1) {
               @tmpitem = ("NAME"     => $act_name,
                           "PROV"     => $act_prov,
                           "TYPE"     => $act_type,
                           "TPID"     => $act_tpid,
                           "FREQ"     => $act_freq,
                           "POL"      => $act_pol,
                           "SRATE"    => $act_srate,
                           "SVID"     => $act_svid,
                           "VPID"     => $act_vpid,
                           "APID"     => $act_apid,
                           "FEC"      => $act_fec,
                           "CAMD"     => $act_camd,
                           "LANG"     => $act_lang);
               push(@chandb, [ @tmpitem ]);
            }
         }
      }
      if ($href_to_add) {
         push @files_to_fetch, [$act_href,$act_prov];
         $href_to_add = 0;
      }
      $tr = 0; $row++; $col = 0; $br_has_occurred = 0;
      while ($table_text[$row][$col] eq "-") { $col++; }
      if ($col > $mcol) { $mcol = $col; }
   }
   if ($tagname eq "td") {
      $td = 0; $col++; $br_has_occurred = 0;
      while ($table_text[$row][$col] eq "-") { $col++; }
      if ($col > $mcol) { $mcol = $col; }
   }
}

sub parser_text {
   my($origtext) = @_;

   $origtext =~ s/^[ \t]*//g;
   $origtext =~ s/[ \t]*$//g;

   if ($origtext eq "Provider Name") {
      $table_is_valid = 1;
   }
   if (($col == 0) ||
       (($row_valid[$row] ne ".") && ($origtext ne "") &&
        (($col == 2) || ($col == 4) || ($col == 5) || ($col == 6) || ($col == 7)))) {
      if ($table_text[$row][$col] eq "*") { $table_text[$row][$col] = $origtext; }
      else {
         if ($br_has_occurred == 1) {
            $table_text[$row][$col] .= "&";
            $br_has_occurred = 0;
         } else {
            $table_text[$row][$col] .= " ";
         }
         $table_text[$row][$col] .= $origtext;
      }
   }
}


my ($x, $y);

for $x (0...2000) {
   for $y (0...20) {
      $table_text[$x][$y] = ".";
   }
   $row_valid[$x] = ".";
   $row_provider[$x] = ".";
}

$p = HTML::Parser->new( api_version => 3,
                        start_h =>  [\&parser_start, "tagname, attr"],
                        end_h   =>  [\&parser_end,   "tagname"],
                        text_h   => [\&parser_text,  "dtext"],
                        unbroken_text => 1 );

foreach $tmpurl (@files_to_fetch) {
   @url = @$tmpurl;
   $act_prov = $url[1];
   print "Getting " . $url[0] . "...";
   $req = new HTTP::Request GET => $url[0];
   $res = $ua->request($req);
   if ($res->is_success) {
      $p->parse ($res->content);
      print "...successful\n";
   } else {
      print "...FAILED\n";
   }
}
$p->eof;

sub sort_channels {
   %chan_a = @$a; %chan_b = @$b;
   return ($chan_a{FREQ} cmp $chan_b{FREQ});
   return 0;
}
@chandb_rep = sort sort_channels @chandb;

$num = 0;
@printed_transponders = ();

print "Creating " . $filename . "...";

open (OUTFILE, ">" . $filename);
print OUTFILE "define_available_transponders {\n";
foreach $tmpitem (@chandb_rep)
{
   %tmp = @$tmpitem;

   $flag = 0;
   foreach $tmptpid (@printed_transponders) {
      if ($tmp{FREQ} eq $tmptpid) { $flag = 1; }
   }
   if ($flag == 0) {
      print OUTFILE "   {" . $tmp{FREQ} . " " . $tmp{POL} . " " . $tmp{SRATE} .  "}\n";
      push(@printed_transponders, $tmp{FREQ});
   }
}
print OUTFILE "}\n";
close (OUTFILE);

print "...successful\n";
