//////////////////////////////////////////////////////////////
///                                                        ///
/// structures.h: data structure definitions for dtv_scan  ///
///                                                        ///
//////////////////////////////////////////////////////////////

// $Revision: 1.2 $
// $Date: 2001/06/08 08:50:18 $
// $Author: hakenes $
//
//   (C) 2001 Rolf Hakenes <hakenes@hippomi.de>, under the GNU GPL.
//
// dtv_scan is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// dtv_scan is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You may have received a copy of the GNU General Public License
// along with dtv_scan; see the file COPYING.  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#include <sys/time.h>
#include <errno.h>

#include <liblx.h>


struct Option
{
   struct NODE              Node;
   int                      Value;
};

#define CreateOption(opt, name, value) \
   do \
   { \
      xCreateNode (opt, name); \
      (opt)->Value = value; \
   } while (0)

#define GetGlobalOption(name) ((statOption = (struct Option *) \
    xFindName (GlobalOptions, name)) ? statOption->Value : -1)

#define AddGlobalOption(name, value) \
   do { \
      CreateOption (statOption, name, value); \
      xAddTail (GlobalOptions, statOption); \
   } while (0)


struct Command
{
   struct NODE              Node;
   unsigned short           Code;
   unsigned short           Status;
   unsigned short           Type;
   int                      Value;
   void                    *Pointer;
   int                      OutputID;
   struct timeval           TimeStamp;
   unsigned short           TimeOut;
};

#define CreateCommand(command, cmd, oid) \
   do \
   { \
      xCreateNode (command, NULL); \
      command->Code = cmd; \
      command->Status = COMMAND_PENDING; \
      command->Type = COMTYPE_DIRECT; \
      command->Value = 0; \
      command->Pointer = NULL; \
      command->OutputID = oid; \
      gettimeofday (&(command->TimeStamp), NULL); \
      command->TimeOut = 0; \
   } while (0)

#define ScheduleDirect(cmd) \
   do \
   { \
      struct Command *tcm; \
      struct MEM_CHUNK **okey; \
      \
      okey = xGetRemember (); \
      xSetRemember (&CommandRemember); \
      CreateCommand (tcm, cmd, ImplicitOutputID); \
      xAddTail (CommandQueue, tcm); \
      xSetRemember (okey); \
   } while (0)

#define ScheduleDirectValue(cmd, val) \
   do \
   { \
      struct Command *tcm; \
      struct MEM_CHUNK **okey; \
      \
      okey = xGetRemember (); \
      xSetRemember (&CommandRemember); \
      CreateCommand (tcm, cmd, ImplicitOutputID); \
      tcm->Value = val; \
      xAddTail (CommandQueue, tcm); \
      xSetRemember (okey); \
   } while (0)

#define ScheduleDirectText(cmd, txt) \
   do \
   { \
      struct Command *tcm; \
      struct MEM_CHUNK **okey; \
      \
      okey = xGetRemember (); \
      xSetRemember (&CommandRemember); \
      CreateCommand (tcm, cmd, ImplicitOutputID); \
      xSetName (tcm, txt); \
      xAddTail (CommandQueue, tcm); \
      xSetRemember (okey); \
   } while (0)

#define ScheduleDirectPointer(cmd, ptr, val) \
   do \
   { \
      struct Command *tcm; \
      struct MEM_CHUNK **okey; \
      \
      okey = xGetRemember (); \
      xSetRemember (&CommandRemember); \
      CreateCommand (tcm, cmd, ImplicitOutputID); \
      tcm->Pointer = (void *)(ptr); \
      tcm->Value = val; \
      xAddTail (CommandQueue, tcm); \
      xSetRemember (okey); \
   } while (0)

#define ScheduleDelayed(cmd, to) \
   do \
   { \
      struct Command *tcm; \
      struct MEM_CHUNK **okey; \
      \
      okey = xGetRemember (); \
      xSetRemember (&CommandRemember); \
      CreateCommand (tcm, cmd, ImplicitOutputID); \
      tcm->TimeOut = to; \
      tcm->Type = COMTYPE_DELAYED; \
      xAddTail (CommandQueue, tcm); \
      xSetRemember (okey); \
   } while (0)

#define ScheduleDelayedValue(cmd, val, to) \
   do \
   { \
      struct Command *tcm; \
      struct MEM_CHUNK **okey; \
      \
      okey = xGetRemember (); \
      xSetRemember (&CommandRemember); \
      CreateCommand (tcm, cmd, ImplicitOutputID); \
      tcm->TimeOut = to; \
      tcm->Value = val; \
      tcm->Type = COMTYPE_DELAYED; \
      xAddTail (CommandQueue, tcm); \
      xSetRemember (okey); \
   } while (0)

#define ScheduleDelayedPointer(cmd, ptr, val, to) \
   do \
   { \
      struct Command *tcm; \
      struct MEM_CHUNK **okey; \
      \
      okey = xGetRemember (); \
      xSetRemember (&CommandRemember); \
      CreateCommand (tcm, cmd, ImplicitOutputID); \
      tcm->TimeOut = to; \
      tcm->Pointer = (void *)(ptr); \
      tcm->Value = val; \
      tcm->Type = COMTYPE_DELAYED; \
      xAddTail (CommandQueue, tcm); \
      xSetRemember (okey); \
   } while (0)

#define CommandHasTimedOut(cmd, to) \
   ((((to).tv_sec - (cmd)->TimeStamp.tv_sec)*10) + \
    (((to).tv_usec - (cmd)->TimeStamp.tv_usec)/100000) > (cmd)->TimeOut)

#define FindCommand(tcm, comcode) \
   do \
   { \
      xForeach (CommandQueue, tcm) \
         if ((tcm->Code == comcode) && (ImplicitOutputID == tcm->OutputID)) \
            break; \
   } while (0)

#define PurgeCommands(comcode) \
   do \
   { \
      struct Command *tcm, *ncm; \
      struct MEM_CHUNK **okey; \
      \
      okey = xGetRemember (); \
      xSetRemember (&CommandRemember); \
      if (tcm = (struct Command *) CommandQueue->Head) \
      do \
      { \
         ncm = (struct Command *) xSucc (tcm); \
         if ((tcm->Code == comcode) && (ImplicitOutputID == tcm->OutputID)) \
         { xRemove (CommandQueue, tcm); if (xName (tcm)) xMemFree (xName (tcm)); xMemFree (tcm); } \
      } while (tcm = ncm); \
      xSetRemember (okey); \
   } while (0)

#define PurgeAllCommands(comd) \
   do \
   { \
      struct Command *tcm, *ncm; \
      struct MEM_CHUNK **okey; \
      \
      okey = xGetRemember (); \
      xSetRemember (&CommandRemember); \
      if (tcm = (struct Command *) CommandQueue->Head) \
      do \
      { \
         ncm = (struct Command *) xSucc (tcm); \
         if ((ImplicitOutputID == tcm->OutputID) && (comd != tcm))\
         { xRemove (CommandQueue, tcm); if (xName (tcm)) xMemFree (xName (tcm)); xMemFree (tcm); } \
      } while (tcm = ncm); \
      xSetRemember (okey); \
   } while (0)

#define FreeCommand(cmd) \
   do \
   { \
      struct MEM_CHUNK **okey; \
      \
      okey = xGetRemember (); \
      xSetRemember (&CommandRemember); \
      if (xName (cmd)) xMemFree (xName (cmd)); xMemFree (cmd); \
      xSetRemember (okey); \
   } while (0)

struct InputDevice
{
   struct NODE              Node;     /* Node enthaelt Pfadname */
   unsigned short           Identifier;
   unsigned short           Status;
   unsigned short           State;
   unsigned short           Type;
   int                      FileHandle;
   int                    (*GetEvent)(struct InputDevice *);
   int                    (*Open)(struct InputDevice *);
   void                   (*Close)(struct InputDevice *);
   int                      UserData;
   int                      Period;
   struct LIST             *Implications;
   struct MEM_CHUNK        *RememberKey;
   struct LIST             *ProgramList;
   struct Program          *Program;
   struct LIST             *ServiceList;
   struct Service          *Service;
   struct LIST             *EventList;
   struct Event            *Event;
};

#define CreateInputDevice(dev, text, iden, ope, cls, eve) \
   do \
   { \
      xCreateNode (dev, text); \
      (dev)->Identifier = iden; \
      (dev)->Status = INPDEV_DISABLED; \
      (dev)->State = 0; \
      (dev)->Type = 0; \
      (dev)->FileHandle = 0; \
      (dev)->Open = ope; \
      (dev)->Close = cls; \
      (dev)->GetEvent = eve; \
      (dev)->UserData = 0; \
      (dev)->Period = 0; \
      (dev)->Implications = xNewList (NULL); \
      (dev)->RememberKey = NULL; \
      (dev)->ProgramList = NULL; \
      (dev)->Program = NULL; \
      (dev)->ServiceList = NULL; \
      (dev)->Service = NULL; \
      (dev)->EventList = NULL; \
      (dev)->Event = NULL; \
   } while (0)

struct Implication
{
   struct NODE              Node;
   unsigned short           OutputID;
   unsigned short           Type;
   unsigned short           Status;
   struct LIST             *TranslationTable;
};

#define CreateImplication(dev, oid, typ) \
   do \
   { \
      xCreateNode (dev, NULL); \
      (dev)->OutputID = oid; \
      (dev)->Type = typ; \
      (dev)->Status = IMPL_DISABLED; \
      (dev)->TranslationTable = NULL; \
   } while (0)

#define FindOutputDevice(indev, oudev) \
   do \
   { \
      struct Implication *impli; \
      \
      xForeach ((indev)->Implications, impli) \
      { \
         xForeach (OutputDevices, (oudev)) \
            if ((oudev)->Identifier == impli->OutputID) break; \
         if (oudev) break; \
      } \
   } while (0);

struct TranslateItem
{
   struct NODE              Node;
   char                    *Command;
   unsigned long            Value;
   unsigned long            CtrlChar;
};

#define CreateTranslateItem(ite, val, cch) \
   do \
   { \
      xCreateNode (ite, NULL); \
      (ite)->Command = NULL; \
      (ite)->Value = val; \
      (ite)->CtrlChar = cch; \
   } while (0)

#define OpenDependentInputDevices(typ) \
   do \
   { \
      struct InputDevice *inpdev; \
      struct Implication *impl; \
      \
      xForeach (InputDevices, inpdev) \
         xForeach (inpdev->Implications, impl) \
            if ((impl->Type & IMPL_DEPENDENT) && \
                (impl->Type & (typ)) && \
                (impl->OutputID == (ImplicitOutputID))) \
               if (inpdev->Open(inpdev) >= 0) \
               { \
                  inpdev->Status = INPDEV_RUNNING; \
                  if (impl->Type & IMPL_PERIODIC) \
                  { \
                     ScheduleDelayedValue (COMCODE_OPEN_DEPENDENT_DEVICES, \
                                              typ, inpdev->Period); \
                  } \
               } \
   } while (0)

#define CloseDependentInputDevices(typ) \
   do \
   { \
      struct InputDevice *inpdev; \
      struct Implication *impl; \
      \
      xForeach (InputDevices, inpdev) \
         xForeach (inpdev->Implications, impl) \
            if ((impl->Type & IMPL_DEPENDENT) && \
                (impl->Type & (typ)) && \
                (impl->OutputID == (ImplicitOutputID))) { \
               inpdev->Close (inpdev); \
               inpdev->Status = INPDEV_DISABLED; \
               inpdev->FileHandle = 0; \
               if (impl->Type & IMPL_PERIODIC) \
               { \
                  struct Command *tcm, *ncm; \
                  struct MEM_CHUNK **okey; \
                  \
                  okey = xGetRemember (); \
                  xSetRemember (&CommandRemember); \
                  if (tcm = (struct Command *) CommandQueue->Head) \
                  do \
                  { \
                     ncm = (struct Command *) xSucc (tcm); \
                     if ((tcm->Code == COMCODE_OPEN_DEPENDENT_DEVICES) && \
                         (tcm->Value & (typ)) &&\
                         (ImplicitOutputID == tcm->OutputID)) \
                     { xRemove (CommandQueue, tcm); \
                       if (xName (tcm)) xMemFree (xName (tcm)); \
                       xMemFree (tcm); } \
                  } while (tcm = ncm); \
                  xSetRemember (okey); \
               } \
            } \
   } while (0)

#define SetupFilter(id, piid, tid) \
   do \
   { \
      struct dmxSctFilterParams sfp; \
      \
      if ((id)->FileHandle) \
       { ioctl ((id)->FileHandle, DMX_STOP, 0); } \
      else \
       { (id)->FileHandle = open (xName (id), O_RDWR | O_NONBLOCK); } \
      \
      if ((id)->FileHandle < 0) \
       { logPrintf (0, "failed to open %s\n", xName (id));  \
         (id)->FileHandle = 0; return (-1); } \
      \
      sfp.pid = (piid); \
      memset (&sfp.filter.filter, 0x00, DMX_FILTER_SIZE); \
      memset (&sfp.filter.mask, 0x00, DMX_FILTER_SIZE); \
      sfp.timeout = 120000; \
      sfp.flags = DMX_IMMEDIATE_START | DMX_CHECK_CRC; \
      \
      sfp.filter.filter[0] = (tid); \
      sfp.filter.mask[0] = 0xFF; \
      \
      if (ioctl ((id)->FileHandle, DMX_SET_FILTER, &sfp) < 0) \
       { logPrintf (0, "failed to setup filter (%s)\n", strerror(errno)); \
         close ((id)->FileHandle); \
         (id)->FileHandle = 0; return (-1); } \
   } while (0)


#define SetupFilterAndSection(id, piid, tid, sid) \
   do \
   { \
      struct dmxSctFilterParams sfp; \
      \
      if ((id)->FileHandle) \
       { ioctl ((id)->FileHandle, DMX_STOP, 0); } \
      else \
       { (id)->FileHandle = open (xName (id), O_RDWR | O_NONBLOCK); } \
      \
      if ((id)->FileHandle < 0) \
       { logPrintf (0, "failed to open %s\n", xName (id));  \
         (id)->FileHandle = 0; return (-1); } \
      \
      sfp.pid = (piid); \
      memset (&sfp.filter.filter, 0x00, DMX_FILTER_SIZE); \
      memset (&sfp.filter.mask, 0x00, DMX_FILTER_SIZE); \
      sfp.timeout = 120000; \
      sfp.flags = DMX_IMMEDIATE_START | DMX_CHECK_CRC; \
      \
      sfp.filter.filter[0] = (tid); \
      sfp.filter.mask[0] = 0xFF; \
      \
      sfp.filter.filter[3] = 0x01; /* setup filter for current/next indicator */ \
      sfp.filter.mask[3] = 0x01;   /* (only current sections will survive) */ \
      \
      sfp.filter.filter[4] = (sid); /* setup filter for section number */ \
      sfp.filter.mask[4] = 0xFF; \
      \
      if (ioctl ((id)->FileHandle, DMX_SET_FILTER, &sfp) < 0) \
       { logPrintf (0, "failed to setup filter (%s)\n", strerror(errno)); \
         close ((id)->FileHandle); \
         (id)->FileHandle = 0; return (-1); } \
   } while (0)


#define SetupFilterSectionAndMask(id, piid, tid, msk) \
   do \
   { \
      struct dmxSctFilterParams sfp; \
      \
      if ((id)->FileHandle) \
       { ioctl ((id)->FileHandle, DMX_STOP, 0); } \
      else \
       { (id)->FileHandle = open (xName (id), O_RDWR | O_NONBLOCK); } \
      \
      if ((id)->FileHandle < 0) \
       { logPrintf (0, "failed to open %s\n", xName (id));  \
         (id)->FileHandle = 0; return (-1); } \
      \
      sfp.pid = (piid); \
      memset (&sfp.filter.filter, 0x00, DMX_FILTER_SIZE); \
      memset (&sfp.filter.mask, 0x00, DMX_FILTER_SIZE); \
      sfp.timeout = 120000; \
      sfp.flags = DMX_IMMEDIATE_START | DMX_CHECK_CRC; \
      \
      sfp.filter.filter[0] = (tid); \
      sfp.filter.mask[0] = (msk); \
      \
      sfp.filter.filter[3] = 0x01; /* setup filter for current/next indicator */ \
      sfp.filter.mask[3] = 0x01;   /* (only current sections will survive) */ \
      \
      if (ioctl ((id)->FileHandle, DMX_SET_FILTER, &sfp) < 0) \
       { logPrintf (0, "failed to setup filter (%s)\n", strerror(errno)); \
         close ((id)->FileHandle); \
         (id)->FileHandle = 0; return (-1); } \
   } while (0)


#define SetupFilterOnID(id, piid, tid, sid, svid) \
   do \
   { \
      struct dmxSctFilterParams sfp; \
      \
      if ((id)->FileHandle) \
       { ioctl ((id)->FileHandle, DMX_STOP, 0); } \
      else \
       { (id)->FileHandle = open (xName (id), O_RDWR | O_NONBLOCK); } \
      \
      if ((id)->FileHandle < 0) \
       { logPrintf (0, "failed to open %s\n", xName (id));  \
         (id)->FileHandle = 0; return (-1); } \
      \
      sfp.pid = (piid); \
      memset (&sfp.filter.filter, 0x00, DMX_FILTER_SIZE); \
      memset (&sfp.filter.mask, 0x00, DMX_FILTER_SIZE); \
      sfp.timeout = 0; \
      sfp.flags = DMX_IMMEDIATE_START | DMX_CHECK_CRC; \
      \
      sfp.filter.filter[0] = (tid); \
      sfp.filter.mask[0] = 0xFF; \
      \
      sfp.filter.filter[1] = (svid & 0xFF00)>>8; \
      sfp.filter.mask[1] = 0xFF; \
      \
      sfp.filter.filter[2] = (svid & 0xFF); \
      sfp.filter.mask[2] = 0xFF; \
      \
      sfp.filter.filter[3] = 0x01; /* setup filter for current/next indicator */ \
      sfp.filter.mask[3] = 0x01;   /* (only current sections will survive) */ \
      \
      sfp.filter.filter[4] = (sid); /* setup filter for section number */ \
      sfp.filter.mask[4] = 0xFF; \
      \
      if (ioctl ((id)->FileHandle, DMX_SET_FILTER, &sfp) < 0) \
       { logPrintf (0, "failed to setup filter (%s)\n", strerror(errno)); \
         close ((id)->FileHandle); \
         (id)->FileHandle = 0; return (-1); } \
   } while (0)


#define SetupFilterOnEitID(id, sid, svid) \
   do \
   { \
      struct dmxSctFilterParams sfp; \
      \
      if ((id)->FileHandle) \
       { ioctl ((id)->FileHandle, DMX_STOP, 0); } \
      else \
       { (id)->FileHandle = open (xName (id), O_RDWR | O_NONBLOCK); } \
      \
      if ((id)->FileHandle < 0) \
       { logPrintf (0, "failed to open %s\n", xName (id));  \
         (id)->FileHandle = 0; return (-1); } \
      \
      sfp.pid = PID_EIT; \
      memset (&sfp.filter.filter, 0x00, DMX_FILTER_SIZE); \
      memset (&sfp.filter.mask, 0x00, DMX_FILTER_SIZE); \
      sfp.timeout = 0; \
      sfp.flags = DMX_IMMEDIATE_START | DMX_CHECK_CRC; \
      \
      sfp.filter.filter[0] = TID_EIT_ACT; \
      sfp.filter.mask[0] = 0xFE; \
      \
      sfp.filter.filter[1] = ((svid) & 0xFF00)>>8; \
      sfp.filter.mask[1] = 0xFF; \
      \
      sfp.filter.filter[2] = ((svid) & 0xFF); \
      sfp.filter.mask[2] = 0xFF; \
      \
      sfp.filter.filter[3] = 0x01; /* setup filter for current/next indicator */ \
      sfp.filter.mask[3] = 0x01;   /* (only current sections will survive) */ \
      \
      sfp.filter.filter[4] = (sid); /* setup filter for section number */ \
      sfp.filter.mask[4] = 0xFF; \
      \
      if (ioctl ((id)->FileHandle, DMX_SET_FILTER, &sfp) < 0) \
       { logPrintf (0, "failed to setup filter (%s)\n", strerror(errno)); \
         close ((id)->FileHandle); \
         (id)->FileHandle = 0; return (-1); } \
   } while (0)


struct OsdTerm
{
   struct NODE         Node;
   int                 FileHandle;
   char               *Screen;
   int                 osdDev;
   int                 PosX;
   int                 PosY;
   int                 FgColor;
   int                 BgColor;
};

#define CreateOsdTerm(term, fh, fgcolor, bgcolor, size) \
   do \
   { \
      xCreateNode (term, NULL); \
      xMemAlloc ((size), &term->Screen); \
      term->osdDev = (fh); \
      term->PosX = 0; \
      term->PosY = 0; \
      term->FgColor = fgcolor; \
      term->BgColor = bgcolor; \
   } while (0)

struct OutputDevice
{
   struct NODE              Node;     /* Node enthaelt Pfadname */
   unsigned short           Identifier;
   unsigned short           Status;
   unsigned short           State;
   struct timeval           TimeStamp;
   struct Channel          *InfoChannel;
   struct Transponder      *InfoTransponder;
   int                      osdDev;
   unsigned short           osdLanguage;
   int                      audioDev;
   int                      videoDev;
   int                    (*Process)(struct OutputDevice *, struct Command *);
   void                   (*Close)(struct OutputDevice *);
   struct LIST             *Channels;
   struct Channel          *Channel;
   struct OsdTerm          *OsdTerm;
   struct VideoText        *VideoText;
   struct MEM_CHUNK        *VtxRemember;
   struct LIST             *UserMenu;
   struct MenuItem         *ActualMenuItem;
};

#define CreateOutputDevice(dev, text, iden, pro, cls) \
   do \
   { \
      xCreateNode ((dev), text); \
      (dev)->Identifier = iden; \
      (dev)->Status = OUTDEV_DISABLED; \
      (dev)->State = 0; \
      (dev)->TimeStamp.tv_sec = 0; \
      (dev)->TimeStamp.tv_usec = 0; \
      (dev)->InfoChannel = NULL; \
      (dev)->InfoTransponder = NULL; \
      (dev)->osdDev = 0; \
      (dev)->osdLanguage = 0; \
      (dev)->audioDev = 0; \
      (dev)->videoDev = 0; \
      (dev)->Process = pro; \
      (dev)->Close = cls; \
      (dev)->Channels = xNewList (NULL); \
      (dev)->Channel = NULL; \
      (dev)->OsdTerm = NULL; \
      (dev)->VideoText = NULL; \
      (dev)->VtxRemember = NULL; \
      (dev)->UserMenu = xNewList (NULL); \
      (dev)->ActualMenuItem = NULL; \
   } while (0)


struct MenuItem
{
   struct NODE              Node;
   unsigned short           Type;
   struct LIST             *Menu;
   struct MenuItem         *UplevelMenu;
   struct MenuItem         *StartOfScreen;
   char                    *Command;
};

#define CreateMenuItem(mit, id, typ, umen) \
   do \
   { \
      xCreateNode ((mit), id); \
      (mit)->Type = (typ); \
      (mit)->Menu = NULL; \
      (mit)->UplevelMenu = (umen); \
      (mit)->StartOfScreen = NULL; \
      (mit)->Command = NULL; \
   } while (0)


struct Satellite {
   struct NODE          Node;
   int                  DiseqcNr;
   int                  LnbLsof;
   int                  LnbFreqLow;
   int                  LnbFreqHigh;
};

#define CreateSatellite(sat, name, dis, lso, lsl, lsh) \
   do { \
      xCreateNode (sat, name); \
      (sat)->DiseqcNr = (dis); \
      (sat)->LnbLsof = (lso); \
      (sat)->LnbFreqLow = (lsl); \
      (sat)->LnbFreqHigh = (lsh); \
   } while (0)


struct Channel {
   struct NODE          Node;
   int                  ChannelNumber;
   int                  ChannelID;
   char                *Provider;
   char                *Type;
   unsigned short       UsedFlag;
   int                  TransportStreamID;
   int                  Frequency;
   char                 Polarisation;
   int                  SymbolRate;
   int                  ServiceID;
   int                  VideoPid;
   unsigned short       VideoTag;
   int                  AudioPid;
   unsigned short       AudioTag;
   int                  VtxPid;
   int                  PcrPid;
   char                *Language;
   char                *Fec;
   char                *Camd;
   struct Satellite    *Satellite;
   struct LIST         *LanguageList;
   struct MEM_CHUNK    *LanguageRemember;
   struct LIST         *NvodList;
   struct MEM_CHUNK    *NvodRemember;
   struct LIST         *LinkList;
   struct MEM_CHUNK    *LinkRemember;
   struct LIST         *ProgramInfos;
   struct MEM_CHUNK    *ProgramRemember;
   struct LIST         *ComponentInfos;
   struct MEM_CHUNK    *ComponentRemember;
   struct Channel      *MasterChannel;
   int                  ScreenPosition;
};

#define CreateChannel(ch, chnum, chid, name, prov, type, tpid, freq, pol, srat, svid, vpid, apid, lang, fec, camd) \
   do { \
      xCreateNode (ch, name); \
      (ch)->ChannelNumber = chnum; \
      (ch)->ChannelID = chid; \
      (ch)->Provider = xSetText (prov); \
      (ch)->Type = xSetText (type); \
      (ch)->UsedFlag = 0; \
      (ch)->TransportStreamID = tpid; \
      (ch)->Frequency = freq; \
      (ch)->Polarisation = pol; \
      (ch)->SymbolRate = srat; \
      (ch)->ServiceID = svid; \
      (ch)->VideoPid = vpid; \
      (ch)->VideoTag = 0; \
      (ch)->AudioPid = apid; \
      (ch)->AudioTag = 0; \
      (ch)->VtxPid = 0; \
      (ch)->PcrPid = 0; \
      (ch)->Language = xSetText (lang); \
      (ch)->Fec = xSetText (fec); \
      (ch)->Camd = xSetText (camd); \
      (ch)->Satellite = NULL; \
      (ch)->LanguageList = NULL; \
      (ch)->LanguageRemember = NULL; \
      (ch)->NvodList = NULL; \
      (ch)->NvodRemember = NULL; \
      (ch)->LinkList = NULL; \
      (ch)->LinkRemember = NULL; \
      (ch)->ProgramInfos = NULL; \
      (ch)->ProgramRemember = NULL; \
      (ch)->ComponentInfos = NULL; \
      (ch)->ComponentRemember = NULL; \
      (ch)->MasterChannel = NULL; \
      (ch)->ScreenPosition = 0; \
   } while (0)

#define FindChannel(dev, chan, num) \
   do { \
      (chan) = NULL; \
      if ((dev)->Channels) \
         xForeach ((dev)->Channels, (chan)) \
            if ((chan)->ChannelNumber == num) break; \
   } while (0)

#define CloneChannel(chd, chs, vpid, vtag, apid, atag, name) \
   do { \
      CreateChannel(chd, (chs)->ChannelNumber, (chs)->ChannelID, (name), \
         (chs)->Provider, (chs)->Type, (chs)->TransportStreamID, \
         (chs)->Frequency, (chs)->Polarisation, (chs)->SymbolRate, \
         (chs)->ServiceID, (vpid), (apid), (chs)->Language, \
         (chs)->Fec, (chs)->Camd); \
      (chd)->PcrPid = (chs)->PcrPid; \
      (chd)->VideoTag = (vtag); \
      (chd)->AudioTag = (atag); \
   } while (0)

struct VideoText {
   struct NODE          Node;
   struct Channel      *Channel;
   int                  PageNumber;
   int                  SubpageNumber;
   struct VtxPage      *CurrentPage;
   struct VtxPage      *DisplayedPage;
   struct LIST         *Pages;
};

#define CreateVideoText(vtx, chan) \
   do { \
      xCreateNode (vtx, NULL); \
      (vtx)->Channel = (chan); \
      (vtx)->PageNumber = 0; \
      (vtx)->SubpageNumber = 0; \
      (vtx)->CurrentPage = NULL; \
      (vtx)->DisplayedPage = NULL; \
      (vtx)->Pages = xNewList (NULL); \
   } while (0)

struct fmt_char
{
   unsigned char        ch;
   unsigned char        fg;
   unsigned char        bg;
   unsigned char        attr;
};

struct VtxPage {
   struct NODE          Node;
   int                  PageNumber;
   int                  SubpageNumber;
   unsigned short       LanguageCode;
   unsigned short       Flags;
   unsigned int         ReceivedLines;
   unsigned char        Data[26][41];
   unsigned short       Flof;
   struct {
      int PageNumber;
      int SubpageNumber;                  
   }                    Link[6];
   struct
   {
      int next_des;
      unsigned int trip[13*16];
   }                    Enhance;
   unsigned int         Double;
   unsigned int         Hidden;
   unsigned int         Reveal;
   struct fmt_char      Page[26][41];
};


#define CreateVtxPage(vtx) \
   do { \
      xCreateNode (vtx, NULL); \
      memset (vtx, 0, sizeof (*vtx)); \
   } while (0)


struct ProgramInfo {
   struct NODE          Node;
   int                  EventID;
   time_t               StartTime;
   time_t               Duration;
   unsigned short       Status;
   char                 LanguageCode[4];
   unsigned short       Rating;
   char                *Content;
   char                *ShortName;
   char                *ShortText;
   char                *ExtendedName;
   char                *ExtendedText;
};

#define CreateProgramInfo(cinf, evid, stst, dura, sta) \
   do \
   { \
      xCreateNode (cinf, NULL); \
      cinf->EventID = evid; \
      cinf->StartTime = stst; \
      cinf->Duration = dura; \
      cinf->Status = sta; \
      cinf->LanguageCode[0] = 0; \
      cinf->Rating = 0; \
      cinf->Content = NULL; \
      cinf->ShortName = NULL; \
      cinf->ShortText = NULL; \
      cinf->ExtendedName = NULL; \
      cinf->ExtendedText = NULL; \
   } while (0)


struct ComponentInfo {
   struct NODE          Node;
   unsigned short       Tag;
};

#define CreateComponentInfo(cinf, txt, ctg) \
   do \
   { \
      xCreateNode (cinf, txt); \
      cinf->Tag = ctg; \
   } while (0)


struct osdFont
{
   unsigned long              Width;
   unsigned long              Height;
   unsigned long              Data[1];
};


struct Transponder
{
   struct NODE             Node;
   int                     Frequency;
   char                    Polarisation;
   int                     SymbolRate;
   int                     TransportStreamID;
   struct Satellite       *Satellite;
};

#define CreateTransponder(transp, freq, pol, symb) \
   do \
   { \
      xCreateNode (transp, NULL); \
      (transp)->Frequency = (freq); \
      (transp)->Polarisation = (pol); \
      (transp)->SymbolRate = (symb); \
      (transp)->TransportStreamID = -1; \
      (transp)->Satellite = NULL; \
   } while (0)


#define AddToText(src, dest) \
   do { \
      if (dest) \
      { \
         char *tmbuf; \
         xMemAlloc (strlen (src) + strlen (dest) + 4, &tmbuf); \
         sprintf (tmbuf, "%s%s", (dest), (src)); \
         xMemFree (dest); (dest) = tmbuf; \
      } else { \
         (dest) = xSetText (src); \
      } \
   } while (0)


#define AddItemToText(src, dest) \
   do { \
      if (dest) \
      { \
         char *tmbuf; \
         xMemAlloc (strlen (src) + strlen (dest) + 4, &tmbuf); \
         sprintf (tmbuf, "%s|%s", (dest), (src)); \
         xMemFree (dest); (dest) = tmbuf; \
      } else { \
         (dest) = xSetText (src); \
      } \
   } while (0)

